@@ -194,10 +194,12 @@ int sock_stalled (int error)
 }
 
 
+#ifdef HAVE_GETADDRINFO
 static int sock_connect_pending (int error)
 {
     return error == EINPROGRESS || error == EALREADY;
 }
+#endif
 
 /* sock_valid_socket
 **
@@ -262,7 +264,7 @@ int sock_set_blocking(sock_t sock, int block)
 #ifdef __MINGW32__
     u_long varblock = 1;
 #else
-    int varblock = 1;
+    u_long varblock = 1;
 #endif
 #endif
 
@@ -327,7 +329,7 @@ ssize_t sock_writev (sock_t sock, const struct iovec *iov, size_t count)
 
 ssize_t sock_writev (sock_t sock, const struct iovec *iov, size_t count)
 {
-    int i = count, accum = 0, ret;
+    int i = (int)count, accum = 0, ret;
     const struct iovec *v = iov;
 
     while (i)
@@ -367,7 +369,7 @@ int sock_write_bytes(sock_t sock, const void *buff, size_t len)
         return SOCK_ERROR;
     } */
 
-    return send(sock, buff, len, 0);
+    return send(sock, buff, (int)len, 0);
 }
 
 /* sock_write_string
@@ -469,7 +471,7 @@ int sock_read_bytes(sock_t sock, char *buff, size_t len)
     if (!buff) return 0;
     if (len <= 0) return 0;
 
-    return recv(sock, buff, len, 0);
+    return recv(sock, buff, (int)len, 0);
 }
 
 /* sock_read_line
@@ -569,7 +571,7 @@ int sock_connected (sock_t sock, int timeout)
     FD_ZERO(&wfds);
     FD_SET(sock, &wfds);
 
-    switch (select(sock + 1, NULL, &wfds, NULL, timeval))
+    switch (select((int)sock + 1, NULL, &wfds, NULL, timeval))
     {
         case 0:
             return SOCK_TIMEOUT;
@@ -786,7 +788,7 @@ int sock_try_connection (sock_t sock, const char *hostname, unsigned int port)
         return -1;
     }
 
-    memcpy(&server.sin_addr, &sin.sin_addr, sizeof(struct sockaddr_in));
+    memcpy(&server.sin_addr, &sin.sin_addr, sizeof(IN_ADDR));
 
     server.sin_family = AF_INET;
     server.sin_port = htons((short)port);
