@@ -312,9 +312,7 @@ LED.prototype.flashOn = function(num_ms_on, value, num_ms_off, flashCount, relig
         // so we don't need this part  if flashcount == 1
 
         // permanent timer
-        this.flashTimer = engine.beginTimer(num_ms_on + num_ms_off, function() {
-            this.flashOnceOn(false);
-        });
+        this.flashTimer = engine.beginTimer(num_ms_on + num_ms_off, ()=>this.flashOnceOn(false));
     }
 
     if (flashCount > 1) {
@@ -322,9 +320,7 @@ LED.prototype.flashOn = function(num_ms_on, value, num_ms_off, flashCount, relig
         // so we don't need this part  if flashcount=1
         // temporary timer. The end of this timer stops the permanent flashing
 
-        this.flashTimer2 = engine.beginTimer(flashCount * (num_ms_on + num_ms_off) - num_ms_off, function() {
-            this.stopflash(relight);
-        }, true);
+        this.flashTimer2 = engine.beginTimer(flashCount * (num_ms_on + num_ms_off) - num_ms_off, ()=>this.stopflash(relight), true);
     }
 };
 
@@ -371,9 +367,7 @@ LED.prototype.flashOnceOn = function(relight) {
     sendShortMsg(this.control, this.midino, this.valueon);
     pauseScript(scriptpause);
     this.flashOnceDuration = this.num_ms_on;
-    this.flashOnceTimer = engine.beginTimer(this.num_ms_on - scriptpause, function() {
-        this.flashOnceOff(relight);
-    }, true);
+    this.flashOnceTimer = engine.beginTimer(this.num_ms_on - scriptpause, ()=>this.flashOnceOff(relight), true);
 };
 
 // private :call back function (called in flashOnceOn() )
@@ -428,7 +422,7 @@ SingleDoubleBtn.prototype.buttonDown = function(channel, control, value, status,
     this.group = group;
 
     if (this.buttonTimer === 0) { // first press
-        this.buttonTimer = engine.beginTimer(this.doublePressTimeOut, this.buttonDecide, true);
+        this.buttonTimer = engine.beginTimer(this.doublePressTimeOut, this.buttonDecide.bind(this), true);
         this.buttonCount = 1;
     } else { // 2nd press (before timer's out)
         engine.stopTimer(this.buttonTimer);
@@ -492,7 +486,7 @@ LongShortBtn.prototype.buttonDown = function(channel, control, value, status, gr
     this.status = status;
     this.group = group;
     this.buttonLongPress = false;
-    this.buttonLongPressTimer = engine.beginTimer(this.longPressThreshold, this.buttonAssertLongPress, true);
+    this.buttonLongPressTimer = engine.beginTimer(this.longPressThreshold, this.buttonAssertLongPress.bind(this), true);
 };
 
 LongShortBtn.prototype.buttonUp = function() {
@@ -582,11 +576,11 @@ LongShortDoubleBtn.prototype.buttonDown = function(channel, control, value, stat
         this.buttonLongPress = false;
 
         this.buttonLongPressTimer = engine.beginTimer(
-            this.longPressThreshold, this.buttonAssertLongPress, true
+            this.longPressThreshold, this.buttonAssertLongPress.bind(this), true
         );
 
         this.buttonTimer = engine.beginTimer(
-            this.doublePressTimeOut, this.buttonAssert1Press, true
+            this.doublePressTimeOut, this.buttonAssert1Press.bind(this), true
         );
 
     } else if (this.buttonCount === 1) { // 2nd press (before short timer's out)
@@ -895,6 +889,9 @@ NumarkMixtrack3.init = function(id, debug) {
         NumarkMixtrack3.decks["D" + i] = new NumarkMixtrack3.deck(i);
     }
 
+    if (engine.getValue("[App]", "num_samplers") < 8) {
+        engine.setValue("[App]", "num_samplers", 8);
+    }
     // initialize 8 samplers
     for (var i = 1; i <= 8; i++) {
         NumarkMixtrack3.samplers["S" + i] = new NumarkMixtrack3.sampler(i);
@@ -975,7 +972,7 @@ NumarkMixtrack3.connectDeckControls = function(group, remove) {
         "hotcue_3_enabled": "NumarkMixtrack3.OnHotcueChange",
         "hotcue_4_enabled": "NumarkMixtrack3.OnHotcueChange",
         "track_samples": "NumarkMixtrack3.OnTrackLoaded",
-        "VuMeter": "NumarkMixtrack3.OnVuMeterChange",
+        "vu_meter": "NumarkMixtrack3.OnVuMeterChange",
         "playposition": "NumarkMixtrack3.OnPlaypositionChange",
         "volume": "NumarkMixtrack3.OnVolumeChange",
         "pfl": "NumarkMixtrack3.OnPFLStatusChange",
@@ -1091,7 +1088,7 @@ NumarkMixtrack3.BrowseButton = function(channel, control, value, status, group)
 	    } else {
 	        // Browse push : maximize/minimize library view
 	        if (value === ON) {
-	            script.toggleControl("[Master]", "maximize_library");
+	            script.toggleControl("[Skin]", "show_maximized_library");
 	        }
 	    }
     }
