@@ -83,19 +83,23 @@ TerminalMix.init = function (id,debug) {
     TerminalMix.effectUnit24.init();
 
     // Enable four decks in v1.11.x
-    engine.setValue("[Master]", "num_decks", 4);
+    engine.setValue("[App]", "num_decks", 4);
+    const samplerCount = 8;
+    if (engine.getValue("[App]", "num_samplers") < samplerCount) {
+        engine.setValue("[App]", "num_samplers", samplerCount);
+    }
 
     // Set soft-takeover for all Sampler volumes
-    for (var i=engine.getValue("[Master]","num_samplers"); i>=1; i--) {
+    for (let i=samplerCount; i>=1; i--) {
         engine.softTakeover("[Sampler"+i+"]","pregain",true);
     }
     // Set soft-takeover for all applicable Deck controls
-    for (var i=engine.getValue("[Master]","num_decks"); i>=1; i--) {
-        engine.softTakeover("[Channel"+i+"]","volume",true);
-        engine.softTakeover("[Channel"+i+"]","filterHigh",true);
-        engine.softTakeover("[Channel"+i+"]","filterMid",true);
-        engine.softTakeover("[Channel"+i+"]","filterLow",true);
-        engine.softTakeover("[Channel"+i+"]","rate",true);
+    for (let j=engine.getValue("[App]", "num_decks"); j>=1; j--) {
+        engine.softTakeover("[Channel"+j+"]", "volume", true);
+        engine.softTakeover("[Channel"+j+"]", "filterHigh", true);
+        engine.softTakeover("[Channel"+j+"]", "filterMid", true);
+        engine.softTakeover("[Channel"+j+"]", "filterLow", true);
+        engine.softTakeover("[Channel"+j+"]", "rate", true);
     }
 
     engine.softTakeover("[Master]","crossfader",true);
@@ -104,8 +108,8 @@ TerminalMix.init = function (id,debug) {
     engine.connectControl("[Channel2]","beat_active","TerminalMix.tapLEDR");
 
     TerminalMix.timers["fstartflash"] = -1;
-//     TerminalMix.timers["qtrSec"] = engine.beginTimer(250,"TerminalMix.qtrSec");
-    TerminalMix.timers["halfSec"] = engine.beginTimer(500,"TerminalMix.halfSec");
+//     TerminalMix.timers["qtrSec"] = engine.beginTimer(250, TerminalMix.qtrSec);
+    TerminalMix.timers["halfSec"] = engine.beginTimer(500, TerminalMix.halfSec);
 
     if (TerminalMix.traxKnobMode == "tracks") {
         midi.sendShortMsg(0x90,0x37,0x7F);  // light Back button
@@ -167,7 +171,7 @@ TerminalMix.wheelTurn = function (channel, control, value, status, group) {
 
 TerminalMix.samplerVolume = function (channel, control, value) {
     // Link all sampler volume controls to the Sampler Volume knob
-    for (var i=engine.getValue("[Master]","num_samplers"); i>=1; i--) {
+    for (var i=engine.getValue("[App]", "num_samplers"); i>=1; i--) {
         engine.setValue("[Sampler"+i+"]","pregain",
                         script.absoluteNonLin(value, 0.0, 1.0, 4.0));
     }
@@ -441,7 +445,7 @@ TerminalMix.crossFader = function (channel, control, value, status, group) {
 
     // If CF is now full left and decks assigned to R are playing, cue them
     if (cfValue==-1.0) {
-        for (var i=engine.getValue("[Master]","num_decks"); i>=1; i--) {
+        for (var i=engine.getValue("[App]", "num_decks"); i>=1; i--) {
             group = "[Channel"+i+"]";
             if (TerminalMix.faderStart[group]
                 && engine.getValue(group,"orientation")==2
@@ -453,7 +457,7 @@ TerminalMix.crossFader = function (channel, control, value, status, group) {
 
     if (cfValue==1.0) {
         // If CF is now full right and decks assigned to L are playing, cue them
-        for (var i=engine.getValue("[Master]","num_decks"); i>=1; i--) {
+        for (var i=engine.getValue("[App]", "num_decks"); i>=1; i--) {
             group = "[Channel"+i+"]";
             if (TerminalMix.faderStart[group]
                 && engine.getValue(group,"orientation")==0
@@ -465,7 +469,7 @@ TerminalMix.crossFader = function (channel, control, value, status, group) {
 
     // If the CF is moved from full left, start any decks assigned to R
     if (TerminalMix.lastFader["crossfader"]==-1.0) {
-        for (var i=engine.getValue("[Master]","num_decks"); i>=1; i--) {
+        for (var i=engine.getValue("[App]", "num_decks"); i>=1; i--) {
             group = "[Channel"+i+"]";
             if (TerminalMix.faderStart[group]
                 && engine.getValue(group,"orientation")==2) {
@@ -476,7 +480,7 @@ TerminalMix.crossFader = function (channel, control, value, status, group) {
 
     if (TerminalMix.lastFader["crossfader"]==1.0) {
         // If the CF is moved from full right, start any decks assigned to L
-        for (var i=engine.getValue("[Master]","num_decks"); i>=1; i--) {
+        for (var i=engine.getValue("[App]", "num_decks"); i>=1; i--) {
             group = "[Channel"+i+"]";
             if (TerminalMix.faderStart[group]
                 && engine.getValue(group,"orientation")==0) {
