@@ -1,10 +1,7 @@
 #include "analyzer/analyzerwaveform.h"
 
-#include "analyzer/constants.h"
-#include "engine/engineobject.h"
+#include "analyzer/analyzertrack.h"
 #include "engine/filters/enginefilterbessel4.h"
-#include "engine/filters/enginefilterbutterworth8.h"
-#include "library/trackcollection.h"
 #include "track/track.h"
 #include "util/logger.h"
 #include "waveform/waveformfactory.h"
@@ -13,6 +10,10 @@ namespace {
 
 mixxx::Logger kLogger("AnalyzerWaveform");
 
+constexpr double kLowMidFreqHz = 600.0;
+
+constexpr double kMidHighFreqHz = 4000.0;
+
 } // namespace
 
 AnalyzerWaveform::AnalyzerWaveform(
@@ -35,7 +36,7 @@ AnalyzerWaveform::~AnalyzerWaveform() {
     destroyFilters();
 }
 
-bool AnalyzerWaveform::initialize(TrackPointer pTrack,
+bool AnalyzerWaveform::initialize(const AnalyzerTrack& track,
         mixxx::audio::SampleRate sampleRate,
         SINT frameLength) {
     if (frameLength <= 0) {
@@ -44,7 +45,7 @@ bool AnalyzerWaveform::initialize(TrackPointer pTrack,
     }
 
     // If we don't need to calculate the waveform/wavesummary, skip.
-    if (!shouldAnalyze(pTrack)) {
+    if (!shouldAnalyze(track.getTrack())) {
         return false;
     }
 
@@ -55,9 +56,9 @@ bool AnalyzerWaveform::initialize(TrackPointer pTrack,
     createFilters(sampleRate);
 
     //TODO (vrince) Do we want to expose this as settings or whatever ?
-    const int mainWaveformSampleRate = 441;
+    constexpr int mainWaveformSampleRate = 441;
     // two visual sample per pixel in full width overview in full hd
-    const int summaryWaveformSamples = 2 * 1920;
+    constexpr int summaryWaveformSamples = 2 * 1920;
 
     m_waveform = WaveformPointer(new Waveform(
             sampleRate, frameLength, mainWaveformSampleRate, -1));
@@ -67,8 +68,8 @@ bool AnalyzerWaveform::initialize(TrackPointer pTrack,
     // Now, that the Waveform memory is initialized, we can set set them to
     // the TIO. Be aware that other threads of Mixxx can touch them from
     // now.
-    pTrack->setWaveform(m_waveform);
-    pTrack->setWaveformSummary(m_waveformSummary);
+    track.getTrack()->setWaveform(m_waveform);
+    track.getTrack()->setWaveformSummary(m_waveformSummary);
 
     m_waveformData = m_waveform->data();
     m_waveformSummaryData = m_waveformSummary->data();
@@ -148,14 +149,14 @@ bool AnalyzerWaveform::shouldAnalyze(TrackPointer tio) const {
     return true;
 }
 
-void AnalyzerWaveform::createFilters(int sampleRate) {
-    // m_filter[Low] = new EngineFilterButterworth8(FILTER_LOWPASS, sampleRate, 200);
-    // m_filter[Mid] = new EngineFilterButterworth8(FILTER_BANDPASS, sampleRate, 200, 2000);
-    // m_filter[High] = new EngineFilterButterworth8(FILTER_HIGHPASS, sampleRate, 2000);
-    m_filter[Low] = new EngineFilterBessel4Low(sampleRate, 600);
-    m_filter[Mid] = new EngineFilterBessel4Band(sampleRate, 600, 4000);
-    m_filter[High] = new EngineFilterBessel4High(sampleRate, 4000);
-    // settle filters for silence in preroll to avoids ramping (Bug #1406389)
+void AnalyzerWaveform::createFilters(mixxx::audio::SampleRate sampleRate) {
+    // m_filter[Low] = new EngineFilterButterworth8Low(sampleRate, kLowMidFreqHz);
+    // m_filter[Mid] = new EngineFilterButterworth8Band(sampleRate, kLowMidFreqHz, kMidHighFreqHz);
+    // m_filter[High] = new EngineFilterButterworth8High(sampleRate, kMidHighFreqHz);
+    m_filter[Low] = new EngineFilterBessel4Low(sampleRate, kLowMidFreqHz);
+    m_filter[Mid] = new EngineFilterBessel4Band(sampleRate, kLowMidFreqHz, kMidHighFreqHz);
+    m_filter[High] = new EngineFilterBessel4High(sampleRate, kMidHighFreqHz);
+    // settle filters for silence in preroll to avoids ramping (Issue #7776)
     for (int i = 0; i < FilterCount; ++i) {
         m_filter[i]->assumeSettled();
     }
@@ -178,7 +179,7 @@ bool AnalyzerWaveform::processSamples(const CSAMPLE* buffer, SINT count) {
         return false;
     }
 
-    //this should only append once if bufferLength is constant
+    // This should only append once if count is constant
     if (count > static_cast<SINT>(m_buffers[0].size())) {
         m_buffers[Low].resize(count);
         m_buffers[Mid].resize(count);
@@ -192,7 +193,7 @@ bool AnalyzerWaveform::processSamples(const CSAMPLE* buffer, SINT count) {
     m_waveform->setSaveState(Waveform::SaveState::NotSaved);
     m_waveformSummary->setSaveState(Waveform::SaveState::NotSaved);
 
-    for (int i = 0; i < count; i += 2) {
+    for (SINT i = 0; i < count; i += 2) {
         // Take max value, not average of data
         CSAMPLE cover[2] = {fabs(buffer[i]), fabs(buffer[i + 1])};
         CSAMPLE clow[2] = {fabs(m_buffers[Low][i]), fabs(m_buffers[Low][i + 1])};
