@@ -5,6 +5,7 @@
 #include <QTimer>
 #include <memory>
 
+#include "controllers/controllerenumerator.h"
 #include "preferences/usersettings.h"
 #include "util/duration.h"
 
@@ -51,13 +52,9 @@ class ControllerManager : public QObject {
     void mappingApplied(bool applied);
 
   public slots:
-    void updateControllerList();
-
     void slotApplyMapping(Controller* pController,
             std::shared_ptr<LegacyControllerMapping> pMapping,
             bool bEnabled);
-    void openController(Controller* pController);
-    void closeController(Controller* pController);
 
   private slots:
     /// Perform initialization that should be delayed until the ControllerManager
@@ -69,12 +66,16 @@ class ControllerManager : public QObject {
     void slotSetUpDevices();
     void slotShutdown();
     /// Calls poll() on all devices that have isPolling() true.
-    void pollDevices();
+    void slotPollDevices();
+
+  private:
+    void updateControllerList();
     void startPolling();
     void stopPolling();
     void pollIfAnyControllersOpen();
+    void openController(Controller* pController);
+    void closeController(Controller* pController);
 
-  private:
     UserSettingsPointer m_pConfig;
     ControllerLearningEventFilter* m_pControllerLearningEventFilter;
     QTimer m_pollTimer;
