@@ -4,36 +4,38 @@
 #include "controllers/delegates/midibytedelegate.h"
 #include "controllers/delegates/midichanneldelegate.h"
 #include "controllers/delegates/midiopcodedelegate.h"
+#include "controllers/midi/legacymidicontrollermapping.h"
 #include "controllers/midi/midimessage.h"
 #include "controllers/midi/midiutils.h"
 #include "moc_controlleroutputmappingtablemodel.cpp"
 
 ControllerOutputMappingTableModel::ControllerOutputMappingTableModel(QObject* pParent,
-        ControlPickerMenu* pControlPickerMenu)
-        : ControllerMappingTableModel(pParent, pControlPickerMenu) {
+        ControlPickerMenu* pControlPickerMenu,
+        QTableView* pTableView)
+        : ControllerMappingTableModel(pParent, pControlPickerMenu, pTableView) {
 }
 
 ControllerOutputMappingTableModel::~ControllerOutputMappingTableModel() {
 }
 
 void ControllerOutputMappingTableModel::apply() {
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         // Clear existing output mappings and insert all the output mappings in
-        // the table into the preset.
+        // the table into the mapping.
         QMultiHash<ConfigKey, MidiOutputMapping> mappings;
-        for (const MidiOutputMapping& mapping : qAsConst(m_midiOutputMappings)) {
+        for (const MidiOutputMapping& mapping : std::as_const(m_midiOutputMappings)) {
             // There can be multiple output mappings for the same output
             // control, so we need to use a QMultiHash here.
             mappings.insert(mapping.controlKey, mapping);
         }
-        m_pMidiPreset->setOutputMappings(mappings);
+        m_pMidiMapping->setOutputMappings(mappings);
     }
 }
 
-void ControllerOutputMappingTableModel::onPresetLoaded() {
+void ControllerOutputMappingTableModel::onMappingLoaded() {
     clear();
 
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         // TODO(rryan): Tooltips
         setHeaderData(MIDI_COLUMN_CHANNEL, Qt::Horizontal, tr("Channel"));
         setHeaderData(MIDI_COLUMN_OPCODE, Qt::Horizontal, tr("Opcode"));
@@ -45,22 +47,22 @@ void ControllerOutputMappingTableModel::onPresetLoaded() {
         setHeaderData(MIDI_COLUMN_MAX, Qt::Horizontal, tr("On Range Max"));
         setHeaderData(MIDI_COLUMN_COMMENT, Qt::Horizontal, tr("Comment"));
 
-        if (!m_pMidiPreset->getOutputMappings().isEmpty()) {
-            beginInsertRows(QModelIndex(), 0, m_pMidiPreset->getOutputMappings().size() - 1);
-            m_midiOutputMappings = m_pMidiPreset->getOutputMappings().values();
+        if (!m_pMidiMapping->getOutputMappings().isEmpty()) {
+            beginInsertRows(QModelIndex(), 0, m_pMidiMapping->getOutputMappings().size() - 1);
+            m_midiOutputMappings = m_pMidiMapping->getOutputMappings().values();
             endInsertRows();
         }
         connect(this,
                 &QAbstractTableModel::dataChanged,
                 this,
                 [this]() {
-                    m_pMidiPreset->setDirty(true);
+                    m_pMidiMapping->setDirty(true);
                 });
     }
 }
 
 void ControllerOutputMappingTableModel::clear() {
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         if (!m_midiOutputMappings.isEmpty()) {
             beginRemoveRows(QModelIndex(), 0, m_midiOutputMappings.size() - 1);
             m_midiOutputMappings.clear();
@@ -70,7 +72,7 @@ void ControllerOutputMappingTableModel::clear() {
 }
 
 void ControllerOutputMappingTableModel::addEmptyMapping() {
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         beginInsertRows(QModelIndex(), m_midiOutputMappings.size(),
                         m_midiOutputMappings.size());
         m_midiOutputMappings.append(MidiOutputMapping());
@@ -102,7 +104,7 @@ void ControllerOutputMappingTableModel::removeMappings(QModelIndexList indices)
 
 QAbstractItemDelegate* ControllerOutputMappingTableModel::delegateForColumn(
         int column, QWidget* pParent) {
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         switch (column) {
             case MIDI_COLUMN_CHANNEL:
                 return new MidiChannelDelegate(pParent);
@@ -123,7 +125,7 @@ int ControllerOutputMappingTableModel::rowCount(const QModelIndex& parent) const
     if (parent.isValid()) {
         return 0;
     }
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         return m_midiOutputMappings.size();
     }
     return 0;
@@ -134,8 +136,8 @@ int ControllerOutputMappingTableModel::columnCount(const QModelIndex& parent) co
         return 0;
     }
     // Control and description
-    const int kBaseColumns = 2;
-    if (m_pMidiPreset != nullptr) {
+    constexpr int kBaseColumns = 2;
+    if (m_pMidiMapping != nullptr) {
         // Channel, Opcode, Control, On, Off, Min, Max
         return kBaseColumns + 7;
     }
@@ -154,7 +156,7 @@ QVariant ControllerOutputMappingTableModel::data(const QModelIndex& index,
     int row = index.row();
     int column = index.column();
 
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         if (row < 0 || row >= m_midiOutputMappings.size()) {
             return QVariant();
         }
@@ -164,7 +166,7 @@ QVariant ControllerOutputMappingTableModel::data(const QModelIndex& index,
             case MIDI_COLUMN_CHANNEL:
                 return MidiUtils::channelFromStatus(mapping.output.status);
             case MIDI_COLUMN_OPCODE:
-                return MidiUtils::opCodeFromStatus(mapping.output.status);
+                return MidiUtils::opCodeValue(MidiUtils::opCodeFromStatus(mapping.output.status));
             case MIDI_COLUMN_CONTROL:
                 return mapping.output.control;
             case MIDI_COLUMN_ON:
@@ -190,6 +192,53 @@ QVariant ControllerOutputMappingTableModel::data(const QModelIndex& index,
     return QVariant();
 }
 
+QString ControllerOutputMappingTableModel::getDisplayString(const QModelIndex& index) const {
+    if (!m_pMidiMapping || !m_pTableView || !index.isValid()) {
+        return QString();
+    }
+
+    int row = index.row();
+    int column = index.column();
+    const MidiOutputMapping& mapping = m_midiOutputMappings.at(row);
+
+    switch (column) {
+    case MIDI_COLUMN_COMMENT:
+        return mapping.description;
+    case MIDI_COLUMN_ON:
+        return QString::number(mapping.output.on);
+    case MIDI_COLUMN_OFF:
+        return QString::number(mapping.output.off);
+    case MIDI_COLUMN_MIN:
+        return QString::number(mapping.output.min);
+    case MIDI_COLUMN_MAX:
+        return QString::number(mapping.output.max);
+    case MIDI_COLUMN_CHANNEL:
+    case MIDI_COLUMN_OPCODE:
+    case MIDI_COLUMN_CONTROL: {
+        QStyledItemDelegate* del = getDelegateForIndex(index);
+        VERIFY_OR_DEBUG_ASSERT(del) {
+            return QString();
+        }
+        return del->displayText(data(index, Qt::DisplayRole), QLocale());
+    }
+    case MIDI_COLUMN_ACTION: {
+        QStyledItemDelegate* del = getDelegateForIndex(index);
+        VERIFY_OR_DEBUG_ASSERT(del) {
+            return QString();
+        }
+        // Return both the raw ConfigKey group + key and the translated display
+        // string and the translated description from ControlPickerMenu.
+        // Note: this may contain duplicate key strings in case this is an
+        // untranslated script control
+        return data(index, Qt::UserRole).toString() + QStringLiteral(" ") +
+                del->displayText(
+                        QVariant::fromValue(mapping.controlKey), QLocale());
+    }
+    default:
+        return QString();
+    }
+}
+
 bool ControllerOutputMappingTableModel::setData(const QModelIndex& index,
                                                 const QVariant& value,
                                                 int role) {
@@ -200,7 +249,7 @@ bool ControllerOutputMappingTableModel::setData(const QModelIndex& index,
     int row = index.row();
     int column = index.column();
 
-    if (m_pMidiPreset != nullptr) {
+    if (m_pMidiMapping != nullptr) {
         if (row < 0 || row >= m_midiOutputMappings.size()) {
             return false;
         }
