@@ -29,14 +29,22 @@ QString HidController::mappingExtension() {
 }
 
 void HidController::setMapping(std::shared_ptr<LegacyControllerMapping> pMapping) {
-    m_pMapping = downcastAndTakeOwnership<LegacyHidControllerMapping>(std::move(pMapping));
+    m_pMutableMapping = pMapping;
+    m_pMapping = downcastAndClone<LegacyHidControllerMapping>(pMapping.get());
 }
 
-std::shared_ptr<LegacyControllerMapping> HidController::cloneMapping() {
+QList<LegacyControllerMapping::ScriptFileInfo> HidController::getMappingScriptFiles() {
     if (!m_pMapping) {
-        return nullptr;
+        return {};
     }
-    return m_pMapping->clone();
+    return m_pMapping->getScriptFiles();
+}
+
+QList<std::shared_ptr<AbstractLegacyControllerSetting>> HidController::getMappingSettings() {
+    if (!m_pMapping) {
+        return {};
+    }
+    return m_pMapping->getSettings();
 }
 
 bool HidController::matchMapping(const MappingInfo& mapping) {
@@ -101,8 +109,6 @@ int HidController::open() {
         return -1;
     }
 
-    setOpen(true);
-
     m_pHidIoThread = std::make_unique<HidIoThread>(pHidDevice, m_deviceInfo);
     m_pHidIoThread->setObjectName(QStringLiteral("HidIoThread ") + getName());
 
@@ -132,6 +138,8 @@ int HidController::open() {
         qWarning() << "HidIoThread wasn't in expected OutputActive state";
     }
 
+    applyMapping();
+    setOpen(true);
     return 0;
 }
 
