@@ -5,13 +5,13 @@
 /// This class handles discovery and enumeration of DJ controllers that use the
 /// USB-HID protocol.
 class HidEnumerator : public ControllerEnumerator {
+    Q_OBJECT
   public:
-    explicit HidEnumerator(UserSettingsPointer pConfig);
-    virtual ~HidEnumerator();
+    HidEnumerator() = default;
+    ~HidEnumerator() override;
 
-    QList<Controller*> queryDevices();
+    QList<Controller*> queryDevices() override;
 
   private:
     QList<Controller*> m_devices;
-    UserSettingsPointer m_pConfig;
 };
