@@ -6,14 +6,13 @@
 class PortMidiEnumerator : public MidiEnumerator {
     Q_OBJECT
   public:
-    explicit PortMidiEnumerator(UserSettingsPointer pConfig);
-    virtual ~PortMidiEnumerator();
+    PortMidiEnumerator();
+    ~PortMidiEnumerator() override;
 
-    QList<Controller*> queryDevices();
+    QList<Controller*> queryDevices() override;
 
   private:
     QList<Controller*> m_devices;
-    UserSettingsPointer m_pConfig;
 };
 
 // For testing.
