@@ -91,12 +91,12 @@ QJSValue ControllerScriptEngineLegacy::wrapFunctionCode(
 }
 
 void ControllerScriptEngineLegacy::setScriptFiles(
-        const QList<LegacyControllerMapping::ScriptFileInfo>& scripts) {
+        QList<LegacyControllerMapping::ScriptFileInfo> scripts) {
     const QStringList paths = m_fileWatcher.files();
     if (!paths.isEmpty()) {
         m_fileWatcher.removePaths(paths);
     }
-    m_scriptFiles = scripts;
+    m_scriptFiles = std::move(scripts);
 }
 
 void ControllerScriptEngineLegacy::setSettings(
