@@ -20,7 +20,7 @@ class EffectsBackendManager {
     /// returns a pointer to the manifest or a null pointer in case a
     /// the previously stored backend or effect is no longer available
     EffectManifestPointer getManifest(const QString& id, EffectBackendType backendType) const;
-    const QString getDisplayNameForEffectPreset(EffectPresetPointer pPreset) const;
+    EffectManifestPointer getManifest(EffectPresetPointer pPreset) const;
 
     std::unique_ptr<EffectProcessor> createProcessor(const EffectManifestPointer pManifest);
 
