@@ -1,17 +1,14 @@
 #pragma once
 
 #include <QObject>
-#include <QVariant>
 #include <QString>
 
-#include "control/controlobject.h"
-#include "effects/effect.h"
 #include "effects/effectparameterslotbase.h"
 #include "util/class.h"
 
-class ControlObject;
 class ControlPushButton;
 
+/// Refer to EffectParameterSlotBase for documentation
 class EffectButtonParameterSlot : public EffectParameterSlotBase {
     Q_OBJECT
   public:
@@ -22,19 +19,11 @@ class EffectButtonParameterSlot : public EffectParameterSlotBase {
         return QString("button_parameter%1").arg(iParameterSlotNumber + 1);
     }
 
-    // Load the parameter of the given effect into this EffectButtonParameterSlot
-    void loadEffect(EffectPointer pEffect);
+    void loadParameter(EffectParameterPointer pEffectParameter) override;
 
-    // Clear the currently loaded effect
-    void clear();
+    void clear() override;
 
-    QDomElement toXml(QDomDocument* doc) const override;
-    void loadParameterSlotFromXml(const QDomElement& parameterElement) override;
-
-  private slots:
-    // Solely for handling control changes
-    void slotParameterValueChanged(double value);
-    void slotValueChanged(double v);
+    void setParameter(double value) override;
 
   private:
     QString debugString() const {
