@@ -21,12 +21,21 @@ class VisibleEffectsList : public QObject {
     const EffectManifestPointer previous(const EffectManifestPointer pManifest) const;
 
     void setList(const QList<EffectManifestPointer>& newList);
-    void readEffectsXml(const QDomDocument& doc, EffectsBackendManagerPointer pBackendManager);
-    void saveEffectsXml(QDomDocument* pDoc);
+    void readEffectsXml(const QDomDocument& doc,
+            EffectsBackendManagerPointer pBackendManager);
+    void saveEffectsXml(QDomDocument* pDoc,
+            EffectsBackendManagerPointer pBackendManager);
 
   signals:
     void visibleEffectsListChanged();
 
   private:
+    QList<EffectManifestPointer> readEffectsList(const QDomDocument& doc,
+            EffectsBackendManagerPointer pBackendManager,
+            const QString& xmlElementName);
+    void saveEffectsListXml(QDomDocument* pDoc,
+            const QList<EffectManifestPointer>& list,
+            const QString& xmlElementName);
+
     QList<EffectManifestPointer> m_list;
 };
