@@ -8,6 +8,7 @@
 #include <QString>
 #include <QStringList>
 
+#include "encoder/encodercallback.h"
 #include "engine/sidechain/enginesidechain.h"
 #include "recording/defs_recording.h"
 #include "util/logger.h"
@@ -15,7 +16,7 @@
 
 namespace {
 // recommended in encoder documentation, section 2.4.1
-const int kOutBufferBits = 6144;
+constexpr int kOutBufferBits = 6144;
 const mixxx::Logger kLogger("EncoderFdkAac");
 } // namespace
 
@@ -28,14 +29,11 @@ EncoderFdkAac::EncoderFdkAac(EncoderCallback* pCallback)
           m_aacAot(AOT_AAC_LC),
           m_bitrate(0),
           m_channels(0),
-          m_samplerate(0),
           m_pCallback(pCallback),
           m_pLibrary(nullptr),
           m_pInputFifo(nullptr),
-          m_pFifoChunkBuffer(nullptr),
           m_readRequired(0),
           m_aacEnc(),
-          m_pAacDataBuffer(nullptr),
           m_aacInfo(),
           m_hasSbr(false) {
     // Load the shared library
@@ -57,14 +55,14 @@ EncoderFdkAac::EncoderFdkAac(EncoderCallback* pCallback)
     // implementation of fdk-aac, we believe that the FDK AAC license is
     // GPL compatible.
     QStringList libnames;
-#if __WINDOWS__
+#if defined(__WINDOWS__)
     // Search for library from B.U.T.T.
     QString buttFdkAacPath = buttWindowsFdkAac();
     if (!buttFdkAacPath.isEmpty()) {
         kLogger.debug() << "Found libfdk-aac at" << buttFdkAacPath;
         libnames << buttFdkAacPath;
     }
-#elif __APPLE__
+#elif defined(__APPLE__)
     // Homebrew
     libnames << QStringLiteral("/usr/local/lib/libfdk-aac");
     // MacPorts
@@ -77,7 +75,7 @@ EncoderFdkAac::EncoderFdkAac(EncoderCallback* pCallback)
 #endif
     libnames << QStringLiteral("fdk-aac");
     // Although the line above should suffice, detection of the fdk-aac library
-    // does not work on Ubuntu 18.04 LTS and Ubuntu 20.04 LTS:
+    // does not work on Ubuntu 20.04 LTS:
     //
     //     $ dpkg -L libfdk-aac1 | grep so
     //     /usr/lib/x86_64-linux-gnu/libfdk-aac.so.1.0.0
@@ -88,7 +86,7 @@ EncoderFdkAac::EncoderFdkAac(EncoderCallback* pCallback)
              << QStringLiteral("libfdk-aac.so.2");
 
     QStringList errorMessages;
-    for (const auto& libname : qAsConst(libnames)) {
+    for (const auto& libname : std::as_const(libnames)) {
         m_pLibrary = std::make_unique<QLibrary>(libname, 2);
         if (m_pLibrary->load()) {
             kLogger.debug() << "Successfully loaded encoder library" << m_pLibrary->fileName();
@@ -107,7 +105,7 @@ EncoderFdkAac::EncoderFdkAac(EncoderCallback* pCallback)
     }
 
     if (!m_pLibrary || !m_pLibrary->isLoaded()) {
-        for (const auto& errorMessage : qAsConst(errorMessages)) {
+        for (const auto& errorMessage : std::as_const(errorMessages)) {
             kLogger.warning() << "Failed to load AAC encoder library:" << errorMessage;
         }
         return;
@@ -134,12 +132,12 @@ EncoderFdkAac::EncoderFdkAac(EncoderCallback* pCallback)
         kLogger.warning() << "Failed to load AAC encoder library: Interface of"
                           << m_pLibrary->fileName() << "is not as expected";
 
-        kLogger.debug() << "aacEncGetLibInfo:" << aacEncGetLibInfo;
-        kLogger.debug() << "aacEncOpen:" << aacEncOpen;
-        kLogger.debug() << "aacEncClose:" << aacEncClose;
-        kLogger.debug() << "aacEncEncode:" << aacEncEncode;
-        kLogger.debug() << "aacEncInfo:" << aacEncInfo;
-        kLogger.debug() << "aacEncoder_SetParam:" << aacEncoder_SetParam;
+        kLogger.debug() << "aacEncGetLibInfo:" << reinterpret_cast<void*>(aacEncGetLibInfo);
+        kLogger.debug() << "aacEncOpen:" << reinterpret_cast<void*>(aacEncOpen);
+        kLogger.debug() << "aacEncClose:" << reinterpret_cast<void*>(aacEncClose);
+        kLogger.debug() << "aacEncEncode:" << reinterpret_cast<void*>(aacEncEncode);
+        kLogger.debug() << "aacEncInfo:" << reinterpret_cast<void*>(aacEncInfo);
+        kLogger.debug() << "aacEncoder_SetParam:" << reinterpret_cast<void*>(aacEncoder_SetParam);
         return;
     }
 
@@ -165,8 +163,6 @@ EncoderFdkAac::~EncoderFdkAac() {
         kLogger.debug() << "Unloaded libfdk-aac";
     }
 
-    delete[] m_pAacDataBuffer;
-    delete[] m_pFifoChunkBuffer;
     delete m_pInputFifo;
 }
 
@@ -184,7 +180,7 @@ QString EncoderFdkAac::buttWindowsFdkAac() {
 
     // Try to find a butt installation in one of the
     // potential paths above
-    for (const auto& topPath : qAsConst(searchPaths)) {
+    for (const auto& topPath : std::as_const(searchPaths)) {
         QDir folder(topPath);
         if (!folder.exists()) {
             continue;
@@ -192,13 +188,12 @@ QString EncoderFdkAac::buttWindowsFdkAac() {
 
         // Typical name for a butt installation folder
         // is "butt-x.x.x" so list subfolders beginning with "butt"
-        QStringList nameFilters("butt*");
-        QStringList subfolders =
-                folder.entryList(nameFilters, QDir::Dirs, QDir::Name);
+        const QStringList subfolders =
+                folder.entryList(QStringList{"butt*"}, QDir::Dirs, QDir::Name);
 
         // If a butt installation is found, try
         // to find libfdk-aac in it
-        for (const auto& subName : qAsConst(subfolders)) {
+        for (const auto& subName : subfolders) {
             if (!folder.cd(subName)) {
                 continue;
             }
@@ -252,8 +247,8 @@ void EncoderFdkAac::setEncoderSettings(const EncoderSettings& settings) {
     }
 }
 
-int EncoderFdkAac::initEncoder(int samplerate, QString* pUserErrorMessage) {
-    m_samplerate = samplerate;
+int EncoderFdkAac::initEncoder(mixxx::audio::SampleRate sampleRate, QString* pUserErrorMessage) {
+    m_sampleRate = sampleRate;
 
     if (!m_pLibrary) {
         kLogger.warning() << "initEncoder failed: fdk-aac library not loaded";
@@ -284,11 +279,7 @@ int EncoderFdkAac::initEncoder(int samplerate, QString* pUserErrorMessage) {
     // This initializes the encoder handle but not the encoder itself.
     // Actual encoder init is done below.
     aacEncOpen(&m_aacEnc, 0, m_channels);
-    VERIFY_OR_DEBUG_ASSERT(!m_pAacDataBuffer) {
-        delete[] m_pAacDataBuffer;
-        m_pAacDataBuffer = nullptr;
-    }
-    m_pAacDataBuffer = new unsigned char[kOutBufferBits * m_channels]();
+    m_pAacDataBuffer.resize(kOutBufferBits * m_channels);
 
     // AAC Object Type: specifies "mode": AAC-LC, HE-AAC, HE-AACv2, DAB AAC, etc...
     if (aacEncoder_SetParam(m_aacEnc, AACENC_AOT, m_aacAot) != AACENC_OK) {
@@ -297,7 +288,7 @@ int EncoderFdkAac::initEncoder(int samplerate, QString* pUserErrorMessage) {
     }
 
     // Input audio samplerate
-    if (aacEncoder_SetParam(m_aacEnc, AACENC_SAMPLERATE, m_samplerate) != AACENC_OK) {
+    if (aacEncoder_SetParam(m_aacEnc, AACENC_SAMPLERATE, m_sampleRate) != AACENC_OK) {
         kLogger.warning() << "aac encoder setting samplerate failed!";
         return -1;
     }
@@ -356,11 +347,7 @@ int EncoderFdkAac::initEncoder(int samplerate, QString* pUserErrorMessage) {
     }
     m_pInputFifo = new FIFO<SAMPLE>(EngineSideChain::SIDECHAIN_BUFFER_SIZE * 2);
 
-    VERIFY_OR_DEBUG_ASSERT(!m_pFifoChunkBuffer) {
-        delete[] m_pFifoChunkBuffer;
-        m_pFifoChunkBuffer = nullptr;
-    }
-    m_pFifoChunkBuffer = new SAMPLE[m_readRequired * sizeof(SAMPLE)]();
+    m_pFifoChunkBuffer.resize(m_readRequired * sizeof(SAMPLE));
     return 0;
 }
 
@@ -395,12 +382,12 @@ void EncoderFdkAac::encodeBuffer(const CSAMPLE* samples, const int sampleCount)
 }
 
 void EncoderFdkAac::processFIFO() {
-    if (!m_pInputFifo || !m_pFifoChunkBuffer) {
+    if (!m_pInputFifo || m_pFifoChunkBuffer.empty()) {
         return;
     }
 
     while (m_pInputFifo->readAvailable() >= m_readRequired) {
-        m_pInputFifo->read(m_pFifoChunkBuffer, m_readRequired);
+        m_pInputFifo->read(m_pFifoChunkBuffer.data(), m_readRequired);
 
         // fdk-aac only accept pointers for most buffer settings.
         // Declare settings here and point to them below.
@@ -415,7 +402,8 @@ void EncoderFdkAac::processFIFO() {
         // Input Buffer
         AACENC_BufDesc inputBuf;
         inputBuf.numBufs = 1;
-        inputBuf.bufs = (void**)&m_pFifoChunkBuffer;
+        void* chunkBuffer[] = {m_pFifoChunkBuffer.data()};
+        inputBuf.bufs = chunkBuffer;
         inputBuf.bufSizes = &inDataSize;
         inputBuf.bufElSizes = &inSampleSize;
         inputBuf.bufferIdentifiers = &inDataDescription;
@@ -427,7 +415,8 @@ void EncoderFdkAac::processFIFO() {
         // Output (result) Buffer
         AACENC_BufDesc outputBuf;
         outputBuf.numBufs = 1;
-        outputBuf.bufs = (void**)&m_pAacDataBuffer;
+        void* dataBuffer[] = {m_pAacDataBuffer.data()};
+        outputBuf.bufs = dataBuffer;
         outputBuf.bufSizes = &outDataSize;
         outputBuf.bufElSizes = &outElemSize;
         outputBuf.bufferIdentifiers = &outDataDescription;
@@ -446,7 +435,7 @@ void EncoderFdkAac::processFIFO() {
             kLogger.warning() << "encoder ignored" << sampleDiff << "samples!";
         }
 
-        m_pCallback->write(nullptr, m_pAacDataBuffer, 0, outputDesc.numOutBytes);
+        m_pCallback->write(nullptr, m_pAacDataBuffer.data(), 0, outputDesc.numOutBytes);
     }
 }
 
