@@ -12,15 +12,6 @@
 
 namespace {
 
-// TODO: Convert these doubles to a standard enum
-// and convert elseif logic to switch statements
-constexpr double CUE_MODE_MIXXX = 0.0;
-constexpr double CUE_MODE_PIONEER = 1.0;
-constexpr double CUE_MODE_DENON = 2.0;
-constexpr double CUE_MODE_NUMARK = 3.0;
-constexpr double CUE_MODE_MIXXX_NO_BLINK = 4.0;
-constexpr double CUE_MODE_CUP = 5.0;
-
 /// This is the position of a fresh loaded tack without any seek
 constexpr int kNoHotCueNumber = 0;
 /// Used for a common tracking of the previewing Hotcue in m_currentlyPreviewingIndex
@@ -99,9 +90,6 @@ CueControl::CueControl(const QString& group,
           m_iNumHotCues(NUM_HOT_CUES),
           m_pCurrentSavedLoopControl(nullptr),
           m_trackMutex(QT_RECURSIVE_MUTEX_INIT) {
-    // To silence a compiler warning about CUE_MODE_PIONEER.
-    Q_UNUSED(CUE_MODE_PIONEER);
-
     createControls();
     connectControls();
 
@@ -119,10 +107,14 @@ CueControl::CueControl(const QString& group,
     m_pBeatLoopActivate = make_parented<ControlProxy>(group, "beatloop_activate", this);
     m_pBeatLoopSize = make_parented<ControlProxy>(group, "beatloop_size", this);
 
-    m_pCuePoint = new ControlObject(ConfigKey(group, "cue_point"));
+    m_pCuePoint = std::make_unique<ControlObject>(ConfigKey(group, "cue_point"));
     m_pCuePoint->set(Cue::kNoPosition);
 
-    m_pCueMode = new ControlObject(ConfigKey(group, "cue_mode"));
+    m_pCueMode = std::make_unique<ControlObject>(ConfigKey(group, "cue_mode"));
+    connect(m_pCueMode.get(),
+            &ControlObject::valueChanged,
+            this,
+            &CueControl::slotCueModeChanged);
 
     m_pPassthrough = make_parented<ControlProxy>(group, "passthrough", this);
     m_pPassthrough->connectValueChanged(this,
@@ -131,8 +123,6 @@ CueControl::CueControl(const QString& group,
 }
 
 CueControl::~CueControl() {
-    delete m_pCuePoint;
-    delete m_pCueMode;
     qDeleteAll(m_hotcueControls);
 }
 
@@ -606,6 +596,16 @@ void CueControl::seekOnLoad(mixxx::audio::FramePos seekOnLoadPosition) {
     m_usedSeekOnLoadPosition.setValue(seekOnLoadPosition);
 }
 
+void CueControl::slotCueModeChanged(double) {
+    // This will call updateIndicatorsAndModifyPlay() with the current play state
+    // and update cue/play indicators.
+    // This is required for updating the indicators when the cue mode was changed
+    // while the deck is paused.
+    if (m_pPlay && !m_pPlay->toBool()) {
+        getEngineBuffer()->verifyPlay();
+    }
+}
+
 void CueControl::cueUpdated() {
     //auto lock = lockMutex(&m_mutex);
     // We should get a trackCuesUpdated call anyway, so do nothing.
@@ -839,7 +839,7 @@ mixxx::RgbColor CueControl::colorFromConfig(const ConfigKey& configKey) {
 };
 
 void CueControl::hotcueSet(HotcueControl* pControl, double value, HotcueSetMode mode) {
-    //qDebug() << "CueControl::hotcueSet" << value;
+    // qDebug() << "CueControl::hotcueSet" << value;
 
     if (value <= 0) {
         return;
@@ -1108,7 +1108,7 @@ void CueControl::hotcueCueLoop(HotcueControl* pControl, double value) {
 }
 
 void CueControl::hotcueActivate(HotcueControl* pControl, double value, HotcueSetMode mode) {
-    //qDebug() << "CueControl::hotcueActivate" << value;
+    // qDebug() << "CueControl::hotcueActivate" << value;
 
     CuePointer pCue = pControl->getCue();
     if (value > 0) {
@@ -1559,23 +1559,26 @@ void CueControl::cuePlay(double value) {
 }
 
 void CueControl::cueDefault(double v) {
-    double cueMode = m_pCueMode->get();
     // Decide which cue implementation to call based on the user preference
-    if (cueMode == CUE_MODE_DENON || cueMode == CUE_MODE_NUMARK) {
+    CueMode cueMode = static_cast<CueMode>(static_cast<int>(m_pCueMode->get()));
+    switch (cueMode) {
+    case CueMode::Denon:
+    case CueMode::Numark:
         cueDenon(v);
-    } else if (cueMode == CUE_MODE_CUP) {
+        break;
+    case CueMode::CueAndPlay:
         cuePlay(v);
-    } else {
-        // The modes CUE_MODE_PIONEER and CUE_MODE_MIXXX are similar
-        // are handled inside cueCDJ(v)
-        // default to Pioneer mode
+        break;
+    default:
+        // The modes Pioneer, Mixxx and MixxxNoBlinking are similar,
+        // all are handled by cueCDJ()
         cueCDJ(v);
     }
 }
 
 void CueControl::pause(double v) {
     auto lock = lockMutex(&m_trackMutex);
-    //qDebug() << "CueControl::pause()" << v;
+    // qDebug() << "CueControl::pause()" << v;
     if (v > 0.0) {
         m_pPlay->set(0.0);
     }
@@ -1583,7 +1586,7 @@ void CueControl::pause(double v) {
 
 void CueControl::playStutter(double v) {
     auto lock = lockMutex(&m_trackMutex);
-    //qDebug() << "playStutter" << v;
+    // qDebug() << "playStutter" << v;
     if (v > 0.0) {
         if (m_pPlay->toBool()) {
             if (m_currentlyPreviewingIndex != Cue::kNoHotCue) {
@@ -2011,8 +2014,8 @@ void CueControl::outroEndActivate(double value) {
 // This is also called from the engine thread. No locking allowed.
 bool CueControl::updateIndicatorsAndModifyPlay(
         bool newPlay, bool oldPlay, bool playPossible) {
-    //qDebug() << "updateIndicatorsAndModifyPlay" << newPlay << playPossible
-    //        << m_iCurrentlyPreviewingHotcues << m_bPreviewing;
+    // qDebug() << "updateIndicatorsAndModifyPlay" << newPlay << playPossible
+    //        << m_currentlyPreviewingIndex;
     CueMode cueMode = static_cast<CueMode>(static_cast<int>(m_pCueMode->get()));
     if ((cueMode == CueMode::Denon || cueMode == CueMode::Numark) &&
             newPlay && !oldPlay && playPossible &&
@@ -2052,6 +2055,7 @@ bool CueControl::updateIndicatorsAndModifyPlay(
 
     TrackAt trackAt = getTrackAt();
 
+    // Set play_indicator
     if (!playPossible) {
         // play not possible
         newPlay = false;
@@ -2067,7 +2071,8 @@ bool CueControl::updateIndicatorsAndModifyPlay(
         // Pause:
         m_pStopButton->set(1.0);
         m_pPlayLatched->forceSet(0.0);
-        if (cueMode == CueMode::Denon) {
+        switch (cueMode) {
+        case CueMode::Denon:
             if (trackAt == TrackAt::Cue || previewing) {
                 m_pPlayIndicator->setBlinkValue(ControlIndicator::OFF);
             } else {
@@ -2075,27 +2080,38 @@ bool CueControl::updateIndicatorsAndModifyPlay(
                 m_pPlayIndicator->setBlinkValue(
                         ControlIndicator::RATIO1TO1_500MS);
             }
-        } else if (cueMode == CueMode::Mixxx ||
-                cueMode == CueMode::MixxxNoBlinking ||
-                cueMode == CueMode::Numark) {
+            break;
+        case CueMode::Mixxx:
+        case CueMode::MixxxNoBlinking:
+        case CueMode::Numark:
             m_pPlayIndicator->setBlinkValue(ControlIndicator::OFF);
-        } else {
-            // Flashing indicates that play is possible in Pioneer mode
+            break;
+        default:
+            // Flashing indicates that play is possible in Pioneer and CueAndPlay mode
             m_pPlayIndicator->setBlinkValue(ControlIndicator::RATIO1TO1_500MS);
         }
     }
 
-    if (cueMode != CueMode::Denon && cueMode != CueMode::Numark) {
+    // Set cue_indicator
+    switch (cueMode) {
+    case CueMode::Denon:
+    case CueMode::Numark:
+        break;
+    default:
         if (m_pCuePoint->get() != Cue::kNoPosition) {
             if (newPlay == 0.0 && trackAt == TrackAt::ElseWhere) {
-                if (cueMode == CueMode::Mixxx) {
+                switch (cueMode) {
+                case CueMode::MixxxNoBlinking:
+                    m_pCueIndicator->setBlinkValue(ControlIndicator::OFF);
+                    break;
+                case CueMode::Mixxx:
                     // in Mixxx mode Cue Button is flashing slow if CUE will move Cue point
                     m_pCueIndicator->setBlinkValue(
                             ControlIndicator::RATIO1TO1_500MS);
-                } else if (cueMode == CueMode::MixxxNoBlinking) {
-                    m_pCueIndicator->setBlinkValue(ControlIndicator::OFF);
-                } else {
-                    // in Pioneer mode Cue Button is flashing fast if CUE will move Cue point
+                    break;
+                default:
+                    // in Pioneer and CueAndPlay mode Cue Button is flashing fast
+                    // if CUE will move Cue point
                     m_pCueIndicator->setBlinkValue(
                             ControlIndicator::RATIO1TO1_250MS);
                 }
@@ -2106,6 +2122,7 @@ bool CueControl::updateIndicatorsAndModifyPlay(
             m_pCueIndicator->setBlinkValue(ControlIndicator::OFF);
         }
     }
+
     m_pPlayStutter->set(newPlay ? 1.0 : 0.0);
 
     return newPlay;
@@ -2114,10 +2131,11 @@ bool CueControl::updateIndicatorsAndModifyPlay(
 // called from the engine thread
 void CueControl::updateIndicators() {
     // No need for mutex lock because we are only touching COs.
-    double cueMode = m_pCueMode->get();
     TrackAt trackAt = getTrackAt();
-
-    if (cueMode == CUE_MODE_DENON || cueMode == CUE_MODE_NUMARK) {
+    CueMode cueMode = static_cast<CueMode>(static_cast<int>(m_pCueMode->get()));
+    switch (cueMode) {
+    case CueMode::Denon:
+    case CueMode::Numark: {
         // Cue button is only lit at cue point
         bool playing = m_pPlay->toBool();
         if (trackAt == TrackAt::Cue) {
@@ -2129,18 +2147,20 @@ void CueControl::updateIndicators() {
         } else {
             m_pCueIndicator->setBlinkValue(ControlIndicator::OFF);
             if (!playing) {
-                if (trackAt != TrackAt::End && cueMode != CUE_MODE_NUMARK) {
+                if (trackAt != TrackAt::End && cueMode == CueMode::Denon) {
                     // Play will move cue point
                     m_pPlayIndicator->setBlinkValue(
                             ControlIndicator::RATIO1TO1_500MS);
                 } else {
-                    // At track end
+                    // At track end or elsewhere, both Denon and Numark mode
                     m_pPlayIndicator->setBlinkValue(ControlIndicator::OFF);
                 }
             }
         }
-    } else {
-        // Here we have CUE_MODE_PIONEER or CUE_MODE_MIXXX
+        break;
+    }
+    default:
+        // Here we have Pioneer, Mixxx, MixxxNoBlinking or CueAndPlay.
         // default to Pioneer mode
         if (m_currentlyPreviewingIndex != kMainCueIndex) {
             const auto freely_playing =
@@ -2148,14 +2168,18 @@ void CueControl::updateIndicators() {
             if (!freely_playing) {
                 switch (trackAt) {
                 case TrackAt::ElseWhere:
-                    if (cueMode == CUE_MODE_MIXXX) {
+                    switch (cueMode) {
+                    case CueMode::Mixxx:
                         // in Mixxx mode Cue Button is flashing slow if CUE will move Cue point
                         m_pCueIndicator->setBlinkValue(
                                 ControlIndicator::RATIO1TO1_500MS);
-                    } else if (cueMode == CUE_MODE_MIXXX_NO_BLINK) {
+                        break;
+                    case CueMode::MixxxNoBlinking:
                         m_pCueIndicator->setBlinkValue(ControlIndicator::OFF);
-                    } else {
-                        // in Pioneer mode Cue Button is flashing fast if CUE will move Cue point
+                        break;
+                    default:
+                        // in Pioneer and CueAndPlay mode Cue button is flashing fast
+                        // if CUE will move Cue point
                         m_pCueIndicator->setBlinkValue(
                                 ControlIndicator::RATIO1TO1_250MS);
                     }
