@@ -12,6 +12,7 @@
 #include "preferences/usersettings.h"
 #include "track/track.h"
 #include "util/compatibility/qatomic.h"
+#include "util/make_const_iterator.h"
 #include "util/math.h"
 
 namespace {
@@ -54,11 +55,9 @@ LoopingControl::LoopingControl(const QString& group,
           m_bAdjustingLoopOut(false),
           m_bAdjustingLoopInOld(false),
           m_bAdjustingLoopOutOld(false),
-          m_bLoopOutPressedWhileLoopDisabled(false) {
-    m_oldLoopInfo = {mixxx::audio::kInvalidFramePos,
-            mixxx::audio::kInvalidFramePos,
-            LoopSeekMode::MovedOut};
-    m_loopInfo.setValue(m_oldLoopInfo);
+          m_bLoopOutPressedWhileLoopDisabled(false),
+          m_prevLoopSize(-1),
+          m_trueTrackBeats(false) {
     m_currentPosition.setValue(mixxx::audio::kStartFramePos);
     m_pActiveBeatLoop = nullptr;
     m_pRateControl = nullptr;
@@ -135,6 +134,10 @@ LoopingControl::LoopingControl(const QString& group,
             this,
             [this](double value) { slotBeatLoop(value); },
             Qt::DirectConnection);
+    m_pCOLoopAnchor = new ControlPushButton(ConfigKey(group, "loop_anchor"),
+            true,
+            static_cast<double>(LoopAnchorPoint::Start));
+    m_pCOLoopAnchor->setButtonMode(ControlPushButton::TOGGLE);
 
     m_pCOBeatLoopSize = new ControlObject(ConfigKey(group, "beatloop_size"),
                                           true, false, false, 4.0);
@@ -268,6 +271,7 @@ LoopingControl::~LoopingControl() {
         delete pBeatLoop;
     }
     delete m_pCOBeatLoopSize;
+    delete m_pCOLoopAnchor;
     delete m_pCOBeatLoopActivate;
     delete m_pCOBeatLoopRollActivate;
 
@@ -417,7 +421,7 @@ mixxx::audio::FramePos LoopingControl::nextTrigger(bool reverse,
         // When the LoopIn button is released in reverse mode we jump to the end of the loop to not fall out and disable the active loop
         // This must not happen in quantized mode. The newly set start is always ahead (in time, but behind spacially) of the current position so we don't jump.
         // Jumping to the end is then handled when the loop's start is reached later in this function.
-        if (reverse && !m_bAdjustingLoopIn && !m_pQuantizeEnabled->toBool()) {
+        if (reverse && !m_bAdjustingLoopIn && !(quantizeEnabledAndHasTrueTrackBeats())) {
             m_oldLoopInfo = loopInfo;
             *pTargetPosition = loopInfo.endPosition;
             return currentPosition;
@@ -431,7 +435,8 @@ mixxx::audio::FramePos LoopingControl::nextTrigger(bool reverse,
         // When the LoopOut button is released in forward mode we jump to the start of the loop to not fall out and disable the active loop
         // This must not happen in quantized mode. The newly set end is always ahead of the current position so we don't jump.
         // Jumping to the start is then handled when the loop's end is reached later in this function.
-        if (!reverse && !m_bAdjustingLoopOut && !m_pQuantizeEnabled->toBool()) {
+        if (!reverse && !m_bAdjustingLoopOut &&
+                !(quantizeEnabledAndHasTrueTrackBeats())) {
             m_oldLoopInfo = loopInfo;
             *pTargetPosition = loopInfo.startPosition;
             return currentPosition;
@@ -573,6 +578,23 @@ void LoopingControl::hintReader(gsl::not_null<HintVector*> pHintList) {
             loop_hint.frameCount = Hint::kFrameCountForward;
             pHintList->append(loop_hint);
         }
+        // We anticipate a potential loop being set from its end point
+        mixxx::BeatsPointer pBeats = m_pBeats;
+        if (!pBeats) {
+            return;
+        }
+        double beats = m_pCOBeatLoopSize->get();
+        bool quantize = m_pQuantizeEnabled->toBool();
+        auto currentPosition = !quantize
+                ? m_currentPosition.getValue()
+                : findQuantizedBeatloopStart(
+                          pBeats, m_currentPosition.getValue(), beats);
+        loop_hint.type = Hint::Type::LoopStart;
+        loop_hint.frame = static_cast<SINT>(
+                pBeats->findNBeatsFromPosition(currentPosition, -beats)
+                        .toLowerFrameBoundary()
+                        .value());
+        loop_hint.frameCount = Hint::kFrameCountForward;
     }
 }
 
@@ -696,7 +718,7 @@ void LoopingControl::setLoopInToCurrentPosition() {
     // silence of the last buffer. This position might be not reachable in
     // a future runs, depending on the buffering.
     mixxx::audio::FramePos position = math_min(info.currentPosition, info.trackEndPosition);
-    if (m_pQuantizeEnabled->toBool() && pBeats) {
+    if (quantizeEnabledAndHasTrueTrackBeats()) {
         mixxx::audio::FramePos prevBeatPosition;
         mixxx::audio::FramePos nextBeatPosition;
         if (pBeats->findPrevNextBeats(position, &prevBeatPosition, &nextBeatPosition, false)) {
@@ -761,9 +783,10 @@ void LoopingControl::setLoopInToCurrentPosition() {
         loopInfo.seekMode = LoopSeekMode::MovedOut;
     }
 
-    if (m_pQuantizeEnabled->toBool() && loopInfo.startPosition.isValid() &&
+    if (quantizeEnabledAndHasTrueTrackBeats() &&
+            loopInfo.startPosition.isValid() &&
             loopInfo.endPosition.isValid() &&
-            loopInfo.startPosition < loopInfo.endPosition && pBeats) {
+            loopInfo.startPosition < loopInfo.endPosition) {
         m_pCOBeatLoopSize->setAndConfirm(pBeats->numBeatsInRange(
                 loopInfo.startPosition, loopInfo.endPosition));
         updateBeatLoopingControls();
@@ -778,14 +801,7 @@ void LoopingControl::setLoopInToCurrentPosition() {
 // Clear the last active loop while saved loop (cue + info) remains untouched
 void LoopingControl::slotLoopRemove() {
     setLoopingEnabled(false);
-    LoopInfo loopInfo = m_loopInfo.getValue();
-    loopInfo.startPosition = mixxx::audio::kInvalidFramePos;
-    loopInfo.endPosition = mixxx::audio::kInvalidFramePos;
-    loopInfo.seekMode = LoopSeekMode::None;
-    m_loopInfo.setValue(loopInfo);
-    m_oldLoopInfo = loopInfo;
-    m_pCOLoopStartPosition->set(loopInfo.startPosition.toEngineSamplePosMaybeInvalid());
-    m_pCOLoopEndPosition->set(loopInfo.endPosition.toEngineSamplePosMaybeInvalid());
+    clearLoopInfoAndControls();
     // The loop cue is stored by BaseTrackPlayerImpl::unloadTrack()
     // if the loop is valid, else it is removed.
     // We remove it here right away so the loop is not restored
@@ -803,6 +819,14 @@ void LoopingControl::slotLoopRemove() {
     }
 }
 
+void LoopingControl::clearLoopInfoAndControls() {
+    LoopInfo loopInfo;
+    m_loopInfo.setValue(loopInfo);
+    m_oldLoopInfo = loopInfo;
+    m_pCOLoopStartPosition->set(loopInfo.startPosition.toEngineSamplePosMaybeInvalid());
+    m_pCOLoopEndPosition->set(loopInfo.endPosition.toEngineSamplePosMaybeInvalid());
+}
+
 void LoopingControl::slotLoopIn(double pressed) {
     if (!m_pTrack) {
         return;
@@ -854,7 +878,7 @@ void LoopingControl::setLoopOutToCurrentPosition() {
     // silence of the last buffer. This position might be not reachable in
     // a future runs, depending on the buffering.
     mixxx::audio::FramePos position = math_min(info.currentPosition, info.trackEndPosition);
-    if (m_pQuantizeEnabled->toBool() && pBeats) {
+    if (quantizeEnabledAndHasTrueTrackBeats()) {
         mixxx::audio::FramePos prevBeatPosition;
         mixxx::audio::FramePos nextBeatPosition;
         if (pBeats->findPrevNextBeats(position, &prevBeatPosition, &nextBeatPosition, false)) {
@@ -930,7 +954,7 @@ void LoopingControl::setLoopOutToCurrentPosition() {
         loopInfo.seekMode = LoopSeekMode::MovedOut;
     }
 
-    if (m_pQuantizeEnabled->toBool() && pBeats) {
+    if (quantizeEnabledAndHasTrueTrackBeats()) {
         m_pCOBeatLoopSize->setAndConfirm(pBeats->numBeatsInRange(
                 loopInfo.startPosition, loopInfo.endPosition));
         updateBeatLoopingControls();
@@ -1228,20 +1252,30 @@ void LoopingControl::trackLoaded(TrackPointer pNewTrack) {
 
 void LoopingControl::trackBeatsUpdated(mixxx::BeatsPointer pBeats) {
     clearActiveBeatLoop();
-    m_pBeats = pBeats;
-    if (m_pBeats) {
-        LoopInfo loopInfo = m_loopInfo.getValue();
-        if (loopInfo.startPosition.isValid() && loopInfo.endPosition.isValid()) {
-            double loaded_loop_size = findBeatloopSizeForLoop(
-                    loopInfo.startPosition, loopInfo.endPosition);
-            if (loaded_loop_size != -1) {
-                m_pCOBeatLoopSize->setAndConfirm(loaded_loop_size);
-            }
+    if (pBeats) {
+        m_pBeats = pBeats;
+        m_trueTrackBeats = true;
+    } else if (m_pTrack) {
+        // no beats, use fake beats so we can use seconds as beat unit
+        m_pBeats = getFake60BpmBeats();
+        m_trueTrackBeats = false;
+    } else {
+        // no track, no beats
+        m_pBeats = pBeats;
+        m_trueTrackBeats = false;
+    }
+    LoopInfo loopInfo = m_loopInfo.getValue();
+    if (loopInfo.startPosition.isValid() && loopInfo.endPosition.isValid()) {
+        double loaded_loop_size = findBeatloopSizeForLoop(
+                loopInfo.startPosition, loopInfo.endPosition);
+        if (loaded_loop_size != -1) {
+            m_pCOBeatLoopSize->setAndConfirm(loaded_loop_size);
         }
     }
 }
 
-void LoopingControl::slotBeatLoopActivate(BeatLoopingControl* pBeatLoopControl) {
+void LoopingControl::slotBeatLoopActivate(
+        BeatLoopingControl* pBeatLoopControl, LoopAnchorPoint forcedAnchor) {
     if (!m_pTrack) {
         return;
     }
@@ -1250,17 +1284,20 @@ void LoopingControl::slotBeatLoopActivate(BeatLoopingControl* pBeatLoopControl)
     // looping. slotBeatLoop will update m_pActiveBeatLoop if applicable. Note,
     // this used to only maintain the current start point if a beatloop was
     // enabled. See Issue #6957.
-    slotBeatLoop(pBeatLoopControl->getSize(), m_bLoopingEnabled, true);
+    slotBeatLoop(pBeatLoopControl->getSize(), m_bLoopingEnabled, true, forcedAnchor);
 }
 
-void LoopingControl::slotBeatLoopActivateRoll(BeatLoopingControl* pBeatLoopControl) {
-     if (!m_pTrack) {
-         return;
-     }
+void LoopingControl::slotBeatLoopActivateRoll(
+        BeatLoopingControl* pBeatLoopControl, LoopAnchorPoint forcedAnchor) {
+    if (!m_pTrack) {
+        return;
+    }
+
+    storeLoopInfo();
 
     // Disregard existing loops (except beatlooprolls).
     m_pSlipEnabled->set(1);
-    slotBeatLoop(pBeatLoopControl->getSize(), m_bLoopRollActive, true);
+    slotBeatLoop(pBeatLoopControl->getSize(), m_bLoopRollActive, true, forcedAnchor);
     m_bLoopRollActive = true;
     m_activeLoopRolls.push(pBeatLoopControl->getSize());
 }
@@ -1277,10 +1314,10 @@ void LoopingControl::slotBeatLoopDeactivateRoll(BeatLoopingControl* pBeatLoopCon
     // and QVector::iterator is a pointer type in Qt5, but QStack inherits
     // from QList in Qt6 so QStack::iterator is not a pointer type in Qt6.
     // NOLINTNEXTLINE(readability-qualified-auto)
-    auto i = m_activeLoopRolls.begin();
-    while (i != m_activeLoopRolls.end()) {
+    auto i = m_activeLoopRolls.constBegin();
+    while (i != m_activeLoopRolls.constEnd()) {
         if (size == *i) {
-            i = m_activeLoopRolls.erase(i);
+            i = constErase(&m_activeLoopRolls, i);
         } else {
             ++i;
         }
@@ -1295,8 +1332,50 @@ void LoopingControl::slotBeatLoopDeactivateRoll(BeatLoopingControl* pBeatLoopCon
     }
 
     // Return to the previous beatlooproll if necessary.
+    // Else previous regular beatloop if no rolling loops are active.
     if (!m_activeLoopRolls.empty()) {
         slotBeatLoop(m_activeLoopRolls.top(), m_bLoopRollActive, true);
+    } else {
+        restoreLoopInfo();
+    }
+}
+
+void LoopingControl::storeLoopInfo() {
+    if (m_bLoopRollActive || !m_activeLoopRolls.empty()) {
+        return;
+    }
+
+    LoopInfo loopInfo = m_loopInfo.getValue();
+    if (loopInfo.startPosition.isValid() && loopInfo.endPosition.isValid()) {
+        m_prevLoopInfo.setValue(loopInfo);
+    } else {
+        // If we don't have a valid loop, yet, we store the current beatloop size.
+        // This way this (default) value is available again for `beatloop_activate`
+        // after disaling the (last) rolling loop.
+        // Explicitly clear the last saved loop.
+        m_prevLoopInfo.setValue(LoopInfo{});
+        m_prevLoopSize = m_pCOBeatLoopSize->get();
+    }
+}
+
+void LoopingControl::restoreLoopInfo() {
+    if (m_bLoopRollActive || !m_activeLoopRolls.empty()) {
+        return;
+    }
+
+    LoopInfo prevLoopInfo = m_prevLoopInfo.getValue();
+    if (prevLoopInfo.startPosition.isValid() && prevLoopInfo.endPosition.isValid()) {
+        setLoop(prevLoopInfo.startPosition, prevLoopInfo.endPosition, false);
+        m_prevLoopInfo.setValue(LoopInfo{});
+    } else {
+        // This may happen when there was no loop set when we activated the
+        // rolling loop that triggered storeLoopInfo(). Re-apply the loop size
+        // we stored.
+        clearLoopInfoAndControls();
+        double prevLoopSize = m_prevLoopSize;
+        if (prevLoopSize > 0) {
+            m_pCOBeatLoopSize->setAndConfirm(m_prevLoopSize);
+        }
     }
 }
 
@@ -1324,6 +1403,10 @@ bool LoopingControl::currentLoopMatchesBeatloopSize(const LoopInfo& loopInfo) co
     return positionNear(loopInfo.endPosition, loopEndPosition);
 }
 
+bool LoopingControl::quantizeEnabledAndHasTrueTrackBeats() const {
+    return m_pQuantizeEnabled->toBool() && m_trueTrackBeats;
+}
+
 double LoopingControl::findBeatloopSizeForLoop(
         mixxx::audio::FramePos startPosition,
         mixxx::audio::FramePos endPosition) const {
@@ -1407,9 +1490,12 @@ mixxx::audio::FramePos LoopingControl::findQuantizedBeatloopStart(
     return previousFractionBeatPosition + loopLength;
 }
 
-void LoopingControl::slotBeatLoop(double beats, bool keepStartPoint, bool enable) {
+void LoopingControl::slotBeatLoop(double beats,
+        bool keepSetPoint,
+        bool enable,
+        LoopAnchorPoint forcedAnchor) {
     // If this is a "new" loop, stop tracking saved loop changes
-    if (!keepStartPoint) {
+    if (!keepSetPoint) {
         emit loopReset();
     }
 
@@ -1441,6 +1527,9 @@ void LoopingControl::slotBeatLoop(double beats, bool keepStartPoint, bool enable
         return;
     }
 
+    const LoopAnchorPoint loopAnchor = forcedAnchor == LoopAnchorPoint::None
+            ? static_cast<LoopAnchorPoint>(m_pCOLoopAnchor->get())
+            : forcedAnchor;
     // Calculate the new loop start and end positions
     // give start and end defaults so we can detect problems
     LoopInfo newloopInfo = {mixxx::audio::kInvalidFramePos,
@@ -1450,12 +1539,19 @@ void LoopingControl::slotBeatLoop(double beats, bool keepStartPoint, bool enable
     mixxx::audio::FramePos currentPosition = info.currentPosition;
     // Start from the current position/closest beat and
     // create the loop around X beats from there.
-    if (keepStartPoint) {
-        if (loopInfo.startPosition.isValid()) {
-            newloopInfo.startPosition = loopInfo.startPosition;
-        } else {
-            newloopInfo.startPosition =
-                    math_min(info.currentPosition, info.trackEndPosition);
+    if (keepSetPoint) {
+        switch (loopAnchor) {
+        case LoopAnchorPoint::None:
+        case LoopAnchorPoint::Start:
+            newloopInfo.startPosition = loopInfo.startPosition.isValid()
+                    ? loopInfo.startPosition
+                    : math_min(info.currentPosition, info.trackEndPosition);
+            break;
+        case LoopAnchorPoint::End:
+            newloopInfo.endPosition = loopInfo.endPosition.isValid()
+                    ? loopInfo.endPosition
+                    : math_min(info.currentPosition, info.trackEndPosition);
+            break;
         }
     } else {
         // If running reverse, move the loop one loop size to the left.
@@ -1469,23 +1565,44 @@ void LoopingControl::slotBeatLoop(double beats, bool keepStartPoint, bool enable
             currentPosition = pBeats->findNBeatsFromPosition(currentPosition, -beats);
         }
 
-        if (!m_pQuantizeEnabled->toBool()) {
-            newloopInfo.startPosition = currentPosition;
-        } else {
-            // loop_in is set to the closest beat if quantize is on and the loop size is >= 1 beat.
-            // The closest beat might be ahead of play position and will cause a catching loop.
-            newloopInfo.startPosition = findQuantizedBeatloopStart(pBeats, currentPosition, beats);
+        bool quantize = quantizeEnabledAndHasTrueTrackBeats();
+        // loop_in is set to the closest beat if quantize is on and the loop size is >= 1 beat.
+        // The closest beat might be ahead of play position and will cause a catching loop.
+        switch (loopAnchor) {
+        case LoopAnchorPoint::None:
+        case LoopAnchorPoint::Start:
+            newloopInfo.startPosition = !quantize
+                    ? currentPosition
+                    : findQuantizedBeatloopStart(
+                              pBeats, currentPosition, beats);
+            break;
+        case LoopAnchorPoint::End:
+            newloopInfo.endPosition = !quantize
+                    ? currentPosition
+                    : findQuantizedBeatloopStart(
+                              pBeats, currentPosition, beats);
+            break;
         }
     }
 
-    newloopInfo.endPosition = pBeats->findNBeatsFromPosition(newloopInfo.startPosition, beats);
+    switch (loopAnchor) {
+    case LoopAnchorPoint::None:
+    case LoopAnchorPoint::Start:
+        newloopInfo.endPosition = pBeats->findNBeatsFromPosition(newloopInfo.startPosition, beats);
+        break;
+    case LoopAnchorPoint::End:
+        newloopInfo.startPosition = pBeats->findNBeatsFromPosition(newloopInfo.endPosition, -beats);
+        break;
+    }
 
     if (!newloopInfo.startPosition.isValid() ||
             !newloopInfo.endPosition.isValid() ||
             newloopInfo.startPosition >=
                     newloopInfo.endPosition // happens when the call above fails
-            || newloopInfo.endPosition >
-                    trackEndPosition) { // Do not allow beat loops to go beyond the end of the track
+            || (newloopInfo.endPosition > trackEndPosition &&
+                       (enable || m_bLoopingEnabled))) { // Do not allow beat
+                                                         // loops to go beyond
+                                                         // the end of the track
         // If a track is loaded with beatloop_size larger than
         // the distance between the loop in point and
         // the end of the track, let beatloop_size be set to
@@ -1522,16 +1639,35 @@ void LoopingControl::slotBeatLoop(double beats, bool keepStartPoint, bool enable
         return;
     }
 
-    // If the start point has changed, or the loop is not enabled,
-    // or if the endpoints are nearly the same, do not seek forward into the adjusted loop.
-    if (!keepStartPoint ||
-            !(enable || m_bLoopingEnabled) ||
-            (positionNear(newloopInfo.startPosition, loopInfo.startPosition) &&
-                    positionNear(newloopInfo.endPosition, loopInfo.endPosition))) {
-        newloopInfo.seekMode = LoopSeekMode::MovedOut;
-    } else {
-        newloopInfo.seekMode = LoopSeekMode::Changed;
+    switch (loopAnchor) {
+    case LoopAnchorPoint::None:
+    case LoopAnchorPoint::Start:
+        // If the start point has changed, or the loop is not enabled,
+        // or if the endpoints are nearly the same, do not seek forward into the adjusted loop.
+        if (!keepSetPoint ||
+                !(enable || m_bLoopingEnabled) ||
+                (positionNear(newloopInfo.startPosition, loopInfo.startPosition) &&
+                        positionNear(newloopInfo.endPosition, loopInfo.endPosition))) {
+            newloopInfo.seekMode = LoopSeekMode::MovedOut;
+        } else {
+            newloopInfo.seekMode = LoopSeekMode::Changed;
+        }
+        break;
+    case LoopAnchorPoint::End:
+        // If the end point is behind the current position and the loop is enabled, seek backward .
+        if (!(enable || m_bLoopingEnabled) || newloopInfo.endPosition > currentPosition) {
+            newloopInfo.seekMode = LoopSeekMode::MovedOut;
+        } else {
+            newloopInfo.seekMode = LoopSeekMode::Changed;
+            // If the loop is being enabled, flush the old loop status to force
+            // LoopingControl::nextTrigger to evaluate the LoopSeekMode
+            if (!m_bLoopingEnabled) {
+                m_oldLoopInfo = LoopInfo{};
+            }
+        }
+        break;
     }
+
     m_loopInfo.setValue(newloopInfo);
     emit loopUpdated(newloopInfo.startPosition, newloopInfo.endPosition);
     m_pCOLoopStartPosition->set(newloopInfo.startPosition.toEngineSamplePos());
@@ -1581,6 +1717,7 @@ void LoopingControl::slotBeatLoopRollActivate(double pressed) {
                 m_activeLoopRolls.clear();
             }
         } else {
+            storeLoopInfo();
             m_pSlipEnabled->set(1.0);
             slotBeatLoop(m_pCOBeatLoopSize->get());
             m_bLoopRollActive = true;
@@ -1594,6 +1731,7 @@ void LoopingControl::slotBeatLoopRollActivate(double pressed) {
             m_bLoopRollActive = false;
             m_activeLoopRolls.clear();
         }
+        restoreLoopInfo();
     }
 }
 
@@ -1873,46 +2011,79 @@ BeatLoopingControl::BeatLoopingControl(const QString& group, double size)
           m_bActive(false) {
     // This is the original beatloop control which is now deprecated. Its value
     // is the state of the beatloop control (1 for enabled, 0 for disabled).
-    m_pLegacy = new ControlPushButton(
+    m_pLegacy = std::make_unique<ControlPushButton>(
             keyForControl(group, "beatloop_%1", size));
     m_pLegacy->setButtonMode(ControlPushButton::TOGGLE);
-    connect(m_pLegacy, &ControlObject::valueChanged,
-            this, &BeatLoopingControl::slotLegacy,
+    connect(m_pLegacy.get(),
+            &ControlObject::valueChanged,
+            this,
+            &BeatLoopingControl::slotLegacy,
             Qt::DirectConnection);
     // A push-button which activates the beatloop.
-    m_pActivate = new ControlPushButton(
+    m_pActivate = std::make_unique<ControlPushButton>(
             keyForControl(group, "beatloop_%1_activate", size));
-    connect(m_pActivate, &ControlObject::valueChanged,
-            this, &BeatLoopingControl::slotActivate,
+    connect(
+            m_pActivate.get(),
+            &ControlObject::valueChanged,
+            this,
+            [this](double value) {
+                slotActivate(value, LoopingControl::LoopAnchorPoint::None);
+            },
+            Qt::DirectConnection);
+    // And the same but setting it from the end point instead of starting
+    m_pRActivate = std::make_unique<ControlPushButton>(
+            keyForControl(group, "beatloop_r%1_activate", size));
+    connect(m_pRActivate.get(),
+            &ControlObject::valueChanged,
+            this,
+            &BeatLoopingControl::slotReverseActivate,
             Qt::DirectConnection);
     // A push-button which toggles the beatloop as active or inactive.
-    m_pToggle = new ControlPushButton(
+    m_pToggle = std::make_unique<ControlPushButton>(
             keyForControl(group, "beatloop_%1_toggle", size));
-    connect(m_pToggle, &ControlObject::valueChanged,
-            this, &BeatLoopingControl::slotToggle,
+    connect(
+            m_pToggle.get(),
+            &ControlObject::valueChanged,
+            this,
+            [this](double value) {
+                slotToggle(value, LoopingControl::LoopAnchorPoint::None);
+            },
+            Qt::DirectConnection);
+    // And the same but setting it from the end point instead of starting
+    m_pRToggle = std::make_unique<ControlPushButton>(
+            keyForControl(group, "beatloop_r%1_toggle", size));
+    connect(m_pRToggle.get(),
+            &ControlObject::valueChanged,
+            this,
+            &BeatLoopingControl::slotReverseToggle,
             Qt::DirectConnection);
 
     // A push-button which activates rolling beatloops
-    m_pActivateRoll = new ControlPushButton(
+    m_pActivateRoll = std::make_unique<ControlPushButton>(
             keyForControl(group, "beatlooproll_%1_activate", size));
-    connect(m_pActivateRoll, &ControlObject::valueChanged,
-            this, &BeatLoopingControl::slotActivateRoll,
+    connect(
+            m_pActivateRoll.get(),
+            &ControlObject::valueChanged,
+            this,
+            [this](double value) {
+                slotActivateRoll(value, LoopingControl::LoopAnchorPoint::None);
+            },
+            Qt::DirectConnection);
+    // And the same but setting it from the end point instead of starting
+    m_pRActivateRoll = std::make_unique<ControlPushButton>(
+            keyForControl(group, "beatlooproll_r%1_activate", size));
+    connect(m_pRActivateRoll.get(),
+            &ControlObject::valueChanged,
+            this,
+            &BeatLoopingControl::slotReverseActivateRoll,
             Qt::DirectConnection);
 
     // An indicator control which is 1 if the beatloop is enabled and 0 if not.
-    m_pEnabled = new ControlObject(
+    m_pEnabled = std::make_unique<ControlObject>(
             keyForControl(group, "beatloop_%1_enabled", size));
     m_pEnabled->setReadOnly();
 }
 
-BeatLoopingControl::~BeatLoopingControl() {
-    delete m_pActivate;
-    delete m_pToggle;
-    delete m_pEnabled;
-    delete m_pLegacy;
-    delete m_pActivateRoll;
-}
-
 void BeatLoopingControl::deactivate() {
     if (m_bActive) {
         m_bActive = false;
@@ -1932,30 +2103,30 @@ void BeatLoopingControl::activate() {
 void BeatLoopingControl::slotLegacy(double v) {
     //qDebug() << "slotLegacy" << m_dBeatLoopSize << "v" << v;
     if (v > 0) {
-        emit activateBeatLoop(this);
+        emit activateBeatLoop(this, LoopingControl::LoopAnchorPoint::None);
     } else {
         emit deactivateBeatLoop(this);
     }
 }
 
-void BeatLoopingControl::slotActivate(double value) {
+void BeatLoopingControl::slotActivate(double value, LoopingControl::LoopAnchorPoint anchor) {
     //qDebug() << "slotActivate" << m_dBeatLoopSize << "value" << value;
     if (value == 0) {
         return;
     }
-    emit activateBeatLoop(this);
+    emit activateBeatLoop(this, anchor);
 }
 
-void BeatLoopingControl::slotActivateRoll(double v) {
+void BeatLoopingControl::slotActivateRoll(double v, LoopingControl::LoopAnchorPoint anchor) {
     //qDebug() << "slotActivateRoll" << m_dBeatLoopSize << "v" << v;
     if (v > 0) {
-        emit activateBeatLoopRoll(this);
+        emit activateBeatLoopRoll(this, anchor);
     } else {
         emit deactivateBeatLoopRoll(this);
     }
 }
 
-void BeatLoopingControl::slotToggle(double value) {
+void BeatLoopingControl::slotToggle(double value, LoopingControl::LoopAnchorPoint anchor) {
     //qDebug() << "slotToggle" << m_dBeatLoopSize << "value" << value;
     if (value == 0) {
         return;
@@ -1963,6 +2134,18 @@ void BeatLoopingControl::slotToggle(double value) {
     if (m_bActive) {
         emit deactivateBeatLoop(this);
     } else {
-        emit activateBeatLoop(this);
+        emit activateBeatLoop(this, anchor);
     }
 }
+
+void BeatLoopingControl::slotReverseActivate(double value) {
+    slotActivate(value, LoopingControl::LoopAnchorPoint::End);
+}
+
+void BeatLoopingControl::slotReverseActivateRoll(double v) {
+    slotActivateRoll(v, LoopingControl::LoopAnchorPoint::End);
+}
+
+void BeatLoopingControl::slotReverseToggle(double value) {
+    slotToggle(value, LoopingControl::LoopAnchorPoint::End);
+}
