@@ -1,12 +1,13 @@
 #include "engine/enginevumeter.h"
 
+#include "audio/types.h"
 #include "moc_enginevumeter.cpp"
 #include "util/sample.h"
 
 namespace {
 
 // Rate at which the vumeter is updated (using a sample rate of 44100 Hz):
-constexpr int kVuUpdateRate = 30;  // in 1/s, fits to display frame rate
+constexpr unsigned int kVuUpdateRate = 30; // in Hz (1/s), fits to display frame rate
 constexpr int kPeakDuration = 500; // in ms
 
 // Smoothing Factors
@@ -25,34 +26,34 @@ EngineVuMeter::EngineVuMeter(const QString& group, const QString& legacyGroup)
           m_peakIndicatorRight(ConfigKey(group, QStringLiteral("peak_indicator_right"))),
           m_sampleRate(QStringLiteral("[App]"), QStringLiteral("samplerate")) {
     const QString& aliasGroup = legacyGroup.isEmpty() ? group : legacyGroup;
-    m_vuMeter.addAlias(ConfigKey(aliasGroup, QStringLiteral("VuMeter"))),
-            m_vuMeterLeft.addAlias(ConfigKey(aliasGroup, QStringLiteral("VuMeterL"))),
-            m_vuMeterRight.addAlias(ConfigKey(aliasGroup, QStringLiteral("VuMeterR"))),
-            m_peakIndicator.addAlias(ConfigKey(aliasGroup, QStringLiteral("PeakIndicator"))),
-            m_peakIndicatorLeft.addAlias(ConfigKey(aliasGroup, QStringLiteral("PeakIndicatorL"))),
-            m_peakIndicatorRight.addAlias(ConfigKey(aliasGroup, QStringLiteral("PeakIndicatorR"))),
-            // Initialize the calculation:
-            reset();
+    m_vuMeter.addAlias(ConfigKey(aliasGroup, QStringLiteral("VuMeter")));
+    m_vuMeterLeft.addAlias(ConfigKey(aliasGroup, QStringLiteral("VuMeterL")));
+    m_vuMeterRight.addAlias(ConfigKey(aliasGroup, QStringLiteral("VuMeterR")));
+    m_peakIndicator.addAlias(ConfigKey(aliasGroup, QStringLiteral("PeakIndicator")));
+    m_peakIndicatorLeft.addAlias(ConfigKey(aliasGroup, QStringLiteral("PeakIndicatorL")));
+    m_peakIndicatorRight.addAlias(ConfigKey(aliasGroup, QStringLiteral("PeakIndicatorR")));
+    // Initialize the calculation:
+    reset();
 }
 
 void EngineVuMeter::process(CSAMPLE* pIn, const int iBufferSize) {
     CSAMPLE fVolSumL, fVolSumR;
 
-    int sampleRate = static_cast<int>(m_sampleRate.get());
+    const auto sampleRate = mixxx::audio::SampleRate::fromDouble(m_sampleRate.get());
 
     SampleUtil::CLIP_STATUS clipped = SampleUtil::sumAbsPerChannel(&fVolSumL,
             &fVolSumR, pIn, iBufferSize);
     m_fRMSvolumeSumL += fVolSumL;
     m_fRMSvolumeSumR += fVolSumR;
 
-    m_iSamplesCalculated += iBufferSize / 2;
+    m_samplesCalculated += static_cast<unsigned int>(iBufferSize / 2);
 
     // Are we ready to update the VU meter?:
-    if (m_iSamplesCalculated > (sampleRate / kVuUpdateRate)) {
+    if (m_samplesCalculated > (sampleRate / kVuUpdateRate)) {
         doSmooth(m_fRMSvolumeL,
-                std::log10(SHRT_MAX * m_fRMSvolumeSumL / (m_iSamplesCalculated * 1000) + 1));
+                std::log10(SHRT_MAX * m_fRMSvolumeSumL / (m_samplesCalculated * 1000) + 1));
         doSmooth(m_fRMSvolumeR,
-                std::log10(SHRT_MAX * m_fRMSvolumeSumR / (m_iSamplesCalculated * 1000) + 1));
+                std::log10(SHRT_MAX * m_fRMSvolumeSumR / (m_samplesCalculated * 1000) + 1));
 
         const double epsilon = .0001;
 
@@ -73,7 +74,7 @@ void EngineVuMeter::process(CSAMPLE* pIn, const int iBufferSize) {
         }
 
         // Reset calculation:
-        m_iSamplesCalculated = 0;
+        m_samplesCalculated = 0;
         m_fRMSvolumeSumL = 0;
         m_fRMSvolumeSumR = 0;
     }
@@ -125,7 +126,7 @@ void EngineVuMeter::reset() {
     m_peakIndicatorLeft.set(0);
     m_peakIndicatorRight.set(0);
 
-    m_iSamplesCalculated = 0;
+    m_samplesCalculated = 0;
     m_fRMSvolumeL = 0;
     m_fRMSvolumeSumL = 0;
     m_fRMSvolumeR = 0;
