@@ -1,7 +1,9 @@
 #pragma once
 
-#include "util/fifo.h"
-#include "util/sample.h"
+#include "util/types.h"
+
+template<class DataType>
+class FIFO;
 
 class NetworkInputStreamWorker {
   public:
