@@ -1,13 +1,13 @@
 #pragma once
 
-#include <QModelIndex>
 #include <QObject>
-#include <QString>
 
 #include "library/trackmodel.h"
 #include "library/basesqltablemodel.h"
 
 class TrackCollection;
+class QModelIndex;
+class QString;
 
 class BaseExternalTrackModel : public BaseSqlTableModel {
     Q_OBJECT
@@ -19,11 +19,11 @@ class BaseExternalTrackModel : public BaseSqlTableModel {
                            QSharedPointer<BaseTrackCache> trackSource);
     ~BaseExternalTrackModel() override;
 
-    CapabilitiesFlags getCapabilities() const override;
+    Capabilities getCapabilities() const override;
     TrackId getTrackId(const QModelIndex& index) const override;
     TrackPointer getTrack(const QModelIndex& index) const override;
     bool isColumnInternal(int column) override;
-    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   private:
     TrackId doGetTrackId(const TrackPointer& pTrack) const override;
