@@ -385,7 +385,8 @@ TrackModel::Capabilities BrowseTableModel::getCapabilities() const {
             Capability::LoadToDeck |
             Capability::LoadToPreviewDeck |
             Capability::LoadToSampler |
-            Capability::RemoveFromDisk;
+            Capability::RemoveFromDisk |
+            Capability::Sorting;
 }
 
 QString BrowseTableModel::modelKey(bool noSearch) const {
