@@ -9,11 +9,11 @@ class LibraryTableModel : public BaseSqlTableModel {
                       const char* settingsNamespace);
     ~LibraryTableModel() override;
 
-    void setTableModel(int id =-1);
+    void setTableModel();
 
     bool isColumnInternal(int column) final;
     // Takes a list of locations and add the tracks to the library. Returns the
     // number of successful additions.
     int addTracks(const QModelIndex& index, const QList<QString>& locations) final;
-    TrackModel::CapabilitiesFlags getCapabilities() const final;
+    TrackModel::Capabilities getCapabilities() const final;
 };
