@@ -1,12 +1,9 @@
 #include "library/recording/recordingfeature.h"
 
 #include "controllers/keyboard/keyboardeventfilter.h"
-#include "library/library.h"
+#include "library/browse/foldertreemodel.h"
 #include "library/recording/dlgrecording.h"
-#include "library/treeitem.h"
 #include "moc_recordingfeature.cpp"
-#include "recording/recordingmanager.h"
-#include "track/track.h"
 #include "widget/wlibrary.h"
 
 namespace {
@@ -16,24 +13,21 @@ const QString kViewName = QStringLiteral("Recording");
 } // anonymous namespace
 
 RecordingFeature::RecordingFeature(Library* pLibrary,
-                                   UserSettingsPointer pConfig,
-                                   RecordingManager* pRecordingManager)
-        : LibraryFeature(pLibrary, pConfig),
+        UserSettingsPointer pConfig,
+        RecordingManager* pRecordingManager)
+        : LibraryFeature(pLibrary, pConfig, QStringLiteral("recordings")),
           m_pRecordingManager(pRecordingManager),
-          m_icon(":/images/library/ic_library_recordings.svg") {
+          m_pSidebarModel(new FolderTreeModel(this)) {
 }
 
 QVariant RecordingFeature::title() {
     return QVariant(tr("Recordings"));
 }
 
-QIcon RecordingFeature::getIcon() {
-    return m_icon;
+TreeItemModel* RecordingFeature::sidebarModel() const {
+    return m_pSidebarModel;
 }
 
-TreeItemModel* RecordingFeature::getChildModel() {
-    return &m_childModel;
-}
 void RecordingFeature::bindLibraryWidget(WLibrary* pLibraryWidget,
                                   KeyboardEventFilter *keyboard) {
     //The view will be deleted by LibraryWidget
@@ -65,12 +59,15 @@ void RecordingFeature::bindLibraryWidget(WLibrary* pLibraryWidget,
             &DlgRecording::restoreSearch,
             this,
             &RecordingFeature::restoreSearch);
+    connect(pRecordingView,
+            &DlgRecording::restoreModelState,
+            this,
+            &RecordingFeature::restoreModelState);
 }
 
-
 void RecordingFeature::activate() {
     emit refreshBrowseModel();
     emit switchToView(kViewName);
-    emit disableSearch();
+    emit requestRestoreSearch();
     emit enableCoverArtDisplay(false);
 }
