@@ -23,11 +23,6 @@ TrackCollection::TrackCollection(
           m_trackDao(m_cueDao, m_playlistDao,
                      m_analysisDao, m_libraryHashDao, pConfig) {
     // Forward signals from TrackDAO
-    connect(&m_trackDao,
-            &TrackDAO::trackClean,
-            this,
-            &TrackCollection::trackClean,
-            /*signal-to-signal*/ Qt::DirectConnection);
     connect(&m_trackDao,
             &TrackDAO::trackDirty,
             this,
@@ -573,11 +568,6 @@ TrackPointer TrackCollection::getTrackByRef(
     return m_trackDao.getTrackByRef(trackRef);
 }
 
-TrackId TrackCollection::getTrackIdByRef(
-        const TrackRef& trackRef) const {
-    return m_trackDao.getTrackIdByRef(trackRef);
-}
-
 TrackPointer TrackCollection::getOrAddTrack(
         const TrackRef& trackRef,
         bool* pAlreadyInLibrary) {
