@@ -19,7 +19,9 @@ class CrateTableModel final : public TrackSetTableModel {
 
     void removeTracks(const QModelIndexList& indices) final;
     /// Returns the number of unsuccessful additions.
-    int addTracks(const QModelIndex& index, const QList<QString>& locations) final;
+    int addTracksWithTrackIds(const QModelIndex& index,
+            const QList<TrackId>& tracks,
+            int* pOutInsertionPos) final;
     bool isLocked() final;
 
     Capabilities getCapabilities() const final;
