@@ -1,5 +1,6 @@
 #include "mixer/auxiliary.h"
 
+#include "audio/types.h"
 #include "control/controlproxy.h"
 #include "engine/channels/engineaux.h"
 #include "engine/enginemixer.h"
@@ -17,7 +18,10 @@ Auxiliary::Auxiliary(PlayerManager* pParent,
     ChannelHandleAndGroup channelGroup = pEngine->registerChannelGroup(group);
     EngineAux* pAuxiliary = new EngineAux(channelGroup, pEffectsManager);
     pEngine->addChannel(pAuxiliary);
-    AudioInput auxInput = AudioInput(AudioPathType::Auxiliary, 0, 2, index);
+    AudioInput auxInput = AudioInput(AudioPathType::Auxiliary,
+            0,
+            mixxx::audio::ChannelCount::stereo(),
+            index);
     pSoundManager->registerInput(auxInput, pAuxiliary);
 
     m_pInputConfigured = make_parented<ControlProxy>(group, "input_configured", this);
