@@ -122,7 +122,6 @@ class BaseTrackPlayerImpl : public BaseTrackPlayer {
     void slotTrackColorChangeRequest(double value);
     /// Slot for change signals from up/down controls (relative values)
     void slotTrackRatingChangeRequestRelative(int change);
-    void slotVinylControlEnabled(double v);
     void slotWaveformZoomValueChangeRequest(double pressed);
     void slotWaveformZoomUp(double pressed);
     void slotWaveformZoomDown(double pressed);
@@ -211,7 +210,4 @@ class BaseTrackPlayerImpl : public BaseTrackPlayer {
     parented_ptr<ControlProxy> m_pPreGain;
     parented_ptr<ControlProxy> m_pRateRatio;
     parented_ptr<ControlProxy> m_pPitchAdjust;
-    parented_ptr<ControlProxy> m_pInputConfigured;
-    parented_ptr<ControlProxy> m_pVinylControlEnabled;
-    parented_ptr<ControlProxy> m_pVinylControlStatus;
 };
