@@ -1,5 +1,9 @@
 #include "preferences/dialog/dlgprefautodj.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+#include <QTimeZone>
+#endif
+
 #include "moc_dlgprefautodj.cpp"
 
 DlgPrefAutoDJ::DlgPrefAutoDJ(QWidget* pParent,
@@ -18,13 +22,23 @@ DlgPrefAutoDJ::DlgPrefAutoDJ(QWidget* pParent,
             &DlgPrefAutoDJ::slotSetMinimumAvailable);
 
     // The auto-DJ replay-age for randomly-selected tracks
-    RequeueIgnoreCheckBox->setChecked(
-            (bool)m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "UseIgnoreTime"), 0));
+    RequeueIgnoreCheckBox->setChecked(m_pConfig->getValue(
+            ConfigKey("[Auto DJ]", "UseIgnoreTime"), false));
     connect(RequeueIgnoreCheckBox,
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+            &QCheckBox::checkStateChanged,
+#else
             &QCheckBox::stateChanged,
+#endif
             this,
             &DlgPrefAutoDJ::slotToggleRequeueIgnore);
+    /// TODO: Once we require at least Qt 6.7, remove this `setTimeZone` call
+    /// and uncomment the corresponding declarations in the UI file instead.
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    RequeueIgnoreTimeEdit->setTimeZone(QTimeZone::LocalTime);
+#else
+    RequeueIgnoreTimeEdit->setTimeSpec(Qt::LocalTime);
+#endif
     RequeueIgnoreTimeEdit->setTime(
             QTime::fromString(
                     m_pConfig->getValue(
@@ -38,9 +52,8 @@ DlgPrefAutoDJ::DlgPrefAutoDJ(QWidget* pParent,
             &DlgPrefAutoDJ::slotSetRequeueIgnoreTime);
 
     // Auto DJ random enqueue
-    RandomQueueCheckBox->setChecked(
-            (bool)m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "EnableRandomQueue"), 0));
+    RandomQueueCheckBox->setChecked(m_pConfig->getValue(
+            ConfigKey("[Auto DJ]", "EnableRandomQueue"), false));
     // 5-arbitrary
     RandomQueueMinimumSpinBox->setValue(
             m_pConfig->getValue(
@@ -48,13 +61,19 @@ DlgPrefAutoDJ::DlgPrefAutoDJ(QWidget* pParent,
     // "[Auto DJ], Requeue" is set by 'Repeat Playlist' toggle in DlgAutoDj GUI.
     // If it's checked un-check 'Random Queue'
     slotConsiderRepeatPlaylistState(
-            m_pConfig->getValueString(ConfigKey("[Auto DJ]", "Requeue")).toInt());
+            m_pConfig->getValue<bool>(ConfigKey("[Auto DJ]", "Requeue")));
     slotToggleRandomQueue(
-            m_pConfig->getValue<int>(
-                    ConfigKey("[Auto DJ]", "EnableRandomQueue")));
+            m_pConfig->getValue<bool>(
+                    ConfigKey("[Auto DJ]", "EnableRandomQueue"))
+                    ? Qt::Checked
+                    : Qt::Unchecked);
     // Be ready to enable and modify the minimum number and un/check the checkbox
     connect(RandomQueueCheckBox,
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+            &QCheckBox::checkStateChanged,
+#else
             &QCheckBox::stateChanged,
+#endif
             this,
             &DlgPrefAutoDJ::slotToggleRandomQueue);
     connect(RandomQueueMinimumSpinBox,
@@ -65,9 +84,6 @@ DlgPrefAutoDJ::DlgPrefAutoDJ(QWidget* pParent,
     setScrollSafeGuardForAllInputWidgets(this);
 }
 
-DlgPrefAutoDJ::~DlgPrefAutoDJ() {
-}
-
 void DlgPrefAutoDJ::slotUpdate() {
 }
 
@@ -82,14 +98,14 @@ void DlgPrefAutoDJ::slotApply() {
                     ConfigKey("[Auto DJ]", "IgnoreTimeBuff"), "23:59"));
     m_pConfig->setValue(ConfigKey("[Auto DJ]", "UseIgnoreTime"),
             m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"), "0"));
+                    ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"), false));
 
     m_pConfig->setValue(ConfigKey("[Auto DJ]", "RandomQueueMinimumAllowed"),
             m_pConfig->getValue(
                     ConfigKey("[Auto DJ]", "RandomQueueMinimumAllowedBuff"), 5));
     m_pConfig->setValue(ConfigKey("[Auto DJ]", "EnableRandomQueue"),
             m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"), 0));
+                    ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"), false));
 }
 
 void DlgPrefAutoDJ::slotCancel() {
@@ -110,7 +126,7 @@ void DlgPrefAutoDJ::slotCancel() {
             RequeueIgnoreCheckBox->checkState() == Qt::Checked);
     m_pConfig->setValue(ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"),
             m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "UseIgnoreTime"), 0));
+                    ConfigKey("[Auto DJ]", "UseIgnoreTime"), false));
 
     RandomQueueMinimumSpinBox->setValue(
             m_pConfig->getValue(
@@ -120,12 +136,17 @@ void DlgPrefAutoDJ::slotCancel() {
                     ConfigKey("[Auto DJ]", "EnableRandomQueue"), false));
     m_pConfig->setValue(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),
             m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "EnableRandomQueue"), 0));
+                    ConfigKey("[Auto DJ]", "EnableRandomQueue"), false));
     slotToggleRandomQueue(
             m_pConfig->getValue(
-                    ConfigKey("[Auto DJ]", "EnableRandomQueue"), 0));
+                    ConfigKey("[Auto DJ]", "EnableRandomQueue"), false)
+                    ? Qt::Checked
+                    : Qt::Unchecked);
     slotToggleRandomQueue(
-            m_pConfig->getValue<int>(ConfigKey("[Auto DJ]", "Requeue")));
+            m_pConfig->getValue(
+                    ConfigKey("[Auto DJ]", "Requeue"), false)
+                    ? Qt::Checked
+                    : Qt::Unchecked);
 }
 
 void DlgPrefAutoDJ::slotResetToDefaults() {
@@ -135,50 +156,48 @@ void DlgPrefAutoDJ::slotResetToDefaults() {
     RequeueIgnoreTimeEdit->setTime(QTime::fromString(
             "23:59", RequeueIgnoreTimeEdit->displayFormat()));
     RequeueIgnoreCheckBox->setChecked(false);
-    m_pConfig->set(ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"),QString("0"));
+    m_pConfig->setValue(ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"), false);
     RequeueIgnoreTimeEdit->setEnabled(false);
 
     RandomQueueMinimumSpinBox->setValue(5);
     RandomQueueCheckBox->setChecked(false);
-    m_pConfig->set(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),QString("0"));
+    m_pConfig->setValue(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"), false);
     RandomQueueMinimumSpinBox->setEnabled(false);
     RandomQueueCheckBox->setEnabled(true);
 }
 
 void DlgPrefAutoDJ::slotSetMinimumAvailable(int a_iValue) {
-    QString str;
-    str.setNum(a_iValue);
-    m_pConfig->set(ConfigKey("[Auto DJ]","MinimumAvailableBuff"),str);
+    m_pConfig->setValue(ConfigKey("[Auto DJ]", "MinimumAvailableBuff"), a_iValue);
 }
 
-void DlgPrefAutoDJ::slotToggleRequeueIgnore(int a_iState) {
-    bool bChecked = (a_iState == Qt::Checked);
-    QString strChecked = (bChecked) ? "1" : "0";
-    m_pConfig->set(ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"), strChecked);
-    RequeueIgnoreTimeEdit->setEnabled(bChecked);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+void DlgPrefAutoDJ::slotToggleRequeueIgnore(Qt::CheckState buttonState) {
+#else
+void DlgPrefAutoDJ::slotToggleRequeueIgnore(int buttonState) {
+#endif
+    bool checked = buttonState == Qt::Checked;
+    m_pConfig->setValue(ConfigKey("[Auto DJ]", "UseIgnoreTimeBuff"), checked);
+    RequeueIgnoreTimeEdit->setEnabled(checked);
 }
 
 void DlgPrefAutoDJ::slotSetRequeueIgnoreTime(const QTime& a_rTime) {
     QString str = a_rTime.toString(RequeueIgnoreTimeEdit->displayFormat());
-    m_pConfig->set(ConfigKey("[Auto DJ]", "IgnoreTimeBuff"),str);
+    m_pConfig->set(ConfigKey("[Auto DJ]", "IgnoreTimeBuff"), str);
 }
 
 void DlgPrefAutoDJ::slotSetRandomQueueMin(int a_iValue) {
-    QString str;
-    //qDebug() << "min allowed " << a_iValue;
-    str.setNum(a_iValue);
-    m_pConfig->set(ConfigKey("[Auto DJ]", "RandomQueueMinimumAllowedBuff"), str);
+    m_pConfig->setValue(ConfigKey("[Auto DJ]", "RandomQueueMinimumAllowedBuff"), a_iValue);
 }
 
-void DlgPrefAutoDJ::slotConsiderRepeatPlaylistState(int a_iValue) {
-    if (a_iValue == 1) {
+void DlgPrefAutoDJ::slotConsiderRepeatPlaylistState(bool enable) {
+    if (enable) {
         // Requeue is enabled
         RandomQueueCheckBox->setChecked(false);
         // ToDo(ronso0): Redundant? If programmatic checkbox change is signaled
         // to slotToggleRandomQueue
         RandomQueueMinimumSpinBox->setEnabled(false);
-        m_pConfig->set(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),
-                ConfigValue(0));
+        m_pConfig->setValue(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),
+                false);
     } else {
         RandomQueueMinimumSpinBox->setEnabled(
                 m_pConfig->getValue(
@@ -186,15 +205,14 @@ void DlgPrefAutoDJ::slotConsiderRepeatPlaylistState(int a_iValue) {
     }
 }
 
-void DlgPrefAutoDJ::slotToggleRandomQueue(int a_iValue) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+void DlgPrefAutoDJ::slotToggleRandomQueue(Qt::CheckState buttonState) {
+#else
+void DlgPrefAutoDJ::slotToggleRandomQueue(int buttonState) {
+#endif
+    bool enable = buttonState == Qt::Checked;
     // Toggle the option to select minimum tracks
-    if (a_iValue == 0) {
-        RandomQueueMinimumSpinBox->setEnabled(false);
-        m_pConfig->set(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),
-                ConfigValue(0));
-    } else {
-        RandomQueueMinimumSpinBox->setEnabled(true);
-        m_pConfig->set(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),
-                ConfigValue(1));
-    }
+    RandomQueueMinimumSpinBox->setEnabled(enable);
+    m_pConfig->setValue(ConfigKey("[Auto DJ]", "EnableRandomQueueBuff"),
+            enable);
 }
