@@ -18,7 +18,6 @@
 #include "util/logger.h"
 
 namespace {
-const char* kSettingsGroupHeader = "Settings for %1";
 constexpr int kColumnEnabled = 0;
 constexpr int kColumnName = 1;
 const mixxx::Logger kLogger("DlgPrefBroadcast");
@@ -417,9 +416,8 @@ void DlgPrefBroadcast::getValuesFromProfile(BroadcastProfilePtr profile) {
     }
 
     // Set groupbox header
-    QString headerText =
-            QString(tr(kSettingsGroupHeader))
-            .arg(profile->getProfileName());
+    //: Settings for broadcast profile, %1 is the profile name placeholder
+    const QString headerText = tr("Settings for %1").arg(profile->getProfileName());
     groupBoxProfileSettings->setTitle(headerText);
 
     rbPasswordCleartext->setChecked(!profile->secureCredentialStorage());
