@@ -15,61 +15,59 @@ void ColorSchemeParser::setupLegacyColorSchemes(const QDomElement& docElem,
         UserSettingsPointer pConfig,
         QString* pStyle,
         SkinContext* pContext) {
-    QDomNode schemesNode = docElem.namedItem("Schemes");
+    QDomNode schemeNode = findConfiguredColorSchemeNode(docElem, pConfig);
 
-    bool bSelectedColorSchemeFound = false;
+    if (!schemeNode.isNull()) {
+        QSharedPointer<ImgSource> pImgSrc =
+                QSharedPointer<ImgSource>(parseFilters(schemeNode.namedItem("Filters")));
+        WPixmapStore::setLoader(pImgSrc);
+        WImageStore::setLoader(pImgSrc);
+        WSkinColor::setLoader(pImgSrc);
 
-    if (!schemesNode.isNull() && schemesNode.isElement()) {
-        QString selectedSchemeName = pConfig->getValueString(ConfigKey("[Config]","Scheme"));
-        QDomNode schemeNode = schemesNode.firstChild();
+        // This calls SkinContext::updateVariables which iterates over all
+        // <SetVariable> nodes in the selected color scheme node.
+        pContext->updateVariables(schemeNode);
 
-        if (selectedSchemeName.isEmpty()) {
-            // If no scheme selected, accept the first one in the file
-            bSelectedColorSchemeFound = true;
+        if (pStyle) {
+            // read scheme's stylesheet (node text or stylesheet file)
+            *pStyle = LegacySkinParser::getStyleFromNode(schemeNode);
         }
-
-        while (!schemeNode.isNull() && !bSelectedColorSchemeFound) {
-            QString schemeName = XmlParse::selectNodeQString(schemeNode, "Name");
-            if (schemeName == selectedSchemeName) {
-                bSelectedColorSchemeFound = true;
-            } else {
-                schemeNode = schemeNode.nextSibling();
-            }
-        }
-
-        if (!bSelectedColorSchemeFound) {
-            // If we didn't find a matching color scheme, pick the first one
-            schemeNode = schemesNode.firstChild();
-            bSelectedColorSchemeFound = !schemeNode.isNull();
-        }
-
-        if (bSelectedColorSchemeFound) {
-            QSharedPointer<ImgSource> imsrc =
-                    QSharedPointer<ImgSource>(parseFilters(schemeNode.namedItem("Filters")));
-            WPixmapStore::setLoader(imsrc);
-            WImageStore::setLoader(imsrc);
-            WSkinColor::setLoader(imsrc);
-
-            // This calls SkinContext::updateVariables which iterates over all
-            // <SetVariable> nodes in the selected color scheme node.
-            pContext->updateVariables(schemeNode);
-
-            if (pStyle) {
-                // read scheme's stylesheet (node text or stylesheet file)
-                *pStyle = LegacySkinParser::getStyleFromNode(schemeNode);
-            }
-        }
-    }
-
-    if (!bSelectedColorSchemeFound) {
-        QSharedPointer<ImgSource> imsrc =
+    } else {
+        QSharedPointer<ImgSource> pImgSrc =
                 QSharedPointer<ImgSource>(new ImgLoader());
-        WPixmapStore::setLoader(imsrc);
-        WImageStore::setLoader(imsrc);
-        WSkinColor::setLoader(imsrc);
+        WPixmapStore::setLoader(pImgSrc);
+        WImageStore::setLoader(pImgSrc);
+        WSkinColor::setLoader(pImgSrc);
     }
 }
 
+QDomNode ColorSchemeParser::findConfiguredColorSchemeNode(
+        const QDomElement& docElem,
+        UserSettingsPointer pConfig) {
+    QDomNode schemesNode = docElem.namedItem("Schemes");
+    if (schemesNode.isNull() || !schemesNode.isElement()) {
+        return {};
+    }
+
+    QDomNode schemeNode = schemesNode.firstChild();
+    const QString selectedSchemeName = pConfig->getValueString(ConfigKey("[Config]", "Scheme"));
+    if (selectedSchemeName.isEmpty()) {
+        // If no scheme selected, accept the first one in the file
+        return schemeNode;
+    }
+
+    while (!schemeNode.isNull()) {
+        QString schemeName = XmlParse::selectNodeQString(schemeNode, "Name");
+        if (schemeName == selectedSchemeName) {
+            return schemeNode;
+        }
+        schemeNode = schemeNode.nextSibling();
+    }
+
+    // If we didn't find a matching color scheme, pick the first one
+    return schemesNode.firstChild();
+}
+
 ImgSource* ColorSchemeParser::parseFilters(const QDomNode& filt) {
     ImgSource* ret = new ImgLoader();
 
