@@ -3,6 +3,7 @@
 #include <QWidget>
 
 QT_FORWARD_DECLARE_CLASS(QProgressBar);
+QT_FORWARD_DECLARE_CLASS(QLabel);
 
 // This is a widget that is shown in the Mixxx main window
 // until the skin is ready to use.
@@ -38,7 +39,7 @@ class LaunchImage: public QWidget {
   public:
     LaunchImage(QWidget* pParent, const QString& styleSheet);
     ~LaunchImage() override = default;
-    void progress(int value);
+    void progress(int value, const QString& serviceName);
 
   protected:
     void paintEvent(QPaintEvent*) override;
