@@ -44,11 +44,11 @@ SoundDeviceNetwork::SoundDeviceNetwork(
           m_targetTime(0) {
     // Setting parent class members:
     m_hostAPI = "Network stream";
-    m_dSampleRate = 44100.0;
+    m_sampleRate = SoundManagerConfig::kMixxxDefaultSampleRate;
     m_deviceId.name = kNetworkDeviceInternalName;
     m_strDisplayName = QObject::tr("Network stream");
-    m_iNumInputChannels = pNetworkStream->getNumInputChannels();
-    m_iNumOutputChannels = pNetworkStream->getNumOutputChannels();
+    m_numInputChannels = pNetworkStream->getNumInputChannels();
+    m_numOutputChannels = pNetworkStream->getNumOutputChannels();
 }
 
 SoundDeviceNetwork::~SoundDeviceNetwork() {
@@ -59,38 +59,38 @@ SoundDeviceStatus SoundDeviceNetwork::open(bool isClkRefDevice, int syncBuffers)
     kLogger.debug() << "open:" << m_deviceId.name;
 
     // Sample rate
-    if (m_dSampleRate <= 0) {
-        m_dSampleRate = 44100.0;
+    if (!m_sampleRate.isValid()) {
+        m_sampleRate = SoundManagerConfig::kMixxxDefaultSampleRate;
     }
 
     const SINT framesPerBuffer = m_configFramesPerBuffer;
     const auto requestedBufferTime = mixxx::Duration::fromSeconds(
-            framesPerBuffer / m_dSampleRate);
+            framesPerBuffer / m_sampleRate.toDouble());
 
     // Feed the network device buffer directly from the
     // clock reference device callback
     // This is what should work best.
-    if (m_iNumOutputChannels) {
+    if (m_numOutputChannels) {
         m_outputFifo = std::make_unique<FIFO<CSAMPLE>>(
-                m_iNumOutputChannels * framesPerBuffer * 2);
+                m_numOutputChannels * framesPerBuffer * 2);
     }
-    if (m_iNumInputChannels) {
+    if (m_numInputChannels) {
         m_inputFifo = std::make_unique<FIFO<CSAMPLE>>(
-                m_iNumInputChannels * framesPerBuffer * 2);
+                m_numInputChannels * framesPerBuffer * 2);
     }
 
-    m_pNetworkStream->startStream(m_dSampleRate);
+    m_pNetworkStream->startStream(m_sampleRate);
 
     // Create the callback Thread if requested
     if (isClkRefDevice) {
         kLogger.debug() << "Clock Reference with:" << framesPerBuffer << "frames/buffer @"
-                        << m_dSampleRate << "Hz =" << requestedBufferTime.formatMillisWithUnit();
+                        << m_sampleRate << "Hz =" << requestedBufferTime.formatMillisWithUnit();
 
         // Update the samplerate and latency ControlObjects, which allow the
         // waveform view to properly correct for the latency.
         ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("output_latency_ms")),
                 requestedBufferTime.toDoubleMillis());
-        ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("samplerate")), m_dSampleRate);
+        ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("samplerate")), m_sampleRate);
 
         // Network stream was just started above so we have to wait until
         // we can pass one chunk.
@@ -101,7 +101,7 @@ SoundDeviceStatus SoundDeviceNetwork::open(bool isClkRefDevice, int syncBuffers)
         m_pThread->start(QThread::TimeCriticalPriority);
     } else {
         kLogger.debug() << "Maximum:" << framesPerBuffer << "frames/buffer @"
-                        << m_dSampleRate << "Hz =" << requestedBufferTime.formatMillisWithUnit();
+                        << m_sampleRate << "Hz =" << requestedBufferTime.formatMillisWithUnit();
     }
 
     return SoundDeviceStatus::Ok;
@@ -126,19 +126,22 @@ SoundDeviceStatus SoundDeviceNetwork::close() {
     return SoundDeviceStatus::Ok;
 }
 
+mixxx::audio::SampleRate SoundDeviceNetwork::getDefaultSampleRate() const {
+    return SoundManagerConfig::kMixxxDefaultSampleRate;
+}
+
 QString SoundDeviceNetwork::getError() const {
     return QString();
 }
 
 void SoundDeviceNetwork::readProcess(SINT framesPerBuffer) {
-    if (!m_inputFifo || !m_pNetworkStream || !m_iNumInputChannels) {
+    if (!m_inputFifo || !m_pNetworkStream || !m_numInputChannels.isValid()) {
         return;
     }
     DEBUG_ASSERT(m_configFramesPerBuffer >= framesPerBuffer);
 
-    int inChunkSize = framesPerBuffer * m_iNumInputChannels;
-    int readAvailable = m_pNetworkStream->getReadExpected()
-            * m_iNumInputChannels;
+    int inChunkSize = framesPerBuffer * m_numInputChannels;
+    int readAvailable = m_pNetworkStream->getReadExpected() * m_numInputChannels;
     int writeAvailable = m_inputFifo->writeAvailable();
     int copyCount = qMin(writeAvailable, readAvailable);
     if (copyCount > 0) {
@@ -150,12 +153,12 @@ void SoundDeviceNetwork::readProcess(SINT framesPerBuffer) {
                 &dataPtr1, &size1, &dataPtr2, &size2);
         // Fetch fresh samples and write to the the input buffer
         m_pNetworkStream->read(dataPtr1,
-                size1 / m_iNumInputChannels);
-        CSAMPLE* lastFrame = &dataPtr1[size1 - m_iNumInputChannels];
+                size1 / m_numInputChannels);
+        CSAMPLE* lastFrame = &dataPtr1[size1 - m_numInputChannels];
         if (size2 > 0) {
             m_pNetworkStream->read(dataPtr2,
-                    size2 / m_iNumInputChannels);
-            lastFrame = &dataPtr2[size2 - m_iNumInputChannels];
+                    size2 / m_numInputChannels);
+            lastFrame = &dataPtr2[size2 - m_numInputChannels];
         }
         m_inputFifo->releaseWriteRegions(copyCount);
 
@@ -175,9 +178,8 @@ void SoundDeviceNetwork::readProcess(SINT framesPerBuffer) {
                 // duplicate one frame
                 //kLogger.debug() << "readProcess() duplicate one frame"
                 //                << (float)writeAvailable / inChunkSize << (float)readAvailable / inChunkSize;
-                (void) m_inputFifo->aquireWriteRegions(
-                        m_iNumInputChannels, &dataPtr1, &size1,
-                        &dataPtr2, &size2);
+                (void)m_inputFifo->aquireWriteRegions(
+                        m_numInputChannels, &dataPtr1, &size1, &dataPtr2, &size2);
                 if (size1) {
                     SampleUtil::copy(dataPtr1, lastFrame, size1);
                     m_inputFifo->releaseWriteRegions(size1);
@@ -207,13 +209,14 @@ void SoundDeviceNetwork::readProcess(SINT framesPerBuffer) {
                 &dataPtr2, &size2);
         // Fetch fresh samples and write to the the output buffer
         composeInputBuffer(dataPtr1,
-                size1 / m_iNumInputChannels, 0,
-                m_iNumInputChannels);
+                size1 / m_numInputChannels,
+                0,
+                m_numInputChannels);
         if (size2 > 0) {
             composeInputBuffer(dataPtr2,
-                    size2 / m_iNumInputChannels,
-                    size1 / m_iNumInputChannels,
-                    m_iNumInputChannels);
+                    size2 / m_numInputChannels,
+                    size1 / m_numInputChannels,
+                    m_numInputChannels);
         }
         m_inputFifo->releaseReadRegions(readCount);
     }
@@ -226,12 +229,12 @@ void SoundDeviceNetwork::readProcess(SINT framesPerBuffer) {
 }
 
 void SoundDeviceNetwork::writeProcess(SINT framesPerBuffer) {
-    if (!m_outputFifo || !m_pNetworkStream || !m_iNumOutputChannels) {
+    if (!m_outputFifo || !m_pNetworkStream || !m_numOutputChannels) {
         return;
     }
     DEBUG_ASSERT(m_configFramesPerBuffer >= framesPerBuffer);
 
-    int outChunkSize = framesPerBuffer * m_iNumOutputChannels;
+    int outChunkSize = framesPerBuffer * m_numOutputChannels;
     int writeAvailable = m_outputFifo->writeAvailable();
     int writeCount = outChunkSize;
     if (outChunkSize > writeAvailable) {
@@ -249,12 +252,12 @@ void SoundDeviceNetwork::writeProcess(SINT framesPerBuffer) {
         (void)m_outputFifo->aquireWriteRegions(writeCount, &dataPtr1,
                 &size1, &dataPtr2, &size2);
         // Fetch fresh samples and write to the the output buffer
-        composeOutputBuffer(dataPtr1, size1 / m_iNumOutputChannels, 0, m_iNumOutputChannels);
+        composeOutputBuffer(dataPtr1, size1 / m_numOutputChannels, 0, m_numOutputChannels);
         if (size2 > 0) {
             composeOutputBuffer(dataPtr2,
-                    size2 / m_iNumOutputChannels,
-                    size1 / m_iNumOutputChannels,
-                    m_iNumOutputChannels);
+                    size2 / m_numOutputChannels,
+                    size1 / m_numOutputChannels,
+                    m_numOutputChannels);
         }
         m_outputFifo->releaseWriteRegions(writeCount);
     }
@@ -271,7 +274,7 @@ void SoundDeviceNetwork::writeProcess(SINT framesPerBuffer) {
     m_outputFifo->aquireReadRegions(readAvailable,
             &dataPtr1, &size1, &dataPtr2, &size2);
 
-    QVector<NetworkOutputStreamWorkerPtr> workers =
+    const QVector<NetworkOutputStreamWorkerPtr> workers =
             m_pNetworkStream->outputWorkers();
     for (const auto& pWorker : workers) {
         if (pWorker.isNull()) {
@@ -294,14 +297,15 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
     int writeExpectedFrames = static_cast<int>(
             pWorker->getStreamTimeFrames() - pWorker->framesWritten());
 
-    int writeExpected = writeExpectedFrames * m_iNumOutputChannels;
+    int writeExpected = writeExpectedFrames * m_numOutputChannels;
 
     if (writeExpected <= 0) {
         // Overflow
         // kLogger.debug() << "workerWriteProcess: buffer full"
         //                 << "outChunkSize" << outChunkSize
         //                 << "readAvailable" << readAvailable
-        //                 << "writeExpected" << writeExpected << pWorker->getStreamTimeFrames();
+        //                 << "writeExpected" << writeExpected
+        //                 << "streamTime" << pWorker->getStreamTimeFrames();
         // catch up by skipping chunk
         m_pSoundManager->underflowHappened(25);
     }
@@ -310,7 +314,9 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
     if (copyCount > 0) {
         if (writeExpected - copyCount > outChunkSize) {
             // Underflow
-            // kLogger.debug() << "workerWriteProcess: buffer empty";
+            // kLogger.debug() << "workerWriteProcess: buffer empty."
+            //                 << "Catch up with silence:" << writeExpected - copyCount
+            //                 << "streamTime" << pWorker->getStreamTimeFrames();;
             // catch up by filling buffer until we are synced
             workerWriteSilence(pWorker, writeExpected - copyCount);
             m_pSoundManager->underflowHappened(24);
@@ -332,9 +338,9 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
                 //                    "skip one frame"
                 //                 << (float)writeAvailable / outChunkSize
                 //                 << (float)readAvailable / outChunkSize;
-                if (size1 >= m_iNumOutputChannels) {
-                    dataPtr1 += m_iNumOutputChannels;
-                    size1 -= m_iNumOutputChannels;
+                if (size1 >= m_numOutputChannels) {
+                    dataPtr1 += m_numOutputChannels;
+                    size1 -= m_numOutputChannels;
                 }
             } else {
                 pWorker->setOutputDrift(true);
@@ -343,9 +349,9 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
             pWorker->setOutputDrift(false);
         }
 
-        workerWrite(pWorker, dataPtr1, size1 / m_iNumOutputChannels);
+        workerWrite(pWorker, dataPtr1, size1 / m_numOutputChannels);
         if (size2 > 0) {
-            workerWrite(pWorker, dataPtr2, size2 / m_iNumOutputChannels);
+            workerWrite(pWorker, dataPtr2, size2 / m_numOutputChannels);
         }
 
         QSharedPointer<FIFO<CSAMPLE>> pFifo = pWorker->getOutputFifo();
@@ -353,8 +359,8 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
             // interval = copyCount
             // Check for desired kNetworkLatencyFrames + 1/2 interval to
             // avoid big jitter due to interferences with sync code
-            if (pFifo->readAvailable() + copyCount / 2
-                    >= (m_iNumOutputChannels * kNetworkLatencyFrames)) {
+            if (pFifo->readAvailable() + copyCount / 2 >=
+                    (m_numOutputChannels * kNetworkLatencyFrames)) {
                 pWorker->outputAvailable();
             }
         }
@@ -371,7 +377,7 @@ void SoundDeviceNetwork::workerWrite(NetworkOutputStreamWorkerPtr pWorker,
     QSharedPointer<FIFO<CSAMPLE>> pFifo = pWorker->getOutputFifo();
     if (pFifo) {
         int writeAvailable = pFifo->writeAvailable();
-        int writeRequired = frames * m_iNumOutputChannels;
+        int writeRequired = frames * m_numOutputChannels;
         if (writeAvailable < writeRequired) {
             kLogger.warning() << "write: worker buffer full, losing samples";
             pWorker->incOverflowCount();
@@ -384,7 +390,7 @@ void SoundDeviceNetwork::workerWrite(NetworkOutputStreamWorkerPtr pWorker,
             // This means in case of buffer full (where we loose some frames)
             // we do not get out of sync, and the syncing code tries to catch up the
             // stream by writing silence, once the buffer is free.
-            pWorker->addFramesWritten(copyCount / m_iNumOutputChannels);
+            pWorker->addFramesWritten(copyCount / m_numOutputChannels);
         }
     }
 }
@@ -398,7 +404,7 @@ void SoundDeviceNetwork::workerWriteSilence(NetworkOutputStreamWorkerPtr pWorker
     QSharedPointer<FIFO<CSAMPLE>> pFifo = pWorker->getOutputFifo();
     if (pFifo) {
         int writeAvailable = pFifo->writeAvailable();
-        int writeRequired = frames * m_iNumOutputChannels;
+        int writeRequired = frames * m_numOutputChannels;
         if (writeAvailable < writeRequired) {
             kLogger.warning() << "writeSilence: worker buffer full, losing samples";
             pWorker->incOverflowCount();
@@ -420,7 +426,7 @@ void SoundDeviceNetwork::workerWriteSilence(NetworkOutputStreamWorkerPtr pWorker
             pFifo->releaseWriteRegions(clearCount);
 
             // we advance the frame only by the samples we have actually cleared
-            pWorker->addFramesWritten(clearCount / m_iNumOutputChannels);
+            pWorker->addFramesWritten(clearCount / m_numOutputChannels);
         }
     }
 }
@@ -439,10 +445,18 @@ void SoundDeviceNetwork::callbackProcessClkRef() {
 
     if (!m_denormals) {
         m_denormals = true;
+
         // This disables the denormals calculations, to avoid a
         // performance penalty of ~20
         // https://github.com/mixxxdj/mixxx/issues/7747
-#ifdef __SSE__
+
+        // On Emscripten (WebAssembly) denormals-as-zero/flush-as-zero are
+        // neither supported nor configurable. This may lead to degraded
+        // performance compared to other platforms and may be addressed in the
+        // future if/when WebAssembly adds support for DAZ/FTZ. For further
+        // discussion and links see https://github.com/mixxxdj/mixxx/pull/12917
+
+#if defined(__SSE__) && !defined(__EMSCRIPTEN__)
         if (!_MM_GET_DENORMALS_ZERO_MODE()) {
             qDebug() << "SSE: Enabling denormals to zero mode";
             _MM_SET_DENORMALS_ZERO_MODE(_MM_DENORMALS_ZERO_ON);
@@ -486,7 +500,7 @@ void SoundDeviceNetwork::callbackProcessClkRef() {
     m_pSoundManager->readProcess(framesPerBuffer);
 
     {
-        ScopedTimer t("SoundDevicePortAudio::callbackProcess prepare %1",
+        ScopedTimer t(QStringLiteral("SoundDeviceNetwork::callbackProcess prepare %1"),
                 m_deviceId.name);
         m_pSoundManager->onDeviceOutputCallback(framesPerBuffer);
     }
@@ -502,7 +516,7 @@ void SoundDeviceNetwork::updateCallbackEntryToDacTime(SINT framesPerBuffer) {
     m_clkRefTimer.start();
     qint64 currentTime = m_pNetworkStream->getInputStreamTimeUs();
     // This deadline for the next buffer in microseconds since the Unix epoch
-    m_targetTime += static_cast<qint64>(framesPerBuffer / m_dSampleRate * 1000000);
+    m_targetTime += static_cast<qint64>(framesPerBuffer / m_sampleRate.toDouble() * 1000000);
     double callbackEntrytoDacSecs = (m_targetTime - currentTime) / 1000000.0;
     callbackEntrytoDacSecs = math_max(callbackEntrytoDacSecs, 0.0001);
     VisualPlayPosition::setCallbackEntryToDacSecs(callbackEntrytoDacSecs, m_clkRefTimer);
@@ -511,11 +525,10 @@ void SoundDeviceNetwork::updateCallbackEntryToDacTime(SINT framesPerBuffer) {
 
 void SoundDeviceNetwork::updateAudioLatencyUsage(SINT framesPerBuffer) {
     m_framesSinceAudioLatencyUsageUpdate += framesPerBuffer;
-    if (m_framesSinceAudioLatencyUsageUpdate
-            > (m_dSampleRate / CPU_USAGE_UPDATE_RATE)) {
+    if (m_framesSinceAudioLatencyUsageUpdate > (m_sampleRate.toDouble() / CPU_USAGE_UPDATE_RATE)) {
         double secInAudioCb = m_timeInAudioCallback.toDoubleSeconds();
         m_audioLatencyUsage.set(secInAudioCb /
-                (m_framesSinceAudioLatencyUsageUpdate / m_dSampleRate));
+                (m_framesSinceAudioLatencyUsageUpdate / m_sampleRate.toDouble()));
         m_timeInAudioCallback = mixxx::Duration::empty();
         m_framesSinceAudioLatencyUsageUpdate = 0;
         // qDebug() << m_audioLatencyUsage->get();
