@@ -1,7 +1,8 @@
 #pragma once
 
+#include <memory>
+
 #include "sources/soundsourceprovider.h"
-#include "util/memory.h"
 
 #define OV_EXCLUDE_STATIC_CALLBACKS
 #include <vorbis/vorbisfile.h>
