@@ -17,7 +17,7 @@ constexpr std::size_t kCanarySize = 1024 * 4;
 constexpr float kMagicFloat = 1234.567890f;
 constexpr float kCanaryFloat = 0.0f;
 constexpr int kChannelCount = 2;
-const QString kReferenceBuffersPath = QStringLiteral("/src/test/reference_buffers/");
+const QString kReferenceBuffersPath = QStringLiteral("reference_buffers/");
 
 class AnalyzerWaveformTest : public MixxxTest {
   protected:
@@ -53,7 +53,7 @@ class AnalyzerWaveformTest : public MixxxTest {
             const QString& reference_title) {
         pWaveform->dump();
 
-        QFile f(QDir::currentPath() + kReferenceBuffersPath + reference_title);
+        QFile f(getTestDir().filePath(kReferenceBuffersPath + reference_title));
         bool pass = true;
         // If the file is not there, we will fail and write out the .actual
         // reference file.
@@ -81,7 +81,7 @@ class AnalyzerWaveformTest : public MixxxTest {
             qWarning() << "Buffer does not match" << reference_title
                        << ", actual buffer written to "
                        << "reference_buffers/" + fname_actual;
-            QFile actualFile(QDir::currentPath() + kReferenceBuffersPath + fname_actual);
+            QFile actualFile(getTestDir().filePath(kReferenceBuffersPath + fname_actual));
             ASSERT_TRUE(actualFile.open(QFile::WriteOnly));
             actualFile.write(actual);
             actualFile.close();
