@@ -5,6 +5,7 @@
 
 #include "audio/types.h"
 #include "track/beats.h"
+#include "track/beatutils.h"
 #include "track/bpm.h"
 
 using namespace mixxx;
@@ -537,4 +538,35 @@ TEST(BeatsTest, ConstTempoFindPrevNextBeatWhenNotOnBeat) {
     EXPECT_NEAR(nextBeat.value(), foundNextBeat.value(), kMaxBeatError);
 }
 
+TEST(BeatsTest, roundBpm) {
+    // Integer Bpm
+    mixxx::Bpm roundBpm = BeatUtils::roundBpmWithinRange(
+            mixxx::Bpm(121.5), mixxx::Bpm(121.9), mixxx::Bpm(122.4));
+    EXPECT_NEAR(roundBpm.value(), 122.0, kMaxBeatError);
+
+    // Half Bpm
+    roundBpm = BeatUtils::roundBpmWithinRange(mixxx::Bpm(80.1), mixxx::Bpm(80.4), mixxx::Bpm(80.7));
+    EXPECT_NEAR(roundBpm.value(), 80.5, kMaxBeatError);
+
+    // High Half Bpm -> 1/3
+    roundBpm = BeatUtils::roundBpmWithinRange(
+            mixxx::Bpm(121.1), mixxx::Bpm(121.4), mixxx::Bpm(122.7));
+    EXPECT_NEAR(roundBpm.value(), 121.3333333333, kMaxBeatError);
+
+    // High Half Bpm -> 1/12
+    roundBpm = BeatUtils::roundBpmWithinRange(
+            mixxx::Bpm(121.4), mixxx::Bpm(121.46), mixxx::Bpm(122.6));
+    EXPECT_NEAR(roundBpm.value(), 121.5, kMaxBeatError);
+
+    // 2/3 Bpm
+    roundBpm = BeatUtils::roundBpmWithinRange(
+            mixxx::Bpm(186.276), mixxx::Bpm(186.621), mixxx::Bpm(186.967));
+    EXPECT_NEAR(roundBpm.value(), 186.666666666, kMaxBeatError);
+
+    // 1/12 Bpm
+    roundBpm = BeatUtils::roundBpmWithinRange(
+            mixxx::Bpm(186.01), mixxx::Bpm(186.1), mixxx::Bpm(186.18));
+    EXPECT_NEAR(roundBpm.value(), 186.0833333333333, kMaxBeatError);
+}
+
 } // namespace
