@@ -68,6 +68,22 @@ class ControllerScriptEngineLegacyTest : public MixxxTest {
     ControllerScriptEngineLegacy* cEngine;
 };
 
+class ControllerScriptEngineLegacyTimerTest : public ControllerScriptEngineLegacyTest {
+  protected:
+    std::unique_ptr<ControlPotmeter> co;
+    std::unique_ptr<ControlPotmeter> coTimerId;
+
+    void SetUp() override {
+        ControllerScriptEngineLegacyTest::SetUp();
+        co = std::make_unique<ControlPotmeter>(ConfigKey("[Test]", "co"), -10.0, 10.0);
+        co->setParameter(0.0);
+        coTimerId = std::make_unique<ControlPotmeter>(
+                ConfigKey("[Test]", "coTimerId"), -10.0, 50.0);
+        coTimerId->setParameter(0.0);
+        EXPECT_TRUE(evaluateAndAssert("engine.setValue('[Test]', 'co', 0.0);"));
+        EXPECT_DOUBLE_EQ(0.0, co->get());
+    }
+};
 TEST_F(ControllerScriptEngineLegacyTest, commonScriptHasNoErrors) {
     QFileInfo commonScript(config()->getResourcePath() +
             QStringLiteral("/controllers/common-controller-scripts.js"));
@@ -257,7 +273,7 @@ TEST_F(ControllerScriptEngineLegacyTest, trigger) {
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "var connection = engine.connectControl('[Test]', 'co', reaction);"
             "engine.trigger('[Test]', 'co');"));
@@ -279,7 +295,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectControl_ByString) {
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "engine.connectControl('[Test]', 'co', 'reaction');"
             "engine.trigger('[Test]', 'co');"
@@ -306,7 +322,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectControl_ByStringForbidDuplicateC
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "engine.connectControl('[Test]', 'co', 'reaction');"
             "engine.connectControl('[Test]', 'co', 'reaction');"
@@ -329,7 +345,7 @@ TEST_F(ControllerScriptEngineLegacyTest,
 
     QString script(
             "var incrementCounterCO = function () {"
-            "  var counter = engine.getValue('[Test]', 'counter');"
+            "  let counter = engine.getValue('[Test]', 'counter');"
             "  engine.setValue('[Test]', 'counter', counter + 1);"
             "};"
             "var connection1 = engine.connectControl('[Test]', 'co', 'incrementCounterCO');"
@@ -337,7 +353,7 @@ TEST_F(ControllerScriptEngineLegacyTest,
             // to check that disconnecting one does not disconnect both.
             "var connection2 = engine.connectControl('[Test]', 'co', 'incrementCounterCO');"
             "function changeTestCoValue() {"
-            "  var testCoValue = engine.getValue('[Test]', 'co');"
+            "  let testCoValue = engine.getValue('[Test]', 'co');"
             "  engine.setValue('[Test]', 'co', testCoValue + 1);"
             "};"
             "function disconnectConnection2() {"
@@ -367,7 +383,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectControl_ByFunction) {
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "var connection = engine.connectControl('[Test]', 'co', reaction);"
             "connection.trigger();"));
@@ -385,7 +401,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectControl_ByFunctionAllowDuplicate
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "engine.connectControl('[Test]', 'co', reaction);"
             "engine.connectControl('[Test]', 'co', reaction);"
@@ -409,7 +425,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectControl_toDisconnectRemovesAllCo
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "engine.connectControl('[Test]', 'co', reaction);"
             "engine.connectControl('[Test]', 'co', reaction);"
@@ -433,7 +449,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectControl_ByLambda) {
 
     EXPECT_TRUE(evaluateAndAssert(
             "var connection = engine.connectControl('[Test]', 'co', function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); });"
             "connection.trigger();"
             "function disconnect() { "
@@ -456,7 +472,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionObject_Disconnect) {
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "var connection = engine.makeConnection('[Test]', 'co', reaction);"
             "connection.trigger();"
@@ -480,15 +496,15 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionObject_reflectDisconnect) {
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(success) { "
             "  if (success) {"
-            "    var pass = engine.getValue('[Test]', 'passed');"
+            "    let pass = engine.getValue('[Test]', 'passed');"
             "    engine.setValue('[Test]', 'passed', pass + 1.0); "
             "  }"
             "};"
-            "var dummy_callback = function(value) {};"
-            "var connection = engine.makeConnection('[Test]', 'co', dummy_callback);"
+            "let dummy_callback = function(value) {};"
+            "let connection = engine.makeConnection('[Test]', 'co', dummy_callback);"
             "reaction(connection);"
             "reaction(connection.isConnected);"
-            "var successful_disconnect = connection.disconnect();"
+            "let successful_disconnect = connection.disconnect();"
             "reaction(successful_disconnect);"
             "reaction(!connection.isConnected);"));
     processEvents();
@@ -508,7 +524,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionObject_DisconnectByPassingToC
 
     EXPECT_TRUE(evaluateAndAssert(
             "var reaction = function(value) { "
-            "  var pass = engine.getValue('[Test]', 'passed');"
+            "  let pass = engine.getValue('[Test]', 'passed');"
             "  engine.setValue('[Test]', 'passed', pass + 1.0); };"
             "var connection1 = engine.connectControl('[Test]', 'co', reaction);"
             "var connection2 = engine.connectControl('[Test]', 'co', reaction);"
@@ -545,7 +561,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionObject_MakesIndependentConnec
 
     EXPECT_TRUE(evaluateAndAssert(
             "var incrementCounterCO = function () {"
-            "  var counter = engine.getValue('[Test]', 'counter');"
+            "  let counter = engine.getValue('[Test]', 'counter');"
             "  engine.setValue('[Test]', 'counter', counter + 1);"
             "};"
             "var connection1 = engine.makeConnection('[Test]', 'co', incrementCounterCO);"
@@ -553,7 +569,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionObject_MakesIndependentConnec
             // to check that disconnecting one does not disconnect both.
             "var connection2 = engine.makeConnection('[Test]', 'co', incrementCounterCO);"
             "function changeTestCoValue() {"
-            "  var testCoValue = engine.getValue('[Test]', 'co');"
+            "  let testCoValue = engine.getValue('[Test]', 'co');"
             "  engine.setValue('[Test]', 'co', testCoValue + 1);"
             "}"
             "function disconnectConnection1() {"
@@ -583,7 +599,7 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionObject_trigger) {
 
     EXPECT_TRUE(evaluateAndAssert(
             "var incrementCounterCO = function () {"
-            "  var counter = engine.getValue('[Test]', 'counter');"
+            "  let counter = engine.getValue('[Test]', 'counter');"
             "  engine.setValue('[Test]', 'counter', counter + 1);"
             "};"
             "var connection1 = engine.makeConnection('[Test]', 'co', incrementCounterCO);"
@@ -620,3 +636,250 @@ TEST_F(ControllerScriptEngineLegacyTest, connectionExecutesWithCorrectThisObject
     // The counter should have been incremented exactly once.
     EXPECT_DOUBLE_EQ(1.0, pass->get());
 }
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_repeatedTimer) {
+    EXPECT_TRUE(evaluateAndAssert(
+            "engine.setValue('[Test]', 'co', 0.0);"));
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+
+    EXPECT_TRUE(
+            evaluateAndAssert(R"(engine.beginTimer(50, function() {
+                                    let x = engine.getValue('[Test]', 'co');
+                                    x++; 
+                                    engine.setValue('[Test]', 'co', x);
+                                 }, false);)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+
+    cEngine->thread()->msleep(70);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(1.0, co->get());
+
+    cEngine->thread()->msleep(140);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(2.0, co->get());
+}
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_singleShotTimer) {
+    EXPECT_TRUE(evaluateAndAssert(
+            "engine.setValue('[Test]', 'co', 0.0);"));
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+
+    // Single shot timer with minimum allowed interval of 20ms
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(engine.beginTimer(20, function() {
+                   engine.setValue('[Test]', 'co', 1.0);
+               }, true);)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(1.0, co->get());
+}
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_singleShotTimerBindFunction) {
+    // Single shot timer with minimum allowed interval of 20ms
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(var globVar = 7;
+            timerId = engine.beginTimer(20, function () {
+                engine.setValue('[Test]', 'co', this.globVar);
+                this.globVar++;
+                engine.setValue('[Test]', 'coTimerId', timerId + 10);
+            }.bind(this), true);            
+            engine.setValue('[Test]', 'coTimerId', timerId);)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+    double timerId = coTimerId->get();
+    EXPECT_TRUE(timerId > 0);
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(timerId + 10, coTimerId->get());
+    EXPECT_DOUBLE_EQ(7.0, co->get());
+    EXPECT_TRUE(evaluateAndAssert("engine.setValue('[Test]', 'co', this.globVar);"));
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(8.0, co->get());
+}
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_singleShotTimerArrowFunction) {
+    // Single shot timer with minimum allowed interval of 20ms
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(var globVar = 7;
+            timerId = engine.beginTimer(20, () => {
+                engine.setValue('[Test]', 'co', this.globVar);
+                this.globVar++;
+                engine.setValue('[Test]', 'coTimerId', timerId + 10);
+            }, true);            
+            engine.setValue('[Test]', 'coTimerId', timerId);)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+    double timerId = coTimerId->get();
+    EXPECT_TRUE(timerId > 0);
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(timerId + 10, coTimerId->get());
+    EXPECT_DOUBLE_EQ(7.0, co->get());
+    EXPECT_TRUE(evaluateAndAssert("engine.setValue('[Test]', 'co', this.globVar);"));
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(8.0, co->get());
+}
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_singleShotTimerBindFunctionInClass) {
+    // Single shot timer with minimum allowed interval of 20ms
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(
+            class MyClass {
+               constructor() {
+                  this.timerId = undefined;
+                  this.globVar = 7;
+               }
+               runTimer() {
+                  this.timerId = engine.beginTimer(20, function() {
+                     engine.setValue('[Test]', 'co', this.globVar);
+                     this.globVar++;
+                     engine.setValue('[Test]', 'coTimerId', this.timerId + 10);
+                  }.bind(this), true);            
+                  engine.setValue('[Test]', 'coTimerId', this.timerId);
+               }
+            }
+            var MyMapping = new MyClass();
+            MyMapping.runTimer();)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+    double timerId = coTimerId->get();
+    EXPECT_TRUE(timerId > 0);
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(timerId + 10, coTimerId->get());
+    EXPECT_DOUBLE_EQ(7.0, co->get());
+    EXPECT_TRUE(evaluateAndAssert("engine.setValue('[Test]', 'co', MyMapping.globVar);"));
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(8.0, co->get());
+}
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_singleShotTimerArrowFunctionInClass) {
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(
+            class MyClass {
+               constructor() {
+                  this.timerId = undefined;
+                  this.globVar = 7;
+               }
+               runTimer() {                  
+                  const savedThis = this;
+                  this.timerId = engine.beginTimer(20, () => {
+                     if (savedThis !== this) { throw new Error("savedThis should be equal to this"); }
+                     if (!(this instanceof MyClass)) { throw new Error("this should be an instance of MyClass"); }
+                     engine.setValue('[Test]', 'co', this.globVar);
+                     this.globVar++;
+                     engine.setValue('[Test]', 'coTimerId', this.timerId + 10);
+                  }, true);            
+                  engine.setValue('[Test]', 'coTimerId', this.timerId);
+               }
+            }
+            var MyMapping = new MyClass();
+            MyMapping.runTimer();)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(0.0, co->get());
+    double timerId = coTimerId->get();
+    EXPECT_TRUE(timerId > 0);
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(timerId + 10, coTimerId->get());
+    EXPECT_DOUBLE_EQ(7.0, co->get());
+    EXPECT_TRUE(evaluateAndAssert("engine.setValue('[Test]', 'co', MyMapping.globVar);"));
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(8.0, co->get());
+}
+
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_repeatedTimerArrowFunctionCallInClass) {
+    // Single shot timer with minimum allowed interval of 20ms
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(
+            class MyClass {
+               constructor() {
+                  this.timerId = undefined;
+                  this.globVar = 7;
+               }
+               stopTimer() {
+                  if (!(this instanceof MyClass)) { throw new Error("this should be an instance of MyClass"); }
+                  engine.stopTimer(this.timerId);
+                  this.timerId = 0;
+                  engine.setValue('[Test]', 'coTimerId', this.timerId + 20);
+               }
+               runTimer() {
+                  this.timerId = engine.beginTimer(20, () => this.stopTimer(), false);                  
+                  engine.setValue('[Test]', 'co', this.globVar);      
+                  engine.setValue('[Test]', 'coTimerId', this.timerId);
+               }
+            }
+            var MyMapping = new MyClass();
+            MyMapping.runTimer();)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(7.0, co->get());
+    double timerId = coTimerId->get();
+    EXPECT_TRUE(timerId > 0);
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(20, coTimerId->get());
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(20, coTimerId->get());
+}
+TEST_F(ControllerScriptEngineLegacyTimerTest, beginTimer_repeatedTimerThisFunctionCallInClass) {
+    // Single shot timer with minimum allowed interval of 20ms
+    EXPECT_TRUE(evaluateAndAssert(
+            R"(
+            class MyClass {
+               constructor() {
+                  this.timerId = undefined;
+                  this.globVar = 7;
+               }
+               stopTimer() {    
+                  if (!(this instanceof MyClass)) {throw new Error("this should be an instance of MyClass");}
+                  engine.stopTimer(this.timerId);
+                  this.timerId = 0;
+                  engine.setValue('[Test]', 'coTimerId', this.timerId + 20);
+               }
+               runTimer() {
+                  this.timerId = engine.beginTimer(20, this.stopTimer.bind(this), false);              
+                  engine.setValue('[Test]', 'co', this.globVar);
+                  engine.setValue('[Test]', 'coTimerId', this.timerId);
+               }
+            }
+            var MyMapping = new MyClass();
+            MyMapping.runTimer();)"));
+    processEvents();
+    EXPECT_DOUBLE_EQ(7.0, co->get());
+    double timerId = coTimerId->get();
+    EXPECT_TRUE(timerId > 0);
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(20, coTimerId->get());
+
+    cEngine->thread()->msleep(35);
+    processEvents();
+
+    EXPECT_DOUBLE_EQ(20, coTimerId->get());
+}
