@@ -1,8 +1,9 @@
 #include <gtest/gtest.h>
+
 #include <QtDebug>
+#include <memory>
 
 #include "control/controlobject.h"
-#include "util/memory.h"
 #include "test/mixxxtest.h"
 
 namespace {
