@@ -1,31 +1,39 @@
 // Tests for enginebuffer.cpp
 
-#include <gtest/gtest.h>
 #include <gmock/gmock.h>
-#include <QtDebug>
-#include <QTest>
+#include <gtest/gtest.h>
 
+#include <QString>
+#include <QTest>
+#include <QtDebug>
+
+#include "control/controlobject.h"
+#include "engine/controls/ratecontrol.h"
 #include "mixer/basetrackplayer.h"
 #include "preferences/usersettings.h"
-#include "control/controlobject.h"
-#include "test/mockedenginebackendtest.h"
 #include "test/mixxxtest.h"
+#include "test/mockedenginebackendtest.h"
 #include "test/signalpathtest.h"
-#include "engine/controls/ratecontrol.h"
 
 // In case any of the test in this file fail. You can use the audioplot.py tool
 // in the tools folder to visually compare the results of the enginebuffer
 // with the golden test data.
 
+namespace {
+const QString kAppGroup = QStringLiteral("[App]");
+}
+
 class EngineBufferTest : public MockedEngineBackendTest {};
 
 class EngineBufferE2ETest : public SignalPathTest {};
 
 TEST_F(EngineBufferTest, DisableKeylockResetsPitch) {
-    // To prevent one-slider users from getting stuck on a key, unsetting
-    // keylock resets the musical pitch.
+    // To prevent one-slider users from getting stuck on a key,
+    // KeyunlockMode::ResetLockedKey resets the musical pitch.
     ControlObject::set(ConfigKey(m_sGroup1, "keylockMode"),
-                       1.0);  // kLockCurrentKey;
+            1.0); // KeylockMode::LockCurrentKey
+    ControlObject::set(ConfigKey(m_sGroup1, "keyunlockMode"),
+            0.0); // KeyunlockMode::ResetLockedKey
     ControlObject::set(ConfigKey(m_sGroup1, "file_bpm"), 128.0);
     ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
     ControlObject::set(ConfigKey(m_sGroup1, "pitch"), 0.5);
@@ -37,6 +45,23 @@ TEST_F(EngineBufferTest, DisableKeylockResetsPitch) {
     ASSERT_EQ(0.0, ControlObject::get(ConfigKey(m_sGroup1, "pitch")));
 }
 
+TEST_F(EngineBufferTest, DisableKeylockKeepsPitch) {
+    // Pitch must not change when unlocking with KeyunlockMode::KeepLockedKey.
+    ControlObject::set(ConfigKey(m_sGroup1, "keylockMode"),
+            1.0); // KeylockMode::LockCurrentKey
+    ControlObject::set(ConfigKey(m_sGroup1, "keyunlockMode"),
+            1.0); // KeyunlockMode::KeepLockedKey
+    ControlObject::set(ConfigKey(m_sGroup1, "file_bpm"), 128.0);
+    ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
+    ControlObject::set(ConfigKey(m_sGroup1, "pitch"), 0.5);
+    ProcessBuffer();
+
+    ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 0.0);
+    // We require a buffer process to see that the keylock state has changed.
+    ProcessBuffer();
+    ASSERT_NEAR(0.5, ControlObject::get(ConfigKey(m_sGroup1, "pitch")), 1e-10);
+}
+
 TEST_F(EngineBufferTest, TrackLoadResetsPitch) {
     // When a new track is loaded, the pitch value should be reset.
     config()->set(ConfigKey("[Controls]","SpeedAutoReset"),
@@ -53,12 +78,14 @@ TEST_F(EngineBufferTest, TrackLoadResetsPitch) {
 TEST_F(EngineBufferTest, PitchRoundtrip) {
     ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 0.0);
     ControlObject::set(ConfigKey(m_sGroup1, "keylockMode"),
-                       0.0);  // kLockOriginalKey;
+            0.0); // KeylockMode::LockOriginalKey
+    ControlObject::set(ConfigKey(m_sGroup1, "keyunlockMode"),
+            0.0); // KeyunlockMode::ResetLockedKey
     ProcessBuffer();
     // we are in kPakmOffsetScaleReseting mode
     ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.5);
     ProcessBuffer();
-    // pitch must not change
+    // pitch_adjust must not change
     ASSERT_DOUBLE_EQ(0.0,
                      ControlObject::get(ConfigKey(m_sGroup1, "pitch_adjust")));
 
@@ -69,28 +96,30 @@ TEST_F(EngineBufferTest, PitchRoundtrip) {
 
     ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
     ProcessBuffer();
-    // pitch and speed must not change
-    ASSERT_DOUBLE_EQ(0.5,
-                     ControlObject::get(ConfigKey(m_sGroup1, "pitch_adjust")));
+    // pitch is reset, as well as pitch_adjust
+    // speed must not change, pitch and pitch_adjust must be 0
     ASSERT_DOUBLE_EQ(0.5, ControlObject::get(ConfigKey(m_sGroup1, "rate")));
+    ASSERT_DOUBLE_EQ(0.0, ControlObject::get(ConfigKey(m_sGroup1, "pitch")));
+    ASSERT_DOUBLE_EQ(0.0, ControlObject::get(ConfigKey(m_sGroup1, "pitch_adjust")));
 
     ControlObject::set(ConfigKey(m_sGroup1, "keylockMode"),
-                       1.0);  // kLockCurrentKey;
+            1.0); // KeylockMode::LockCurrentKey
     ProcessBuffer();
     // rate must not change
     ASSERT_DOUBLE_EQ(0.5, ControlObject::get(ConfigKey(m_sGroup1, "rate")));
     // pitch must reflect the absolute pitch
-    ASSERT_NEAR(0.5, ControlObject::get(ConfigKey(m_sGroup1, "pitch")), 1e-10);
+    ASSERT_DOUBLE_EQ(0.0, ControlObject::get(ConfigKey(m_sGroup1, "pitch")));
 
     ControlObject::set(ConfigKey(m_sGroup1, "keylockMode"),
-                       0.0);  // kLockOriginalKey;
+            0.0); // KeylockMode::LockOriginalKey
     ProcessBuffer();
     // rate must not change
-    ASSERT_NEAR(0.5, ControlObject::get(ConfigKey(m_sGroup1, "pitch")), 1e-10);
-    // pitch must reflect the pitch shift only
     ASSERT_DOUBLE_EQ(0.5, ControlObject::get(ConfigKey(m_sGroup1, "rate")));
+    // pitch must be 0
+    ASSERT_NEAR(0.0, ControlObject::get(ConfigKey(m_sGroup1, "pitch")), 1e-10);
 }
 
+#ifdef __RUBBERBAND__
 TEST_F(EngineBufferTest, SlowRubberBand) {
     // At very slow speeds, RubberBand needs to reallocate buffers and since
     // this
@@ -102,8 +131,8 @@ TEST_F(EngineBufferTest, SlowRubberBand) {
     ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0072);
 
     // With Soundtouch, it should switch the scaler as well
-    ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                       static_cast<double>(EngineBuffer::SOUNDTOUCH));
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::SoundTouch));
     ProcessBuffer();
     EXPECT_EQ(m_pMockScaleVinyl1, m_pChannel1->getEngineBuffer()->m_pScale);
 
@@ -112,18 +141,19 @@ TEST_F(EngineBufferTest, SlowRubberBand) {
     ProcessBuffer();
 
     // With Rubberband, and transport stopped it should be still keylock
-    ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                       static_cast<double>(EngineBuffer::RUBBERBAND));
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::RubberBandFaster));
     ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0);
     ProcessBuffer();
     EXPECT_EQ(m_pMockScaleKeylock1, m_pChannel1->getEngineBuffer()->m_pScale);
 
     ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0072);
 
-    // Paying at low rate, the vinyl scaler should be used
+    // Playing at low rate, the vinyl scaler should be used
     ProcessBuffer();
     EXPECT_EQ(m_pMockScaleVinyl1, m_pChannel1->getEngineBuffer()->m_pScale);
 }
+#endif
 
 TEST_F(EngineBufferTest, ScalerNoTransport) {
     // normally use the Vinyl scaler
@@ -204,8 +234,8 @@ TEST_F(EngineBufferTest, ResetPitchAdjustUsesLinear) {
 TEST_F(EngineBufferE2ETest, SoundTouchCrashTest) {
     // Soundtouch has a bug where a pitch value of zero causes an infinite loop
     // and crash.
-    ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                       static_cast<double>(EngineBuffer::SOUNDTOUCH));
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::SoundTouch));
     ControlObject::set(ConfigKey(m_sGroup1, "pitch"), 1.2);
     ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.05);
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
@@ -225,15 +255,18 @@ TEST_F(EngineBufferE2ETest, BasicProcessingTest) {
     ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.05);
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "BasicProcessingTestPlay");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "BasicProcessingTestPlay");
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "BasicProcessingTestPlaying");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "BasicProcessingTestPlaying");
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 0.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "BasicProcessingTestPause");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "BasicProcessingTestPause");
 }
 
 TEST_F(EngineBufferE2ETest, ScratchTest) {
@@ -241,13 +274,14 @@ TEST_F(EngineBufferE2ETest, ScratchTest) {
     // to the other.
     ControlObject::set(ConfigKey(m_sGroup1, "scratch2_enable"), 1.0);
     ControlObject::set(ConfigKey(m_sGroup1, "scratch2"), 1.1);
-    m_pChannel1->getEngineBuffer()->queueNewPlaypos(450,
-                                                    EngineBuffer::SEEK_EXACT);
+    m_pChannel1->getEngineBuffer()->queueNewPlaypos(
+            mixxx::audio::FramePos(225), EngineBuffer::SEEK_EXACT);
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "scratch2"), -1.1);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "ScratchTestMaster");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "ScratchTestMain");
 }
 
 TEST_F(EngineBufferE2ETest, ScratchTestStart) {
@@ -260,8 +294,9 @@ TEST_F(EngineBufferE2ETest, ScratchTestStart) {
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "scratch2"), 0.5);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "ScratchTestStart");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "ScratchTestStart");
 }
 
 TEST_F(EngineBufferE2ETest, ReverseTest) {
@@ -271,61 +306,70 @@ TEST_F(EngineBufferE2ETest, ReverseTest) {
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "reverse"), 1.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "ReverseTest");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "ReverseTest");
 }
 
 // DISABLED: This test is too dependent on the sound touch library version.
 TEST_F(EngineBufferE2ETest, DISABLED_SoundTouchToggleTest) {
    // Test various cases where SoundTouch toggles on and off.
-   ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                      static_cast<double>(EngineBuffer::SOUNDTOUCH));
-   ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.5);
-   ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
-   ProcessBuffer();
-   // Test transition from vinyl to keylock
-   ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
-   ProcessBuffer();
-   assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                kProcessBufferSize, "SoundTouchTest");
-   // Test transition from keylock to vinyl due to slow speed.
-   ControlObject::set(ConfigKey(m_sGroup1, "play"), 0.0);
-   ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0072);
-   ProcessBuffer();
-   assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                kProcessBufferSize, "SoundTouchTestSlow");
-   // Test transition back to keylock due to regular speed.
-   ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 1.0);
-   ProcessBuffer();
-   assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                kProcessBufferSize, "SoundTouchTestRegular");
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::SoundTouch));
+    ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.5);
+    ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
+    ProcessBuffer();
+    // Test transition from vinyl to keylock
+    ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
+    ProcessBuffer();
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "SoundTouchTest");
+    // Test transition from keylock to vinyl due to slow speed.
+    ControlObject::set(ConfigKey(m_sGroup1, "play"), 0.0);
+    ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0072);
+    ProcessBuffer();
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "SoundTouchTestSlow");
+    // Test transition back to keylock due to regular speed.
+    ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 1.0);
+    ProcessBuffer();
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "SoundTouchTestRegular");
 }
 
+#ifdef __RUBBERBAND__
 // DISABLED: This test is too dependent on the rubber band library version.
 TEST_F(EngineBufferE2ETest, DISABLED_RubberbandToggleTest) {
    // Test various cases where Rubberband toggles on and off.
-   ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                      static_cast<double>(EngineBuffer::RUBBERBAND));
-   ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.5);
-   ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
-   ProcessBuffer();
-   // Test transition from vinyl to keylock
-   ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
-   ProcessBuffer();
-   assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                kProcessBufferSize, "RubberbandTest");
-   // Test transition from keylock to vinyl due to slow speed.
-   ControlObject::set(ConfigKey(m_sGroup1, "play"), 0.0);
-   ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0072);
-   ProcessBuffer();
-   assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                kProcessBufferSize, "RubberbandTestSlow");
-   // Test transition back to keylock due to regular speed.
-   ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 1.0);
-   ProcessBuffer();
-   assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                kProcessBufferSize, "RubberbandTestRegular");
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::RubberBandFaster));
+    ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.5);
+    ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
+    ProcessBuffer();
+    // Test transition from vinyl to keylock
+    ControlObject::set(ConfigKey(m_sGroup1, "keylock"), 1.0);
+    ProcessBuffer();
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "RubberbandTest");
+    // Test transition from keylock to vinyl due to slow speed.
+    ControlObject::set(ConfigKey(m_sGroup1, "play"), 0.0);
+    ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 0.0072);
+    ProcessBuffer();
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "RubberbandTestSlow");
+    // Test transition back to keylock due to regular speed.
+    ControlObject::set(ConfigKey(m_sGroup1, "rateSearch"), 1.0);
+    ProcessBuffer();
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "RubberbandTestRegular");
 }
+#endif
 
 // DISABLED: This test is too dependent on the sound touch library version.
 // NOTE(uklotzde, 2018-01-10): We have also seen spurious failures on the
@@ -335,8 +379,8 @@ TEST_F(EngineBufferE2ETest, DISABLED_RubberbandToggleTest) {
 TEST_F(EngineBufferE2ETest, DISABLED_KeylockReverseTest) {
     // Confirm that when toggling reverse while keylock is on, interpolation
     // is smooth.
-    ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                       static_cast<double>(EngineBuffer::SOUNDTOUCH));
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::SoundTouch));
     ControlObject::set(ConfigKey(m_sGroup1, "keylockMode"),
                        0.0);
     ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.5);
@@ -345,8 +389,9 @@ TEST_F(EngineBufferE2ETest, DISABLED_KeylockReverseTest) {
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "reverse"), 1.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "KeylockReverseTest");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "KeylockReverseTest");
 }
 
 TEST_F(EngineBufferE2ETest, SeekTest) {
@@ -354,18 +399,19 @@ TEST_F(EngineBufferE2ETest, SeekTest) {
     ControlObject::set(ConfigKey(m_sGroup1, "rate"), 0.0);
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
     ProcessBuffer();
-    m_pChannel1->getEngineBuffer()->queueNewPlaypos(1000,
-                                                    EngineBuffer::SEEK_EXACT);
+    m_pChannel1->getEngineBuffer()->queueNewPlaypos(
+            mixxx::audio::FramePos(500), EngineBuffer::SEEK_EXACT);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "SeekTest");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "SeekTest");
 }
 
 TEST_F(EngineBufferE2ETest, SoundTouchReverseTest) {
     // This test must not crash when changing to reverse while pitch is tweaked
-    // Testing bug #1458263
-    ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                       static_cast<double>(EngineBuffer::SOUNDTOUCH));
+    // Testing issue #8061
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::SoundTouch));
     ControlObject::set(ConfigKey(m_sGroup1, "pitch"), -1);
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
     ProcessBuffer();
@@ -375,11 +421,12 @@ TEST_F(EngineBufferE2ETest, SoundTouchReverseTest) {
     // on the uses library version
 }
 
+#ifdef __RUBBERBAND__
 TEST_F(EngineBufferE2ETest, RubberbandReverseTest) {
     // This test must not crash when changing to reverse while pitch is tweaked
-    // Testing bug #1458263
-    ControlObject::set(ConfigKey("[Master]", "keylock_engine"),
-                       static_cast<double>(EngineBuffer::RUBBERBAND));
+    // Testing issue #8061
+    ControlObject::set(ConfigKey(kAppGroup, QStringLiteral("keylock_engine")),
+            static_cast<double>(EngineBuffer::KeylockEngine::RubberBandFaster));
     ControlObject::set(ConfigKey(m_sGroup1, "pitch"), -1);
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
     ProcessBuffer();
@@ -388,49 +435,53 @@ TEST_F(EngineBufferE2ETest, RubberbandReverseTest) {
     // Note: we cannot compare a golden buffer here, because the result depends
     // on the uses library version
 }
+#endif
 
 TEST_F(EngineBufferE2ETest, CueGotoAndStopTest) {
     // Be sure, that the Crossfade buffer is processed only once
-    // Bug #1504838
+    // Issue #8251
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "cue_gotoandstop"), 1.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "CueGotoAndStopTest");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "CueGotoAndStopTest");
 }
 
 TEST_F(EngineBufferE2ETest, CueGotoAndPlayTest) {
     // Be sure, cue seek is not overwritten by quantization seek
-    // Bug #1504503
+    // Issue #8249
     ControlObject::set(ConfigKey(m_sGroup1, "quantize"), 1.0);
     ControlObject::set(ConfigKey(m_sGroup1, "cue_point"), 0.0);
     m_pChannel1->getEngineBuffer()->queueNewPlaypos(
-            1000, EngineBuffer::SEEK_EXACT);
+            mixxx::audio::FramePos(500), EngineBuffer::SEEK_EXACT);
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "cue_gotoandplay"), 1.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "CueGotoAndPlayTest");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "CueGotoAndPlayTest");
 }
 
 TEST_F(EngineBufferE2ETest, CueStartPlayTest) {
     // Be sure, cue seek is not overwritten by quantization seek
-    // Bug #1504851
+    // Issue #8252
     ControlObject::set(ConfigKey(m_sGroup1, "play"), 1.0);
     ProcessBuffer();
     ControlObject::set(ConfigKey(m_sGroup1, "start_play"), 1.0);
     ProcessBuffer();
-    assertBufferMatchesReference(m_pEngineMaster->masterBuffer(),
-                                 kProcessBufferSize, "StartPlayTest");
+    assertBufferMatchesReference(m_pEngineMixer->getMainBuffer(),
+            kProcessBufferSize,
+            "StartPlayTest");
 }
 
 TEST_F(EngineBufferE2ETest, CueGotoAndPlayDenon) {
     // Be sure, cue point is not moved
-    // enable Denon mode Bug #1504934
+    // enable Denon mode issue #8254
     ControlObject::set(ConfigKey(m_sGroup1, "cue_mode"), 2.0); // CUE_MODE_DENON
     m_pChannel1->getEngineBuffer()->queueNewPlaypos(
-            1000, EngineBuffer::SEEK_EXACT);
+            mixxx::audio::FramePos(500), EngineBuffer::SEEK_EXACT);
     ProcessBuffer();
     double cueBefore = ControlObject::get(ConfigKey(m_sGroup1, "cue_point"));
     ControlObject::set(ConfigKey(m_sGroup1, "cue_gotoandplay"), 1.0);
