@@ -4,7 +4,6 @@
 
 #include "control/control.h"
 #include "library/coverartutils.h"
-#include "sources/soundsourceproxy.h"
 #include "util/cmdlineargs.h"
 #include "util/logging.h"
 
@@ -21,11 +20,11 @@ QString makeTestConfigFile(const QString& path) {
 
 // Static initialization
 QScopedPointer<MixxxApplication> MixxxTest::s_pApplication;
+QDir MixxxTest::s_TestDir;
 
 MixxxTest::ApplicationScope::ApplicationScope(int& argc, char** argv) {
-    // Construct a list of strings based on the command line arguments
     CmdlineArgs args;
-    const bool argsParsed = args.Parse(argc, argv);
+    const bool argsParsed = args.parse(argc, argv);
     Q_UNUSED(argsParsed);
     DEBUG_ASSERT(argsParsed);
 
@@ -46,11 +45,6 @@ MixxxTest::ApplicationScope::ApplicationScope(int& argc, char** argv) {
 
     DEBUG_ASSERT(s_pApplication.isNull());
     s_pApplication.reset(new MixxxApplication(argc, argv));
-
-    const bool providersRegistered =
-            SoundSourceProxy::registerProviders();
-    Q_UNUSED(providersRegistered);
-    DEBUG_ASSERT(providersRegistered);
 }
 
 MixxxTest::ApplicationScope::~ApplicationScope() {
@@ -84,29 +78,13 @@ void MixxxTest::saveAndReloadConfig() {
 
 namespace mixxxtest {
 
-bool copyFile(const QString& srcFileName, const QString& dstFileName) {
+void copyFile(const QString& srcFileName, const QString& dstFileName) {
     auto srcFile = QFile(srcFileName);
-    DEBUG_ASSERT(srcFile.exists());
-    VERIFY_OR_DEBUG_ASSERT(srcFile.copy(dstFileName)) {
-        qWarning()
-                << srcFile.errorString()
-                << "- Failed to copy file"
-                << srcFile.fileName()
-                << "->"
-                << dstFileName;
-        return false;
-    }
+    ASSERT_TRUE(srcFile.exists());
+    ASSERT_TRUE(srcFile.copy(dstFileName));
     auto dstFile = QFile(dstFileName);
-    VERIFY_OR_DEBUG_ASSERT(dstFile.exists()) {
-        return false;
-    }
-    if (srcFile.size() != dstFile.size()) {
-        dstFile.remove();
-        DEBUG_ASSERT(!"dstFile size does not match srcFile");
-        return false;
-    }
-
-    return true;
+    ASSERT_TRUE(dstFile.exists());
+    ASSERT_EQ(dstFile.size(), srcFile.size());
 }
 
 } // namespace mixxxtest
