@@ -10,11 +10,11 @@
 #include "track/track.h"
 #include "util/assert.h"
 
-TrackPointer newTestTrack(int sampleRate) {
+TrackPointer newTestTrack() {
     TrackPointer pTrack(Track::newTemporary());
     pTrack->setAudioProperties(
             mixxx::audio::ChannelCount(2),
-            mixxx::audio::SampleRate(sampleRate),
+            mixxx::audio::SampleRate(44100),
             mixxx::audio::Bitrate(),
             mixxx::Duration::fromSeconds(180));
     return pTrack;
@@ -351,18 +351,17 @@ TEST_F(SearchQueryParserTest, TextFilterNegation) {
 
 TEST_F(SearchQueryParserTest, NumericFilter) {
     m_parser.setSearchColumns({"artist", "album"});
-    auto pQuery(
-            m_parser.parseQuery("bpm:127.12", QString()));
+    auto pQuery(m_parser.parseQuery("bitrate:127", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
-    pTrack->trySetBpm(127);
+    TrackPointer pTrack = newTestTrack();
+    pTrack->setBitrate(128);
     EXPECT_FALSE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.12);
+    pTrack->setBitrate(127);
     EXPECT_TRUE(pQuery->match(pTrack));
 
     EXPECT_STREQ(
-        qPrintable(QString("bpm = 127.12")),
-        qPrintable(pQuery->toSql()));
+            qPrintable(QString("bitrate = 127")),
+            qPrintable(pQuery->toSql()));
 }
 
 TEST_F(SearchQueryParserTest, NumericFilterYear) {
@@ -371,7 +370,7 @@ TEST_F(SearchQueryParserTest, NumericFilterYear) {
     auto pQuery(
             m_parser.parseQuery("year:1969", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
     EXPECT_FALSE(pQuery->match(pTrack));
     // Note: The sourounding spaces are checking that a user input is popperly trimmed.
     pTrack->setYear(" 1969-08-15 ");
@@ -388,11 +387,10 @@ TEST_F(SearchQueryParserTest, NumericFilterYear) {
 
 TEST_F(SearchQueryParserTest, NumericFilterEmpty) {
     m_parser.setSearchColumns({"artist", "album"});
-    auto pQuery(
-            m_parser.parseQuery("bpm:", QString()));
+    auto pQuery(m_parser.parseQuery("bitrate:", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
-    pTrack->trySetBpm(127);
+    TrackPointer pTrack = newTestTrack();
+    pTrack->setBitrate(127);
     EXPECT_TRUE(pQuery->match(pTrack));
 
     EXPECT_STREQ(
@@ -402,84 +400,156 @@ TEST_F(SearchQueryParserTest, NumericFilterEmpty) {
 
 TEST_F(SearchQueryParserTest, NumericFilterNegation) {
     m_parser.setSearchColumns({"artist", "album"});
-    auto pQuery(
-            m_parser.parseQuery("-bpm:127.12", QString()));
+    auto pQuery(m_parser.parseQuery("-bitrate:127", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
-    pTrack->trySetBpm(127);
+    TrackPointer pTrack = newTestTrack();
+    pTrack->setBitrate(129);
     EXPECT_TRUE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.12);
+    pTrack->setBitrate(127);
     EXPECT_FALSE(pQuery->match(pTrack));
 
     EXPECT_STREQ(
-        qPrintable(QString("NOT (bpm = 127.12)")),
-        qPrintable(pQuery->toSql()));
+            qPrintable(QString("NOT (bitrate = 127)")),
+            qPrintable(pQuery->toSql()));
 }
 
 TEST_F(SearchQueryParserTest, NumericFilterAllowsSpace) {
     m_parser.setSearchColumns({"artist", "album"});
-    auto pQuery(
-            m_parser.parseQuery("bpm: 127.12", QString()));
+    auto pQuery(m_parser.parseQuery("bitrate: 127", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
-    pTrack->trySetBpm(127);
+    TrackPointer pTrack = newTestTrack();
+    pTrack->setBitrate(128);
     EXPECT_FALSE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.12);
+    pTrack->setBitrate(127);
     EXPECT_TRUE(pQuery->match(pTrack));
 
-    EXPECT_STREQ(
-        qPrintable(QString("bpm = 127.12")),
-        qPrintable(pQuery->toSql()));
+    EXPECT_STREQ(qPrintable(QString("bitrate = 127")),
+            qPrintable(pQuery->toSql()));
 }
 
 TEST_F(SearchQueryParserTest, NumericFilterOperators) {
     m_parser.setSearchColumns({"artist", "album"});
-    auto pQuery(
-            m_parser.parseQuery("bpm:>127.12", QString()));
+    auto pQuery(m_parser.parseQuery("bitrate:>127", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
-    pTrack->trySetBpm(127.12);
+    TrackPointer pTrack = newTestTrack();
+    pTrack->setBitrate(127);
     EXPECT_FALSE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.13);
+    pTrack->setBitrate(128);
     EXPECT_TRUE(pQuery->match(pTrack));
     EXPECT_STREQ(
-        qPrintable(QString("bpm > 127.12")),
-        qPrintable(pQuery->toSql()));
+            qPrintable(QString("bitrate > 127")),
+            qPrintable(pQuery->toSql()));
 
-    pQuery = m_parser.parseQuery("bpm:>=127.12", QString());
-    pTrack->trySetBpm(127.11);
+    pQuery = m_parser.parseQuery("bitrate:>=127", QString());
+    pTrack->setBitrate(126);
     EXPECT_FALSE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.12);
+    pTrack->setBitrate(127);
     EXPECT_TRUE(pQuery->match(pTrack));
     EXPECT_STREQ(
-        qPrintable(QString("bpm >= 127.12")),
-        qPrintable(pQuery->toSql()));
+            qPrintable(QString("bitrate >= 127")),
+            qPrintable(pQuery->toSql()));
 
-    pQuery = m_parser.parseQuery("bpm:<127.12", QString());
-    pTrack->trySetBpm(127.12);
+    pQuery = m_parser.parseQuery("bitrate:<127", QString());
+    pTrack->setBitrate(127);
     EXPECT_FALSE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.11);
+    pTrack->setBitrate(126);
     EXPECT_TRUE(pQuery->match(pTrack));
     EXPECT_STREQ(
-        qPrintable(QString("bpm < 127.12")),
-        qPrintable(pQuery->toSql()));
+            qPrintable(QString("bitrate < 127")),
+            qPrintable(pQuery->toSql()));
 
-    pQuery = m_parser.parseQuery("bpm:<=127.12", QString());
-    pTrack->trySetBpm(127.13);
+    pQuery = m_parser.parseQuery("bitrate:<=127", QString());
+    pTrack->setBitrate(129);
     EXPECT_FALSE(pQuery->match(pTrack));
-    pTrack->trySetBpm(127.12);
+    pTrack->setBitrate(127);
     EXPECT_TRUE(pQuery->match(pTrack));
     EXPECT_STREQ(
-        qPrintable(QString("bpm <= 127.12")),
-        qPrintable(pQuery->toSql()));
+            qPrintable(QString("bitrate <= 127")),
+            qPrintable(pQuery->toSql()));
+
+    pQuery = m_parser.parseQuery("bitrate:=127", QString());
+    pTrack->setBitrate(129);
+    EXPECT_FALSE(pQuery->match(pTrack));
+    pTrack->setBitrate(127);
+    EXPECT_TRUE(pQuery->match(pTrack));
+    EXPECT_STREQ(
+            qPrintable(QString("bitrate = 127")),
+            qPrintable(pQuery->toSql()));
 }
 
 TEST_F(SearchQueryParserTest, NumericRangeFilter) {
     m_parser.setSearchColumns({"artist", "album"});
-    auto pQuery(
-            m_parser.parseQuery("bpm:127.12-129", QString()));
+    auto pQuery(m_parser.parseQuery("bitrate:127-129", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
+    pTrack->setBitrate(125);
+    EXPECT_FALSE(pQuery->match(pTrack));
+    pTrack->setBitrate(127);
+    EXPECT_TRUE(pQuery->match(pTrack));
+    pTrack->setBitrate(129);
+    EXPECT_TRUE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bitrate BETWEEN 127 AND 129")),
+            qPrintable(pQuery->toSql()));
+}
+
+TEST_F(SearchQueryParserTest, BpmFilter) {
+    m_parser.setSearchColumns({"artist", "album"});
+
+    // Test BpmFilter's MatchModes:
+
+    // HalveDouble even
+    auto pQuery = m_parser.parseQuery("bpm:126", QString());
+    TrackPointer pTrack = newTestTrack();
+    EXPECT_FALSE(pQuery->match(pTrack));
+    pTrack->trySetBpm(126.13);
+    EXPECT_TRUE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("(bpm >= 125.95 AND bpm < 127) OR "
+                               "(bpm >= 62.95 AND bpm < 64) OR "
+                               "(bpm >= 251.95 AND bpm < 254)")),
+            qPrintable(pQuery->toSql()));
+
+    // HalveDouble uneven
+    pQuery = m_parser.parseQuery("bpm:127", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+    pTrack->trySetBpm(127.13);
+    EXPECT_TRUE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("(bpm >= 126.95 AND bpm < 128) OR "
+                               "(bpm >= 62.95 AND bpm < 64.5) OR "
+                               "(bpm >= 253.95 AND bpm < 256)")),
+            qPrintable(pQuery->toSql()));
+
+    // HalveDoubleStrict
+    pQuery = m_parser.parseQuery("bpm:127.12", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+    pTrack->trySetBpm(127.12);
+    EXPECT_TRUE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("(bpm BETWEEN 127.115 AND 127.125) OR "
+                               "(bpm BETWEEN 63.555 AND 63.565) OR "
+                               "(bpm BETWEEN 254.235 AND 254.245)")),
+            qPrintable(pQuery->toSql()));
+
+    // ExplicitStrict
+    // '=' omits halve/double ==> MatchMode::Explicit
+    // decimals engage Strict mode
+    pQuery = m_parser.parseQuery("bpm:=127.12", QString());
+    EXPECT_TRUE(pQuery->match(pTrack));
+    pTrack->trySetBpm(127.13);
+    EXPECT_FALSE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bpm BETWEEN 127.115 AND 127.125")),
+            qPrintable(pQuery->toSql()));
+
+    // Range
+    pQuery = m_parser.parseQuery("bpm:127.12-129", QString());
     pTrack->trySetBpm(125);
     EXPECT_FALSE(pQuery->match(pTrack));
     pTrack->trySetBpm(127.12);
@@ -490,6 +560,58 @@ TEST_F(SearchQueryParserTest, NumericRangeFilter) {
     EXPECT_STREQ(
             qPrintable(QString("bpm BETWEEN 127.12 AND 129")),
             qPrintable(pQuery->toSql()));
+
+    // Fuzzy
+    // Should be enabled by default and default range is 6% (= 75% of default
+    // pitch slider range)
+    pQuery = m_parser.parseQuery("~bpm:100", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+    pTrack->trySetBpm(106);
+    EXPECT_TRUE(pQuery->match(pTrack));
+    pTrack->trySetBpm(94);
+    EXPECT_TRUE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bpm BETWEEN 94 AND 106")),
+            qPrintable(pQuery->toSql()));
+
+    // Test empty BPM (incomplete query)
+    pQuery = m_parser.parseQuery("bpm:", QString());
+    EXPECT_TRUE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("")),
+            qPrintable(pQuery->toSql()));
+
+    // Null
+    pQuery = m_parser.parseQuery("bpm:\"\"", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bpm IS 0")),
+            qPrintable(pQuery->toSql()));
+    // Null
+    pQuery = m_parser.parseQuery("bpm:00.0", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bpm IS 0")),
+            qPrintable(pQuery->toSql()));
+    // Null
+    pQuery = m_parser.parseQuery("bpm:-", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bpm IS 0")),
+            qPrintable(pQuery->toSql()));
+
+    // Invalid ~bpm:= | ~bpm:12-34
+    pQuery = m_parser.parseQuery("~bpm:=106", QString());
+    EXPECT_FALSE(pQuery->match(pTrack));
+
+    EXPECT_STREQ(
+            qPrintable(QString("bpm IS NULL")),
+            qPrintable(pQuery->toSql()));
 }
 
 TEST_F(SearchQueryParserTest, MultipleFilters) {
@@ -497,7 +619,7 @@ TEST_F(SearchQueryParserTest, MultipleFilters) {
     auto pQuery(
             m_parser.parseQuery("bpm:127.12-129 artist:\"com truise\" Colorvision", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
     pTrack->trySetBpm(128);
     EXPECT_FALSE(pQuery->match(pTrack));
     pTrack->setArtist("Com Truise");
@@ -518,7 +640,7 @@ TEST_F(SearchQueryParserTest, ExtraFilterAppended) {
     auto pQuery(
             m_parser.parseQuery("asdf", "1 > 2"));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
     pTrack->setArtist("zxcv");
     EXPECT_FALSE(pQuery->match(pTrack));
     pTrack->setArtist("asdf");
@@ -534,7 +656,7 @@ TEST_F(SearchQueryParserTest, HumanReadableDurationSearch) {
     auto pQuery(
             m_parser.parseQuery("duration:1:30", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
     pTrack->setDuration(91);
     EXPECT_FALSE(pQuery->match(pTrack));
     pTrack->setDuration(90);
@@ -570,7 +692,7 @@ TEST_F(SearchQueryParserTest, HumanReadableDurationSearchWithOperators) {
     auto pQuery(
             m_parser.parseQuery("duration:>1:30", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
     pTrack->setDuration(89);
     EXPECT_FALSE(pQuery->match(pTrack));
     pTrack->setDuration(91);
@@ -672,7 +794,7 @@ TEST_F(SearchQueryParserTest, HumanReadableDurationSearchwithRangeFilter) {
     auto pQuery(
             m_parser.parseQuery("duration:2:30-3:20", QString()));
 
-    TrackPointer pTrack = newTestTrack(44100);
+    TrackPointer pTrack = newTestTrack();
     pTrack->setDuration(80);
     EXPECT_FALSE(pQuery->match(pTrack));
     pTrack->setDuration(150);
@@ -1065,3 +1187,197 @@ TEST_F(SearchQueryParserTest, QueryIsLessSpecific) {
             QStringLiteral("-crate:\"a b c\""),
             QStringLiteral("crate:\"a b c\"")));
 }
+
+TEST_F(SearchQueryParserTest, EmptyOrOperator) {
+    auto pQuery = m_parser.parseQuery("|", QString());
+
+    // An empty OR query matches no tracks.
+    TrackPointer pTrack = Track::newTemporary();
+    EXPECT_FALSE(pQuery->match(pTrack));
+}
+
+TEST_F(SearchQueryParserTest, EmptySpelledOutOrOperator) {
+    auto pQuery = m_parser.parseQuery("OR", QString());
+
+    // An empty OR query matches no tracks.
+    TrackPointer pTrack = Track::newTemporary();
+    EXPECT_FALSE(pQuery->match(pTrack));
+}
+
+TEST_F(SearchQueryParserTest, PrefixedSpelledOutOrOperator) {
+    m_parser.setSearchColumns({"title"});
+
+    // 'OR' needs to have a boundary on the left to be parsed as an operator
+    auto pQuery = m_parser.parseQuery("aOR", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setTitle("aOR");
+    EXPECT_TRUE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setTitle("a");
+    EXPECT_FALSE(pQuery->match(pTrackB));
+}
+
+TEST_F(SearchQueryParserTest, SuffixedSpelledOutOrOperator) {
+    m_parser.setSearchColumns({"title"});
+
+    // 'OR' needs to have a boundary on the right to be parsed as an operator
+    auto pQuery = m_parser.parseQuery("ORa", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setTitle("ORa");
+    EXPECT_TRUE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setTitle("a");
+    EXPECT_FALSE(pQuery->match(pTrackB));
+}
+
+TEST_F(SearchQueryParserTest, LowercaseOr) {
+    m_parser.setSearchColumns({"title"});
+
+    // Lowercase 'or' is not parsed as an operator and treated literally instead
+    auto pQuery = m_parser.parseQuery("or", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setTitle("or");
+    EXPECT_TRUE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setTitle("and");
+    EXPECT_FALSE(pQuery->match(pTrackB));
+
+    TrackPointer pTrackC = newTestTrack();
+    pTrackC->setTitle("OR");
+    EXPECT_TRUE(pQuery->match(pTrackC));
+}
+
+TEST_F(SearchQueryParserTest, QuotedOr) {
+    m_parser.setSearchColumns({"title"});
+
+    // Quoted uppercase 'OR' is treated literally too.
+    auto pQuery = m_parser.parseQuery("\"OR\"", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setTitle("or");
+    EXPECT_TRUE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setTitle("and");
+    EXPECT_FALSE(pQuery->match(pTrackB));
+
+    TrackPointer pTrackC = newTestTrack();
+    pTrackC->setTitle("OR");
+    EXPECT_TRUE(pQuery->match(pTrackC));
+}
+
+TEST_F(SearchQueryParserTest, DurationSearchWithOrOperator) {
+    // Query is intentionally "misformatted" to ensure whitespace-invariance
+    auto pQuery = m_parser.parseQuery("duration:<39|duration:>=2:00", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setDuration(39);
+    EXPECT_FALSE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setDuration(38);
+    EXPECT_TRUE(pQuery->match(pTrackB));
+
+    TrackPointer pTrackC = newTestTrack();
+    pTrackC->setDuration(120);
+    EXPECT_TRUE(pQuery->match(pTrackC));
+
+    TrackPointer pTrackD = newTestTrack();
+    pTrackD->setDuration(119);
+    EXPECT_FALSE(pQuery->match(pTrackD));
+}
+
+TEST_F(SearchQueryParserTest, MultiWayOrOperator) {
+    m_parser.setSearchColumns({"title", "album", "comment"});
+
+    auto pQuery = m_parser.parseQuery("house|  funk | big room", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setComment("tech house");
+    EXPECT_TRUE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setTitle("The Funk, the Whole Funk, and Nothing but the Funk");
+    EXPECT_TRUE(pQuery->match(pTrackB));
+
+    TrackPointer pTrackC = newTestTrack();
+    pTrackC->setAlbum("Big room anthems vol. 1");
+    EXPECT_TRUE(pQuery->match(pTrackC));
+
+    TrackPointer pTrackD = newTestTrack();
+    pTrackD->setAlbum("homework");
+    EXPECT_FALSE(pQuery->match(pTrackD));
+
+    TrackPointer pTrackE = newTestTrack();
+    pTrackE->setAlbum("housework");
+    EXPECT_TRUE(pQuery->match(pTrackE));
+
+    TrackPointer pTrackF = newTestTrack();
+    pTrackF->setAlbum("small room");
+    EXPECT_FALSE(pQuery->match(pTrackF));
+
+    TrackPointer pTrackG = newTestTrack();
+    pTrackG->setAlbum("big   room");
+    EXPECT_TRUE(pQuery->match(pTrackG));
+
+    TrackPointer pTrackH = newTestTrack();
+    pTrackH->setTitle("big");
+    EXPECT_FALSE(pQuery->match(pTrackH));
+
+    TrackPointer pTrackI = newTestTrack();
+    pTrackI->setTitle("big");
+    pTrackI->setComment("Room");
+    EXPECT_TRUE(pQuery->match(pTrackI));
+}
+
+TEST_F(SearchQueryParserTest, QuotedOrOperator) {
+    m_parser.setSearchColumns({"title", "comment"});
+
+    auto pQuery = m_parser.parseQuery("title:\"a | contrived|example\" house | techno", QString());
+
+    TrackPointer pTrackA = newTestTrack();
+    pTrackA->setTitle("a");
+    EXPECT_FALSE(pQuery->match(pTrackA));
+
+    TrackPointer pTrackB = newTestTrack();
+    pTrackB->setTitle("a  contrived example");
+    EXPECT_FALSE(pQuery->match(pTrackB));
+
+    TrackPointer pTrackC = newTestTrack();
+    pTrackC->setTitle("a | contrived|example");
+    EXPECT_FALSE(pQuery->match(pTrackC));
+
+    TrackPointer pTrackD = newTestTrack();
+    pTrackD->setTitle("a | contrived|example");
+    pTrackD->setComment("house");
+    EXPECT_TRUE(pQuery->match(pTrackD));
+
+    TrackPointer pTrackE = newTestTrack();
+    pTrackE->setTitle("house");
+    EXPECT_FALSE(pQuery->match(pTrackE));
+
+    TrackPointer pTrackF = newTestTrack();
+    pTrackF->setTitle("techno");
+    EXPECT_TRUE(pQuery->match(pTrackF));
+
+    TrackPointer pTrackG = newTestTrack();
+    pTrackG->setTitle("a contrived|example");
+    pTrackG->setComment("house");
+    EXPECT_FALSE(pQuery->match(pTrackG));
+
+    TrackPointer pTrackH = newTestTrack();
+    pTrackH->setTitle("a  | contrived|example");
+    pTrackH->setComment("house");
+    EXPECT_FALSE(pQuery->match(pTrackH));
+
+    TrackPointer pTrackI = newTestTrack();
+    pTrackI->setTitle("a | contrived|example and more");
+    pTrackI->setComment("house");
+    EXPECT_TRUE(pQuery->match(pTrackI));
+}
