@@ -3,6 +3,7 @@
 #include <QHash>
 #include <QString>
 
+#include "audio/types.h"
 #include "proto/keys.pb.h"
 #include "track/keys.h"
 #include "util/types.h"
@@ -38,6 +39,6 @@ class KeyFactory {
     static Keys makePreferredKeys(
             const KeyChangeList& key_changes,
             const QHash<QString, QString>& extraVersionInfo,
-            int iSampleRate,
+            mixxx::audio::SampleRate sampleRate,
             SINT totalFrames);
 };
