@@ -1,18 +1,21 @@
 #pragma once
 
-#include <taglib/apetag.h>
+#include <apetag.h>
 
-#include "track/taglib/trackmetadata_common.h"
+class QImage;
 
 namespace mixxx {
 
+class TrackMetadata;
+
 namespace taglib {
 
 namespace ape {
 
 void importTrackMetadataFromTag(
         TrackMetadata* pTrackMetadata,
-        const TagLib::APE::Tag& tag);
+        const TagLib::APE::Tag& tag,
+        bool resetMissingTagMetadata);
 
 bool importCoverImageFromTag(
         QImage* pCoverArt,
