@@ -1,10 +1,7 @@
-#ifndef TRACKID_H
-#define TRACKID_H
-
+#pragma once
 
 #include "util/db/dbid.h"
 
-
 class TrackId: public DbId {
 public:
     // Inherit constructors from base class
@@ -15,5 +12,3 @@ Q_DECLARE_TYPEINFO(TrackId, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(TrackId)
 
 typedef QList<TrackId> TrackIdList;
-
-#endif // TRACKID_H
