@@ -22,7 +22,7 @@ TrackRecord::TrackRecord(TrackId id)
           m_headerParsed(false) {
 }
 
-void TrackRecord::setKeys(const Keys& keys) {
+void TrackRecord::setKeys(Keys keys) {
     refMetadata().refTrackInfo().setKeyText(keys.getGlobalKeyText());
     m_keys = std::move(keys);
 }
@@ -38,7 +38,7 @@ UpdateResult TrackRecord::updateGlobalKeyNormalizeText(
     // Try to parse the input as a key.
     mixxx::track::io::key::ChromaticKey newKey =
             KeyUtils::guessKeyFromText(keyText);
-    if (newKey == mixxx::track::io::key::INVALID) {
+    if (newKey == mixxx::track::io::key::INVALID && !keyText.isEmpty()) {
         // revert if we can't guess a valid key from it
         return UpdateResult::Rejected;
     }
@@ -48,7 +48,14 @@ UpdateResult TrackRecord::updateGlobalKeyNormalizeText(
         return UpdateResult::Unchanged;
     }
 
-    Keys newKeys = KeyFactory::makeBasicKeys(newKey, keySource);
+    Keys newKeys;
+    if (keySource == mixxx::track::io::key::FILE_METADATA) {
+        newKeys = KeyFactory::makeBasicKeysKeepText(
+                keyText,
+                mixxx::track::io::key::FILE_METADATA);
+    } else {
+        newKeys = KeyFactory::makeBasicKeys(newKey, keySource);
+    }
     setKeys(newKeys);
     return UpdateResult::Updated;
 }
