@@ -11,6 +11,7 @@
 #include <QCoreApplication>
 #include <QProcessEnvironment>
 #include <QStandardPaths>
+#include <QStyleFactory>
 #include <QtGlobal>
 
 #include "config.h"
@@ -350,6 +351,15 @@ bool CmdlineArgs::parse(const QStringList& arguments, CmdlineArgs::ParseMode mod
     parser.addOption(debugAssertBreak);
     parser.addOption(debugAssertBreakDeprecated);
 
+    const QCommandLineOption styleOption(QStringLiteral("style"),
+            forUserFeedback
+                    ? QCoreApplication::translate("CmdlineArgs",
+                              "Overrides the default application GUI style. Possible values: %1")
+                              .arg(QStyleFactory::keys().join(QStringLiteral(", ")))
+                    : QString(),
+            QStringLiteral("style"));
+    parser.addOption(styleOption);
+
     const QCommandLineOption helpOption = parser.addHelpOption();
     const QCommandLineOption versionOption = parser.addVersionOption();
 
@@ -489,5 +499,9 @@ bool CmdlineArgs::parse(const QStringList& arguments, CmdlineArgs::ParseMode mod
         fputs("Unknown argument for for color.\n", stdout);
     }
 
+    if (parser.isSet(styleOption)) {
+        m_styleName = parser.value(styleOption);
+    }
+
     return true;
 }
