@@ -1,6 +1,7 @@
 #pragma once
 
 #include <QDateTime>
+#include <QTimeZone>
 #include <QVariant>
 
 #include "util/assert.h"
@@ -12,9 +13,12 @@ namespace mixxx {
 
 /// Obtain the local date time from an UTC date time.
 inline QDateTime localDateTimeFromUtc(
-        QDateTime dt) {
-    dt.setTimeSpec(Qt::UTC);
-    return dt.toLocalTime();
+        const QDateTime& dt) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+    return QDateTime(dt.date(), dt.time(), QTimeZone::UTC).toLocalTime();
+#else
+    return QDateTime(dt.date(), dt.time(), Qt::UTC).toLocalTime();
+#endif
 }
 
 /// Extract a QDateTime from a QVariant.
