@@ -1,11 +1,7 @@
 #pragma once
 
-#include <QDir>
-#include <QFile>
 #include <QString>
 
-#include "util/sandbox.h"
-
 // Check if the extension from the file filter was added to the file base name.
 // Otherwise add it manually.
 // Works around https://bugreports.qt.io/browse/QTBUG-27186
@@ -23,32 +19,3 @@ QString getFilePathWithVerifiedExtensionFromFileDialog(
         const QString& preSelectedDirectory,
         const QString& fileFilters,
         const QString& preSelectedFileFilter);
-
-class MDir {
-  public:
-    MDir();
-    MDir(const QString& name);
-    MDir(const MDir& other);
-    virtual ~MDir();
-
-    QDir& dir() {
-        return m_dir;
-    }
-
-    const QDir& dir() const {
-        return m_dir;
-    }
-
-    SecurityTokenPointer token() {
-        return m_pSecurityToken;
-    }
-
-    bool canAccess();
-
-    MDir& operator=(const MDir& other);
-
-  private:
-    QString m_dirPath;
-    QDir m_dir;
-    SecurityTokenPointer m_pSecurityToken;
-};
