@@ -2,9 +2,12 @@
 
 #include <QString>
 
-#include "util/types.h"
+#include "control/pollingcontrolproxy.h"
 #include "preferences/usersettings.h"
+#include "util/parented_ptr.h"
+#include "util/types.h"
 
+class PollingControlProxy;
 class ControlProxy;
 struct VinylSignalQualityReport;
 
@@ -65,6 +68,8 @@ class VinylControl : public QObject {
     ControlProxy* signalenabled;
     // When the user has pressed the "reverse" button.
     ControlProxy* reverseButton;
+    PollingControlProxy m_passthroughEnabled;
+    PollingControlProxy m_scratchPositionEnabled;
 
     // The lead-in time...
     int m_iLeadInTime;
