@@ -53,15 +53,9 @@ VinylControlXwax::VinylControlXwax(UserSettingsPointer pConfig, const QString& g
           m_iPitchRingSize(0),
           m_iPitchRingPos(0),
           m_iPitchRingFilled(0),
-          m_dDisplayPitch(0.0),
           m_pSteadySubtle(nullptr),
           m_pSteadyGross(nullptr),
           m_bCDControl(false),
-          m_bTrackSelectMode(false),
-          m_pControlTrackSelector(nullptr),
-          m_pControlTrackLoader(nullptr),
-          m_dLastTrackSelectPos(0.0),
-          m_dCurTrackSelectPos(0.0),
           m_dDriftAmt(0.0),
           m_initialRelativeDriftAmt(0.0),
           m_deltaRelativeDriftAmount(0.0),
@@ -77,6 +71,8 @@ VinylControlXwax::VinylControlXwax(UserSettingsPointer pConfig, const QString& g
         ConfigKey(group,"vinylcontrol_vinyl_type"));
     QString strVinylSpeed = m_pConfig->getValueString(
         ConfigKey(group,"vinylcontrol_speed_type"));
+    QString strPitchEstimator = m_pConfig->getValueString(
+            ConfigKey(group, "vinylcontrol_pitch_estimator_type"));
 
     // libxwax indexes by C-strings so we pass libxwax string literals so we
     // don't have to deal with freeing the strings later
@@ -139,9 +135,8 @@ VinylControlXwax::VinylControlXwax(UserSettingsPointer pConfig, const QString& g
         latency = 20;
     }
 
-    const auto sampleRate = mixxx::audio::SampleRate(
-            m_pConfig->getValueString(ConfigKey("[Soundcard]", "Samplerate"))
-                    .toUInt());
+    const auto sampleRate = static_cast<unsigned int>(ControlObject::get(
+            ConfigKey(QStringLiteral("[App]"), QStringLiteral("samplerate"))));
 
     // Set pitch ring size to 1/4 of one revolution -- a full revolution adds
     // too much stickiness to the pitch.
@@ -155,7 +150,14 @@ VinylControlXwax::VinylControlXwax(UserSettingsPointer pConfig, const QString& g
     // do this once across the VinylControlXwax instances.
     s_xwaxLUTMutex.lock();
 
-    timecoder_init(&timecoder, tc_def, speed, sampleRate.value(), /* phono */ false);
+    const bool use_legacy_pitch_filter = strPitchEstimator == MIXXX_VINYL_PITCH_FILTER_LEGACY;
+
+    timecoder_init(&timecoder,
+            tc_def,
+            speed,
+            sampleRate,
+            /* phono */ false,
+            use_legacy_pitch_filter);
     timecoder_monitor_init(&timecoder, MIXXX_VINYL_SCOPE_SIZE);
     //Note that timecoder_init will not double-malloc the LUTs, and after this we are guaranteed
     //that the LUT has been generated unless we ran out of memory.
@@ -271,7 +273,6 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
     double duration_inaccurate = duration->get();
     if (duration_inaccurate != m_dOldDurationInaccurate) {
         m_bForceResync = true;
-        m_bTrackSelectMode = false; //just in case
         m_dOldDurationInaccurate = duration_inaccurate;
         m_dOldDuration = trackSamples->get() / 2 / trackSampleRate->get();
 
@@ -291,10 +292,6 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
         m_dVinylPosition = static_cast<double>(m_iPosition) / 1000.0 - m_iLeadInTime;
     }
 
-    // Initialize drift control to zero in case we don't get any position data
-    // to calculate it with.
-    double dDriftControl = 0.0;
-
     // Get the playback position in the file in seconds.
     double filePosition = playPos->get() * m_dOldDuration;
 
@@ -378,61 +375,6 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
         }
     }
 
-    //check here for position > safe, and if no record end mode,
-    //then trigger track selection mode.  just pass position to it
-    //and ignore pitch
-
-    if (!m_bAtRecordEnd) {
-        if (m_iPosition != -1 && m_iPosition > static_cast<int>(m_uiSafeZone)) {
-            //only enable if pitch is steady, though.  Heavy scratching can
-            //produce crazy results and trigger this mode
-            if (m_bTrackSelectMode || checkSteadyPitch(dVinylPitch, filePosition) > 0.1) {
-                //until I can figure out how to detect "track 2" on serato CD,
-                //don't try track selection
-                if (!m_bCDControl) {
-                    if (!m_bTrackSelectMode) {
-                        qDebug() << "position greater than safe, select mode" << m_iPosition << m_uiSafeZone;
-                        m_bTrackSelectMode = true;
-                        togglePlayButton(false);
-                        resetSteadyPitch(0.0, 0.0);
-                        m_pVCRate->set(0.0);
-                    }
-                    doTrackSelection(true, dVinylPitch, m_iPosition);
-                }
-
-                //hm I wonder if track will keep playing while this happens?
-                //not sure what we want to do here...  probably enforce
-                //stopped deck.
-
-                //but if constant mode...  nah, force stop.
-                return;
-            }
-            //if it's not steady yet we process as normal
-        } else {
-            //so we're not unsafe.... but
-            //if no position, but we were in select mode, do select mode
-            if (m_iPosition == -1 && m_bTrackSelectMode) {
-                //qDebug() << "no position, but were in select mode";
-                doTrackSelection(false, dVinylPitch, m_iPosition);
-
-                //again, force stop?
-                return;
-            } else if (m_bTrackSelectMode) {
-                //qDebug() << "discontinuing select mode, selecting track";
-                if (m_pControlTrackLoader == nullptr) {
-                    m_pControlTrackLoader = new ControlProxy(
-                            m_group, "LoadSelectedTrack", this);
-                }
-
-                m_pControlTrackLoader->set(1.0);
-                m_pControlTrackLoader->set(0.0); // I think I have to do this...
-
-                // if position is known and safe then no track select mode
-                m_bTrackSelectMode = false;
-            }
-        }
-    }
-
     if (m_iVCMode == MIXXX_VCMODE_CONSTANT) {
         // when we enabled constant mode we set the rate slider
         // now we just either set scratch val to 0 (stops playback)
@@ -452,13 +394,8 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
     if(bHaveSignal) {
         //POSITION: MAYBE  PITCH: YES
 
-        //We have pitch, but not position.  so okay signal but not great (scratching / cueing?)
-        //qDebug() << "Pitch" << dVinylPitch;
-
         if (m_iPosition != -1) {
             //POSITION: YES  PITCH: YES
-            //add a value to the pitch ring (for averaging / smoothing the pitch)
-            //qDebug() << fabs(((m_dVinylPosition - m_dVinylPositionOld) * (dVinylPitch / fabs(dVinylPitch))));
 
             bool reversed = static_cast<bool>(reverseButton->get());
             if (!reversed && m_bWasReversed) {
@@ -487,8 +424,8 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
                     resetSteadyPitch(dVinylPitch, m_dVinylPosition);
                 }
                 m_bForceResync = false;
-            } else if (fabs(m_dVinylPosition - filePosition) > 0.1 &&
-                       m_dVinylPosition < -2.0) {
+            } else if (fabs(m_dDriftAmt) > 0.1 &&
+                    m_dVinylPosition < -2.0) {
                 //At first I thought it was a bug to resync to leadin in relative mode,
                 //but after using it that way it's actually pretty convenient.
                 //qDebug() << "Vinyl leadin";
@@ -498,14 +435,14 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
                     m_pRateRatio->set(fabs(dVinylPitch));
                 }
             } else if (m_iVCMode == MIXXX_VCMODE_ABSOLUTE &&
-                       (fabs(m_dVinylPosition - m_dVinylPositionOld) >= 5.0)) {
+                    (fabs(m_dVinylPosition - m_dVinylPositionOld) >= 5.0)) {
                 //If the position from the timecode is more than a few seconds off, resync the position.
                 //qDebug() << "resync position (>15.0 sec)";
                 //qDebug() << m_dVinylPosition << m_dVinylPositionOld << m_dVinylPosition - m_dVinylPositionOld;
                 syncPosition();
                 resetSteadyPitch(dVinylPitch, m_dVinylPosition);
             } else if (m_iVCMode == MIXXX_VCMODE_ABSOLUTE && m_bCDControl &&
-                       fabs(m_dVinylPosition - m_dVinylPositionOld) >= 0.1) {
+                    fabs(m_dVinylPosition - m_dVinylPositionOld) >= 0.1) {
                 //qDebug() << "CDJ resync position (>0.1 sec)";
                 syncPosition();
                 resetSteadyPitch(dVinylPitch, m_dVinylPosition);
@@ -521,24 +458,6 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
                 togglePlayButton(checkSteadyPitch(dVinylPitch, filePosition) > 0.5);
             }
 
-            // Calculate how much the vinyl's position has drifted from it's timecode and compensate for it.
-            // (This is caused by the manufacturing process of the vinyl.)
-            if (m_iVCMode == MIXXX_VCMODE_ABSOLUTE &&
-                    std::fabs(m_dDriftAmt) > 0.03 && std::fabs(m_dDriftAmt) < 5.0) {
-                dDriftControl = m_dDriftAmt * .01;
-            } else {
-                // Apply relative drift control
-                if (m_iVCMode == MIXXX_VCMODE_RELATIVE) {
-                    if (std::fabs(m_deltaRelativeDriftAmount) > 0.006 &&
-                            std::fabs(m_deltaRelativeDriftAmount) < 1.0 &&
-                            std::fabs(m_deltaFilePos) < 0.03) {
-                        dDriftControl = m_deltaRelativeDriftAmount * 0.3;
-                    }
-                } else {
-                    dDriftControl = 0.0;
-                }
-            }
-
             m_dVinylPositionOld = m_dVinylPosition;
         } else {
             //POSITION: NO  PITCH: YES
@@ -557,7 +476,7 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
 
             if (m_iVCMode == MIXXX_VCMODE_ABSOLUTE &&
                     fabs(dVinylPitch) < 0.05 &&
-                    fabs(m_dDriftAmt) >= 0.3) {
+                    fabs(m_dDriftAmt) >= 1.0) {
                 //qDebug() << "slow, out of sync, syncing position";
                 syncPosition();
             }
@@ -569,6 +488,9 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
             }
         }
 
+        // Vinyl rate is exactly what is detected.
+        m_pVCRate->set(dVinylPitch);
+
         //playbutton status may have changed
         reportedPlayButton = playButton->toBool();
 
@@ -585,7 +507,7 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
             m_iPitchRingFilled = 0;
         }
 
-        //only smooth when we have good position (no smoothing for scratching)
+        // Smoothed pitch is only used for UI display, not actual rate.
         double averagePitch = 0.0;
         if (m_iPosition != -1 && reportedPlayButton) {
             for (int i = 0; i < m_iPitchRingFilled; ++i) {
@@ -599,31 +521,11 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
             averagePitch = dVinylPitch;
         }
 
-        m_pVCRate->set(dVinylPitch + dDriftControl);
         if (uiUpdateTime(filePosition)) {
-            double true_pitch = averagePitch + dDriftControl;
-            double pitch_difference = true_pitch - m_dDisplayPitch;
-
-            // The true pitch can show a misleading amount of variance --
-            // differences of .1% or less can show up as 1 or 2 bpm changes.
-            // Therefore we react slowly to bpm changes to show a more steady
-            // number to the user.
-            if (fabs(pitch_difference) > 0.5) {
-                // For large changes in pitch (start/stop, usually), immediately
-                // update the display.
-                m_dDisplayPitch = true_pitch;
-            } else if (fabs(pitch_difference) > 0.005) {
-                // For medium changes in pitch, take 4 callback loops to
-                // converge on the correct amount.
-                m_dDisplayPitch += pitch_difference * .25;
-            } else {
-                // For extremely small changes, converge very slowly.
-                m_dDisplayPitch += pitch_difference * .01;
-            }
             // Don't show extremely high or low speeds in the UI.
             if (reportedPlayButton && !scratching->toBool() &&
-                    m_dDisplayPitch < 1.9 && m_dDisplayPitch > 0.2) {
-                m_pRateRatio->set(m_dDisplayPitch);
+                    dVinylPitch < 1.9 && dVinylPitch > 0.2) {
+                m_pRateRatio->set(dVinylPitch);
             } else {
                 m_pRateRatio->set(1.0);
             }
@@ -642,14 +544,8 @@ void VinylControlXwax::analyzeSamples(CSAMPLE* pSamples, size_t nFrames) {
 
         m_pRateRatio->set(1.0);
 
-        if (m_iVCMode == MIXXX_VCMODE_ABSOLUTE &&
-                fabs(m_dVinylPosition - filePosition) >= 0.1) {
-            //qDebug() << "stopped, out of sync, syncing position";
-            syncPosition();
-        }
-
-        if(fabs(filePosition - m_dOldFilePos) >= 0.1 ||
-               filePosition == m_dOldFilePos) {
+        if (fabs(filePosition - m_dOldFilePos) >= 0.3 ||
+                filePosition == m_dOldFilePos) {
             //We are not playing any more
             togglePlayButton(false);
             resetSteadyPitch(0.0, 0.0);
@@ -720,52 +616,6 @@ void VinylControlXwax::togglePlayButton(bool on) {
     }
 }
 
-void VinylControlXwax::doTrackSelection(bool valid_pos, double pitch, double position) {
-    //compare positions, fabricating if we don't have position data, and
-    //move the selector every so often
-    //track will be selected when the needle is moved back to play area
-    //track selection can be cancelled by loading a track manually
-
-    constexpr int SELECT_INTERVAL = 150;
-    constexpr double NOPOS_SPEED = 0.50;
-
-    if (m_pControlTrackSelector == nullptr) {
-        // this isn't done in the constructor because this object
-        // doesn't seem to be created yet
-        m_pControlTrackSelector = new ControlProxy(
-                "[Playlist]","SelectTrackKnob", this);
-    }
-
-    if (!valid_pos) {
-        if (fabs(pitch) > 0.1) {
-            //how to estimate how far the record has moved when we don't have a valid
-            //position and no mp3 track to compare with???  just add a bullshit amount?
-            m_dCurTrackSelectPos += pitch * NOPOS_SPEED; //MADE UP CONSTANT, needs to be based on frames per second I think
-        } else {
-            // too slow, do nothing
-            return;
-        }
-    } else {
-        // if we have valid pos, use it
-        m_dCurTrackSelectPos = position;
-    }
-
-
-    //we have position or at least record is moving, so check if we should
-    //change location
-
-    if (fabs(m_dCurTrackSelectPos - m_dLastTrackSelectPos) > 10.0 * 1000) {
-        //yeah probably not a valid value
-        //qDebug() << "large change in track position, resetting";
-        m_dLastTrackSelectPos = m_dCurTrackSelectPos;
-    } else if (fabs(m_dCurTrackSelectPos - m_dLastTrackSelectPos) > SELECT_INTERVAL) {
-        //only adjust by one at a time.  It's no help jumping around
-        m_pControlTrackSelector->set((int)(m_dCurTrackSelectPos - m_dLastTrackSelectPos) / fabs(m_dCurTrackSelectPos - m_dLastTrackSelectPos));
-        m_dLastTrackSelectPos = m_dCurTrackSelectPos;
-    }
-}
-
-
 void VinylControlXwax::resetSteadyPitch(double pitch, double time) {
     m_pSteadySubtle->reset(pitch, time);
     m_pSteadyGross->reset(pitch, time);
