@@ -1,11 +1,19 @@
-#include <QTimer>
-
 #include "waveform/guitick.h"
+
 #include "control/controlobject.h"
 
+namespace {
+const QString kAppGroup = QStringLiteral("[App]");
+const QString kLegacyGroup = QStringLiteral("[Master]");
+} // namespace
+
 GuiTick::GuiTick() {
-    m_pCOGuiTickTime = std::make_unique<ControlObject>(ConfigKey("[Master]", "guiTickTime"));
-    m_pCOGuiTick50ms = std::make_unique<ControlObject>(ConfigKey("[Master]", "guiTick50ms"));
+    m_pCOGuiTickTime = std::make_unique<ControlObject>(
+            ConfigKey(kAppGroup, QStringLiteral("gui_tick_full_period_s")));
+    m_pCOGuiTickTime->addAlias(ConfigKey(kLegacyGroup, QStringLiteral("guiTickTime")));
+    m_pCOGuiTick50ms = std::make_unique<ControlObject>(
+            ConfigKey(kAppGroup, QStringLiteral("gui_tick_50ms_period_s")));
+    m_pCOGuiTick50ms->addAlias(ConfigKey(kLegacyGroup, QStringLiteral("guiTick50ms")));
     m_cpuTimer.start();
 }
 
