@@ -16,7 +16,9 @@ class WaveformRenderBeat;
 
 class allshader::WaveformRenderBeat final : public allshader::WaveformRenderer {
   public:
-    explicit WaveformRenderBeat(WaveformWidgetRenderer* waveformWidget);
+    explicit WaveformRenderBeat(WaveformWidgetRenderer* waveformWidget,
+            ::WaveformRendererAbstract::PositionSource type =
+                    ::WaveformRendererAbstract::Play);
 
     void setup(const QDomNode& node, const SkinContext& context) override;
     void paintGL() override;
@@ -27,5 +29,7 @@ class allshader::WaveformRenderBeat final : public allshader::WaveformRenderer {
     QColor m_color;
     VertexData m_vertices;
 
+    bool m_isSlipRenderer;
+
     DISALLOW_COPY_AND_ASSIGN(WaveformRenderBeat);
 };
