@@ -12,7 +12,9 @@ class WaveformRendererRGB;
 
 class allshader::WaveformRendererRGB final : public allshader::WaveformRendererSignalBase {
   public:
-    explicit WaveformRendererRGB(WaveformWidgetRenderer* waveformWidget);
+    explicit WaveformRendererRGB(WaveformWidgetRenderer* waveformWidget,
+            ::WaveformRendererAbstract::PositionSource type =
+                    ::WaveformRendererAbstract::Play);
 
     // override ::WaveformRendererSignalBase
     void onSetup(const QDomNode& node) override;
@@ -25,5 +27,7 @@ class allshader::WaveformRendererRGB final : public allshader::WaveformRendererS
     VertexData m_vertices;
     RGBData m_colors;
 
+    bool m_isSlipRenderer;
+
     DISALLOW_COPY_AND_ASSIGN(WaveformRendererRGB);
 };
