@@ -1,19 +1,10 @@
-#include <QtDebug>
-#include <QColor>
-#include <QDomNode>
-#include <QPaintEvent>
-#include <QPainter>
-#include <QObject>
-#include <QVector>
-
 #include "waveform/renderers/waveformrendermarkrange.h"
 
-#include "preferences/usersettings.h"
-#include "track/track.h"
-#include "waveform/renderers/waveformwidgetrenderer.h"
-#include "widget/wskincolor.h"
-#include "widget/wwidget.h"
+#include <QPainter>
+#include <QtDebug>
+
 #include "util/painterscope.h"
+#include "waveform/renderers/waveformwidgetrenderer.h"
 
 WaveformRenderMarkRange::WaveformRenderMarkRange(WaveformWidgetRenderer* waveformWidgetRenderer) :
     WaveformRendererAbstract(waveformWidgetRenderer) {
