@@ -4,11 +4,9 @@
 
 #include "moc_emptywaveformwidget.cpp"
 #include "waveform/renderers/waveformrenderbackground.h"
-#include "waveform/renderers/waveformwidgetrenderer.h"
 
 EmptyWaveformWidget::EmptyWaveformWidget(const QString& group, QWidget* parent)
-        : QWidget(parent),
-          WaveformWidgetAbstract(group) {
+        : NonGLWaveformWidgetAbstract(group, parent) {
     //Empty means just a background ;)
     addRenderer<WaveformRenderBackground>();
 
