@@ -12,14 +12,9 @@ namespace mixxx {
 namespace library {
 
 void createFindOnWebSubmenus(QMenu* pFindOnWebMenu, const Track& track) {
-    auto pFindOnWebMenuSoundcloud = make_parented<QMenu>(
-            new FindOnWebMenuSoundcloud(pFindOnWebMenu, track));
-
-    auto pFindOnWebMenuDiscogs = make_parented<QMenu>(
-            new FindOnWebMenuDiscogs(pFindOnWebMenu, track));
-
-    auto pFindOnWebMenuLastfm = make_parented<QMenu>(
-            new FindOnWebMenuLastfm(pFindOnWebMenu, track));
+    make_parented<QMenu>(new FindOnWebMenuSoundcloud(pFindOnWebMenu, track));
+    make_parented<QMenu>(new FindOnWebMenuDiscogs(pFindOnWebMenu, track));
+    make_parented<QMenu>(new FindOnWebMenuLastfm(pFindOnWebMenu, track));
 }
 
 } // namespace library
