@@ -1,26 +1,36 @@
 #pragma once
 
-#include <QMouseEvent>
-#include <QWheelEvent>
-#include <QColor>
 #include <QCursor>
-#include <QPoint>
+#include <QMouseEvent>
 #include <QPixmap>
+#include <QPoint>
+#include <QTimer>
+#include <QWheelEvent>
 
 #include "util/math.h"
 
+// duration (ms) the cursor is blanked after a mouse wheel event
+// 800 ms is the duration the parameter value is shown in the parameter name widget
+// src/widget/weffectparameternamebase.cpp
+constexpr int wheelEventCursorTimeout = 800;
+
 template <class T>
 class KnobEventHandler {
   public:
     KnobEventHandler()
-            : m_bRightButtonPressed(false) {
-            QPixmap blankPixmap(32, 32);
-            blankPixmap.fill(QColor(0, 0, 0, 0));
-            m_blankCursor = QCursor(blankPixmap);
+            : m_bRightButtonPressed(false),
+              m_pWheelCursorTimer(nullptr) {
+        QPixmap blankPixmap(32, 32);
+        blankPixmap.fill(Qt::transparent);
+        m_blankCursor = QCursor(blankPixmap);
     }
 
     double valueFromMouseEvent(T* pWidget, QMouseEvent* e) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QPoint cur = e->globalPosition().toPoint();
+#else
         QPoint cur = e->globalPos();
+#endif
         QPoint diff = cur - m_prevPos;
         m_prevPos = cur;
         double dist = sqrt(static_cast<double>(diff.x() * diff.x() + diff.y() * diff.y()));
@@ -58,7 +68,11 @@ class KnobEventHandler {
                 break;
             case Qt::LeftButton:
             case Qt::MiddleButton:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                m_startPos = e->globalPosition().toPoint();
+#else
                 m_startPos = e->globalPos();
+#endif
                 m_prevPos = m_startPos;
                 // Somehow using Qt::BlankCursor does not work on Windows
                 // https://mixxx.org/forums/viewtopic.php?p=40298#p40298
@@ -69,6 +83,12 @@ class KnobEventHandler {
         }
     }
 
+    void mouseDoubleClickEvent(T* pWidget, QMouseEvent* e) {
+        if (e->button() == Qt::LeftButton) {
+            pWidget->resetControlParameter();
+        }
+    }
+
     void mouseReleaseEvent(T* pWidget, QMouseEvent* e) {
         double value = 0.0;
         switch (e->button()) {
@@ -89,6 +109,9 @@ class KnobEventHandler {
     }
 
     void wheelEvent(T* pWidget, QWheelEvent* e) {
+        // Hide/blank the cursor so the parameter value below the knob is not obscured.
+        // Restore the cursor when the timer runs out, or when the cursor leaves the widget.
+        pWidget->setCursor(m_blankCursor);
         // For legacy (MIDI) reasons this is tuned to 127.
         double wheelDirection = e->angleDelta().y() / (120.0 * 127.0);
         double newValue = pWidget->getControlParameter() + wheelDirection;
@@ -99,6 +122,26 @@ class KnobEventHandler {
         pWidget->setControlParameter(newValue);
         pWidget->inputActivity();
         e->accept();
+        if (!m_pWheelCursorTimer) {
+            m_pWheelCursorTimer = new QTimer(pWidget);
+            m_pWheelCursorTimer->setSingleShot(true);
+            m_pWheelCursorTimer->setInterval(wheelEventCursorTimeout);
+        }
+        m_pWheelCursorTimer->start();
+        m_pWheelCursorTimer->callOnTimeout(
+                [pWidget]() {
+                    if (pWidget) {
+                        pWidget->unsetCursor();
+                    }
+                });
+    }
+
+    void leaveEvent(T* pWidget, QEvent* e) {
+        if (m_pWheelCursorTimer && m_pWheelCursorTimer->isActive()) {
+            m_pWheelCursorTimer->stop();
+            pWidget->unsetCursor();
+        }
+        e->accept();
     }
 
   private:
@@ -109,4 +152,5 @@ class KnobEventHandler {
     QPoint m_startPos;
     QPoint m_prevPos;
     QCursor m_blankCursor;
+    QTimer* m_pWheelCursorTimer;
 };
