@@ -145,7 +145,7 @@ void WBattery::setPixmap(PaintablePointer* ppPixmap, const PixmapSource& source,
                          Paintable::DrawMode mode, double scaleFactor) {
     PaintablePointer pPixmap = WPixmapStore::getPaintable(source, mode, scaleFactor);
     if (pPixmap.isNull() || pPixmap->isNull()) {
-        qDebug() << this << "Error loading pixmap:" << source.getPath();
+        qDebug() << "WBattery: Error loading pixmap:" << source.getPath();
     } else {
         *ppPixmap = pPixmap;
         if (mode == Paintable::FIXED) {
