@@ -1,13 +1,13 @@
 #pragma once
 
-#include "control/controlobject.h"
-#include "control/controlproxy.h"
-#include "widget/wbasewidget.h"
-#include "skin/legacy/skincontext.h"
 #include <QDoubleSpinBox>
 #include <QLineEdit>
 
-class ControlProxy;
+#include "control/controlproxy.h"
+#include "widget/wbasewidget.h"
+
+class QDomNode;
+class SkinContext;
 
 class WBeatSpinBox : public QDoubleSpinBox, public WBaseWidget {
     Q_OBJECT
@@ -30,10 +30,10 @@ class WBeatSpinBox : public QDoubleSpinBox, public WBaseWidget {
     QString fractionString(int numerator, int denominator) const;
 
     ControlProxy m_valueControl;
-    static QRegExp s_regexpBlacklist;
 
     // for font scaling
     bool event(QEvent* pEvent) override;
+    void keyPressEvent(QKeyEvent* pEvent) override;
     double m_scaleFactor;
 };
 
