@@ -1,5 +1,7 @@
 #include "widget/wcolorpickeraction.h"
 
+#include <QHBoxLayout>
+
 #include "moc_wcolorpickeraction.cpp"
 
 WColorPickerAction::WColorPickerAction(WColorPicker::Options options, const ColorPalette& palette, QWidget* parent)
@@ -21,7 +23,7 @@ void WColorPickerAction::resetSelectedColor() {
     m_pColorPicker->resetSelectedColor();
 }
 
-void WColorPickerAction::setSelectedColor(mixxx::RgbColor::optional_t color) {
+void WColorPickerAction::setSelectedColor(const mixxx::RgbColor::optional_t& color) {
     m_pColorPicker->setSelectedColor(color);
 }
 
