@@ -30,11 +30,11 @@ void WEffectParameterBase::parameterUpdated() {
         } else {
             setText(m_pEffectParameterSlot->name());
         }
-        setBaseTooltip(QString("%1\n%2").arg(
-                       m_pEffectParameterSlot->name(),
-                       m_pEffectParameterSlot->description()));
+        setBaseTooltip(QStringLiteral("%1\n%2").arg(
+                m_pEffectParameterSlot->name(),
+                m_pEffectParameterSlot->description()));
     } else {
         setText(EffectsManager::kNoEffectString);
-        setBaseTooltip(tr("No effect loaded."));
+        setBaseTooltip(kNoEffectString);
     }
 }
