@@ -1,7 +1,9 @@
 #pragma once
 
+#include "effects/defs.h"
 #include "widget/wknob.h"
-#include "effects/effectparameterslot.h"
+
+class EffectsManager;
 
 // This is used for effect parameter knobs with dynamic
 // tooltips, if the knob value is displayed by one of e.g.
@@ -9,23 +11,20 @@
 // If the knob value can be displayed by rotating a single
 // SVG, use WEffectParameterKnobComposed.
 class WEffectParameterKnob : public WKnob {
-  Q_OBJECT
+    Q_OBJECT
   public:
-    WEffectParameterKnob(QWidget* pParent, EffectsManager* pEffectsManager) :
-        WKnob(pParent),
-        m_pEffectsManager(pEffectsManager) {
+    WEffectParameterKnob(QWidget* pParent, EffectsManager* pEffectsManager)
+            : WKnob(pParent),
+              m_pEffectsManager(pEffectsManager) {
+        setFocusPolicy(Qt::NoFocus);
     };
 
-    void setupEffectParameterSlot(const ConfigKey& configKey);
+    void setup(const QDomNode& node, const SkinContext& context) override;
 
   private slots:
     void parameterUpdated();
 
   private:
-    // Set the EffectParameterSlot that should be monitored by this
-    // WEffectKnobComposed.
-    void setEffectParameterSlot(EffectParameterSlotPointer pParameterSlot);
-
     EffectsManager* m_pEffectsManager;
     EffectParameterSlotBasePointer m_pEffectParameterSlot;
 };
