@@ -1,15 +1,11 @@
 #pragma once
 
-#include <QMenu>
-#include <QAction>
-#include <QMouseEvent>
-#include <QDomNode>
-#include <QWidget>
-
-#include "widget/wpushbutton.h"
-#include "effects/effectsmanager.h"
 #include "effects/defs.h"
-#include "skin/legacy/skincontext.h"
+#include "widget/wpushbutton.h"
+
+class QAction;
+class QMenu;
+class EffectsManager;
 
 class WEffectPushButton : public WPushButton {
     Q_OBJECT
@@ -17,7 +13,6 @@ class WEffectPushButton : public WPushButton {
     WEffectPushButton(QWidget* pParent, EffectsManager* pEffectsManager);
 
     void setup(const QDomNode& node, const SkinContext& context) override;
-    void setupEffectParameterSlot(const ConfigKey& configKey);
 
   public slots:
     void onConnectedControlChanged(double dParameter, double dValue) override;
@@ -31,11 +26,6 @@ class WEffectPushButton : public WPushButton {
     void slotActionChosen(QAction* action);
 
   private:
-    // Set the EffectParameterSlot that should be monitored by this
-    // WEffectKnobComposed.
-    void setEffectParameterSlot(EffectButtonParameterSlotPointer pParameterSlot);
-
-
     EffectsManager* m_pEffectsManager;
     EffectParameterSlotBasePointer m_pEffectParameterSlot;
     QMenu* m_pButtonMenu;
