@@ -1,10 +1,7 @@
 #pragma once
 
-#include <QDomNode>
-#include <QMouseEvent>
-#include <QWidget>
+#include <QString>
 
-#include "skin/legacy/skincontext.h"
 #include "util/parented_ptr.h"
 #include "widget/wcuemenupopup.h"
 #include "widget/wpushbutton.h"
@@ -16,8 +13,16 @@ class WHotcueButton : public WPushButton {
 
     void setup(const QDomNode& node, const SkinContext& context) override;
 
+    ConfigKey getLeftClickConfigKey() {
+        return createConfigKey(QStringLiteral("activate"));
+    }
+    ConfigKey getClearConfigKey() {
+        return createConfigKey(QStringLiteral("clear"));
+    }
+
     Q_PROPERTY(bool light MEMBER m_bCueColorIsLight);
     Q_PROPERTY(bool dark MEMBER m_bCueColorIsDark);
+    Q_PROPERTY(QString type MEMBER m_type);
 
   protected:
     void mousePressEvent(QMouseEvent* e) override;
@@ -26,6 +31,7 @@ class WHotcueButton : public WPushButton {
 
   private slots:
     void slotColorChanged(double color);
+    void slotTypeChanged(double type);
 
   private:
     ConfigKey createConfigKey(const QString& name);
@@ -35,9 +41,11 @@ class WHotcueButton : public WPushButton {
     int m_hotcue;
     bool m_hoverCueColor;
     parented_ptr<ControlProxy> m_pCoColor;
+    parented_ptr<ControlProxy> m_pCoType;
     parented_ptr<WCueMenuPopup> m_pCueMenuPopup;
     int m_cueColorDimThreshold;
     bool m_bCueColorDimmed;
     bool m_bCueColorIsLight;
     bool m_bCueColorIsDark;
+    QString m_type;
 };
