@@ -155,9 +155,13 @@ void WPushButton::setup(const QDomNode& node, const SkinContext& context) {
             switch (m_leftButtonMode) {
                 case ControlPushButton::PUSH:
                 case ControlPushButton::POWERWINDOW:
+                leftConnection->setEmitOption(
+                        ControlParameterWidgetConnection::EMIT_ON_PRESS_AND_RELEASE);
+                break;
                 case ControlPushButton::LONGPRESSLATCHING:
                     leftConnection->setEmitOption(
                             ControlParameterWidgetConnection::EMIT_ON_PRESS_AND_RELEASE);
+                    m_pLongPressLatching = std::make_unique<LongPressLatching>(this);
                     break;
                 case ControlPushButton::TOGGLE:
                 case ControlPushButton::TRIGGER:
@@ -259,7 +263,9 @@ void WPushButton::setPixmap(int iState,
     if (pPixmap.isNull() || pPixmap->isNull()) {
         // Only log if it looks like the user tried to specify a pixmap.
         if (!source.isEmpty()) {
-            qDebug() << "WPushButton: Error loading pixmap:" << source.getPath();
+            qDebug() << metaObject()->className() << objectName()
+                     << "Error loading pixmap" << source.getPath()
+                     << "for state" << iState;
         }
     } else if (mode == Paintable::FIXED) {
         // Set size of widget equal to pixmap size
@@ -276,19 +282,14 @@ void WPushButton::setPixmapBackground(const PixmapSource& source,
     if (!source.isEmpty() &&
             (m_pPixmapBack.isNull() || m_pPixmapBack->isNull())) {
         // Only log if it looks like the user tried to specify a pixmap.
-        qDebug() << "WPushButton: Error loading background pixmap:" << source.getPath();
+        qDebug() << metaObject()->className() << objectName()
+                 << "Error loading background pixmap:" << source.getPath();
     }
 }
 
 void WPushButton::restyleAndRepaint() {
     emit displayValueChanged(readDisplayValue());
 
-    // According to http://stackoverflow.com/a/3822243 this is the least
-    // expensive way to restyle just this widget.
-    // Since we expect button connections to not change at high frequency we
-    // don't try to detect whether things have changed for WPushButton, we just
-    // re-render.
-    style()->unpolish(this);
     style()->polish(this);
 
     // These calls don't always trigger the repaint, so call it explicitly.
@@ -302,23 +303,33 @@ void WPushButton::onConnectedControlChanged(double dParameter, double dValue) {
     if (m_iNoStates == 1) {
         m_bPressed = (dValue == 1.0);
     }
-
+    if (m_pLongPressLatching) {
+        if (dValue == 1.0) {
+            m_pLongPressLatching->start();
+        } else {
+            m_pLongPressLatching->stop();
+        }
+    }
     restyleAndRepaint();
 }
 
 void WPushButton::paintEvent(QPaintEvent* e) {
     Q_UNUSED(e);
+    paintOnDevice(nullptr, readDisplayValue());
+}
+
+void WPushButton::paintOnDevice(QPaintDevice* pd, int idx) {
     QStyleOption option;
     option.initFrom(this);
-    QStylePainter p(this);
-    p.drawPrimitive(QStyle::PE_Widget, option);
+    std::unique_ptr<QStylePainter> p(pd ? new QStylePainter(pd, this) : new QStylePainter(this));
+    p->drawPrimitive(QStyle::PE_Widget, option);
 
     if (m_iNoStates == 0) {
         return;
     }
 
     if (m_pPixmapBack) {
-        m_pPixmapBack->draw(rect(), &p);
+        m_pPixmapBack->draw(rect(), p.get());
     }
 
     const QVector<PaintablePointer>& pixmaps = m_bPressed ?
@@ -331,7 +342,6 @@ void WPushButton::paintEvent(QPaintEvent* e) {
         return;
     }
 
-    int idx = readDisplayValue();
     // Just in case m_iNoStates is somehow different from pixmaps.size().
     if (idx < 0) {
         idx = 0;
@@ -341,7 +351,7 @@ void WPushButton::paintEvent(QPaintEvent* e) {
 
     PaintablePointer pPixmap = pixmaps.at(idx);
     if (!pPixmap.isNull() && !pPixmap->isNull()) {
-        pPixmap->draw(rect(), &p);
+        pPixmap->draw(rect(), p.get());
     }
 
     QString text = m_text.at(idx);
@@ -354,7 +364,11 @@ void WPushButton::paintEvent(QPaintEvent* e) {
 //        int textWidth = width() - lPad - rPad;
 //        QRect textRect = rect().adjust(x1, y1, x2, y2);
         QString elidedText = metrics.elidedText(text, m_elideMode, width());
-        p.drawText(rect(), m_align.at(idx), elidedText);
+        p->drawText(rect(), m_align.at(idx), elidedText);
+    }
+
+    if (pd == nullptr && m_pLongPressLatching) {
+        m_pLongPressLatching->paint(p.get());
     }
 }
 
@@ -401,12 +415,16 @@ void WPushButton::mousePressEvent(QMouseEvent * e) {
         } else {
             // Toggle through the states
             emitValue = getControlParameterLeft();
+            const auto oldValue = emitValue;
             if (!util_isnan(emitValue) && m_iNoStates > 0) {
                 emitValue = static_cast<int>(emitValue + 1.0) % m_iNoStates;
             }
             if (m_leftButtonMode == ControlPushButton::LONGPRESSLATCHING) {
                 m_clickTimer.setSingleShot(true);
                 m_clickTimer.start(ControlPushButtonBehavior::kLongPressLatchingTimeMillis);
+                if (oldValue == 0.0 && m_pLongPressLatching) {
+                    m_pLongPressLatching->start();
+                }
             }
         }
         setControlParameterLeftDown(emitValue);
@@ -446,7 +464,6 @@ bool WPushButton::event(QEvent* e) {
 }
 
 void WPushButton::focusOutEvent(QFocusEvent* e) {
-    qDebug() << "focusOutEvent" << e->reason();
     if (m_bPressed && e->reason() != Qt::MouseFocusReason) {
         // Since we support multi touch there is no reason to reset
         // the pressed flag if the Primary touch point is moved to an
@@ -461,6 +478,10 @@ void WPushButton::mouseReleaseEvent(QMouseEvent * e) {
     const bool leftClick = e->button() == Qt::LeftButton;
     const bool rightClick = e->button() == Qt::RightButton;
 
+    if (m_pLongPressLatching) {
+        m_pLongPressLatching->stop();
+    }
+
     if (m_leftButtonMode == ControlPushButton::POWERWINDOW
             && m_iNoStates == 2) {
         if (leftClick) {
@@ -526,3 +547,60 @@ void WPushButton::fillDebugTooltip(QStringList* debug) {
            << QString("RightButtonMode: %1")
             .arg(ControlPushButton::buttonModeToString(m_rightButtonMode));
 }
+
+void WPushButton::updateSlot() {
+    update();
+}
+
+WPushButton::LongPressLatching::LongPressLatching(WPushButton* pButton)
+        : m_pButton(pButton) {
+    // To animate the long press latching
+    connect(&m_animTimer, &QTimer::timeout, m_pButton, &WPushButton::updateSlot);
+}
+
+void WPushButton::LongPressLatching::paint(QPainter* p) {
+    if (m_animTimer.isActive()) {
+        // Animate the long press latching by capturing the off state in a pixmap
+        // and gradually draw less of it over the duration of the long press latching.
+
+        int remainingTime = std::max(0,
+                ControlPushButtonBehavior::kLongPressLatchingTimeMillis -
+                        static_cast<int>(
+                                m_sinceStart.elapsed().toIntegerMillis()));
+
+        if (remainingTime == 0) {
+            m_animTimer.stop();
+        } else {
+            qreal x = m_pButton->width() * static_cast<qreal>(remainingTime) /
+                    static_cast<qreal>(ControlPushButtonBehavior::
+                                    kLongPressLatchingTimeMillis);
+            p->drawPixmap(QPointF(m_pButton->width() - x, 0),
+                    m_preLongPressPixmap,
+                    QRectF((m_pButton->width() - x) * m_pButton->devicePixelRatio(),
+                            0,
+                            x * m_pButton->devicePixelRatio(),
+                            m_pButton->height() * m_pButton->devicePixelRatio()));
+        }
+    }
+}
+
+void WPushButton::LongPressLatching::start() {
+    if (m_animTimer.isActive()) {
+        // already running
+        return;
+    }
+    // Capture pixmap with the off state ...
+    m_preLongPressPixmap = QPixmap(static_cast<int>(m_pButton->width() *
+                                           m_pButton->devicePixelRatio()),
+            static_cast<int>(
+                    m_pButton->height() * m_pButton->devicePixelRatio()));
+    m_preLongPressPixmap.setDevicePixelRatio(m_pButton->devicePixelRatio());
+    m_pButton->paintOnDevice(&m_preLongPressPixmap, 0);
+    // ... and start the long press latching animation
+    m_sinceStart.start();
+    m_animTimer.start(1000 / 60);
+}
+
+void WPushButton::LongPressLatching::stop() {
+    m_animTimer.stop();
+}
