@@ -2,8 +2,10 @@
 
 #include <QCheckBox>
 #include <QMouseEvent>
+#include <QPalette>
 #include <QScreen>
 #include <QStyleOptionButton>
+#include <QStylePainter>
 #include <QWidgetAction>
 
 #include "library/searchquery.h"
@@ -20,7 +22,7 @@ namespace {
 // a viable upper bound for the context menu.
 constexpr double kMaxMenuToAvailableScreenWidthRatio = 0.2;
 
-const QString kActionTextPrefixSuffixSeparator = QStringLiteral(" | ");
+const QString kActionTextPrefixSuffixSeparator = QStringLiteral(": ");
 
 inline QString quoteSearchQueryText(const QString& text) {
     return QChar('"') + text + QChar('"');
@@ -75,7 +77,7 @@ void WSearchRelatedTracksMenu::addTriggerSearchAction(
                     actionTextPrefix,
                     elidableTextSuffix);
 
-    auto pCheckBox = make_parented<QCheckBox>(
+    auto pCheckBox = make_parented<WSearchRelatedCheckBox>(
             mixxx::escapeTextPropertyWithoutShortcuts(elidedActionText),
             this);
     pCheckBox->setProperty("query", searchQuery);
@@ -130,7 +132,8 @@ QString WSearchRelatedTracksMenu::elideActionText(
                     // TODO: Customize the suffix elision?
                     Qt::ElideMiddle,
                     maxWidthInPixels - prefixWidthInPixels);
-    return actionTextPrefixWithSeparator + elidedTextSuffix;
+    // Add some margin between the label and the separator bar (see paintEvent())
+    return QStringLiteral("  ") + actionTextPrefixWithSeparator + elidedTextSuffix;
 }
 
 void WSearchRelatedTracksMenu::addActionsForTrack(
@@ -358,7 +361,8 @@ void WSearchRelatedTracksMenu::addActionsForTrack(
 
     // Make the Search button a checkbox to simplify setting an icon via qss.
     // This is not possible with a QAction, and tedious with a QPushButton.
-    auto pCheckBox = make_parented<QCheckBox>(tr("&Search selected"), this);
+    // Use a custom QCheckBox with fixed hover behavior.
+    auto pCheckBox = make_parented<WMenuCheckBox>(tr("&Search selected"), this);
     pCheckBox->setObjectName("SearchSelectedAction");
     m_pSearchAction = make_parented<QWidgetAction>(this);
     m_pSearchAction->setDefaultWidget(pCheckBox.get());
@@ -379,33 +383,35 @@ void WSearchRelatedTracksMenu::addActionsForTrack(
 
 bool WSearchRelatedTracksMenu::eventFilter(QObject* pObj, QEvent* e) {
     if (e->type() == QEvent::MouseButtonPress) {
-        // Clicking any spot in the checkbox that is not inside the indicator's
-        // 'click' rectangle triggers the search, ignoring other checked boxes.
-        // Clicks on the indicator are passed on to the event filter, hence
-        // toggling the checkbox happens as usual.
+        // Since we want tp provide a toggle function that allows to check multiple
+        // criteria (ie. don't auto-close the menu on first click) we need to
+        // figure the intended click target.
+        // Simply checking whether the click is inside the indicator's rectangle
+        // is not sufficient: the indicator's width & height is only about 60%
+        // of the item's total height, so there's top/left/bottom margin that
+        // would activate the action.
+        // Let's simply check if the click's x position is in the label region.
+        // If it is, trigger search ignoring other checked boxes. Else toggle it.
         QCheckBox* pBox = qobject_cast<QCheckBox*>(pObj);
         if (pBox) {
-            QMouseEvent* pMe = static_cast<QMouseEvent*>(e);
-            VERIFY_OR_DEBUG_ASSERT(pMe) {
-                return true;
-            }
+            auto* pStyle = pBox->style();
             QStyleOptionButton option;
             option.initFrom(pBox);
-            auto* pStyle = pBox->style();
-            if (!pStyle) {
-                return true;
-            }
-            const QRect indicatorClickRect = pStyle->subElementRect(QStyle::SE_CheckBoxClickRect,
+            const QRect labelRect = pStyle->subElementRect(QStyle::SE_CheckBoxContents,
                     &option,
                     pBox);
-            if (!indicatorClickRect.contains(pMe->pos())) {
-                // Text ('border' ractangle) was clicked, trigger the search.
+            QMouseEvent* pMe = static_cast<QMouseEvent*>(e);
+            if (pMe->pos().x() > labelRect.left()) {
+                // Label region was clicked, trigger the search.
                 const QString query = pBox->property("query").toString();
                 emit triggerSearch(query);
                 // Note that this click will not emit QAction::triggered like
                 // when pressing Return on a selected action, hence we need to
                 // make sure WTrackMenu closes when receiving triggerSearch().
+            } else {
+                pBox->toggle();
             }
+            return true;
         }
     }
     return QObject::eventFilter(pObj, e);
@@ -448,3 +454,31 @@ void WSearchRelatedTracksMenu::combineQueriesTriggerSearch() {
         emit triggerSearch(queryCombo);
     }
 }
+
+void WSearchRelatedCheckBox::paintEvent(QPaintEvent*) {
+    // start original QCheckBox implementation
+    QStylePainter painter(this);
+    QStyleOptionButton opt;
+    initStyleOption(&opt);
+    painter.drawControl(QStyle::CE_CheckBox, opt);
+    // end
+
+    // Draw a vertical bar over the entire height at the left edge of the label
+    const QStyle* pStyle = style();
+    const QRect labelRect = pStyle->subElementRect(QStyle::SE_CheckBoxContents,
+            &opt,
+            this);
+    const QRect frameRect = opt.rect;
+    const QPoint top(labelRect.left(), frameRect.top());
+    const QPoint bottom(labelRect.left(), frameRect.bottom());
+    // We draw with the separator color from qss or, if that's not set,
+    // with the palette's inactive text color.
+    const QPen linePen(
+            m_separatorColor.isValid() ? m_separatorColor
+                                       : opt.palette.color(QPalette::Disabled, QPalette::Text),
+            1,
+            Qt::SolidLine,
+            Qt::SquareCap);
+    painter.setPen(linePen);
+    painter.drawLine(top, bottom);
+}
