@@ -1,11 +1,19 @@
 #pragma once
 
+#include <QSize>
+#include <QStackedLayout>
 #include <QWidget>
-#include <QEvent>
 
 #include "widget/wbasewidget.h"
 
-class SizeAwareLayout;
+class QEvent;
+
+class SizeAwareLayout : public QStackedLayout {
+    Q_OBJECT
+  public:
+    QSize minimumSize() const override;
+    int setCurrentIndexForSize(const QSize& s);
+};
 
 class WSizeAwareStack : public QWidget, public WBaseWidget {
     Q_OBJECT
