@@ -9,7 +9,7 @@
 class QDomNode;
 class SkinContext;
 
-/** A widget for a slider composed of a background pixmap and a handle. */
+/// A widget for a slider composed of a background pixmap and a handle.
 class WSliderComposed : public WWidget  {
     Q_OBJECT
   public:
@@ -22,11 +22,15 @@ class WSliderComposed : public WWidget  {
             Paintable::DrawMode drawMode,
             double scaleFactor);
     void setHandlePixmap(
-            bool bHorizontal,
             const PixmapSource& sourceHandle,
             Paintable::DrawMode mode,
             double scaleFactor);
-    inline bool isHorizontal() const { return m_bHorizontal; };
+    // This is called by LegacySkinParser::setupConnections() before setup()
+    // because it needs 'horizontal' for picking the correct keyboard shortcut
+    // command (left/right or up/down.
+    // Doesn't recognize variables, hence we don't store the result in m_bHorizontal,
+    // that's done in setup() where we have a SkinContext, i.e. variable support.
+    bool tryParseHorizontal(const QDomNode& node) const;
     void inputActivity();
 
   public slots:
